@@ -1,7 +1,7 @@
 /******************************************************************************
 **  libDXFrw - Library to read/write DXF files (ascii & binary)              **
 **                                                                           **
-**  Copyright (C) 2011 Rallaz, rallazz@gmail.com                             **
+**  Copyright (C) 2011-2015 José F. Soriano, rallazz@gmail.com               **
 **                                                                           **
 **  This library is free software, licensed under the terms of the GNU       **
 **  General Public License as published by the Free Software Foundation,     **
@@ -16,34 +16,26 @@
 
 #include <string>
 #include <vector>
+#include <list>
 #include "drw_base.h"
 
 class dxfReader;
+class dwgBuffer;
 class DRW_Polyline;
 
 namespace DRW {
 
    //! Entity's type.
     enum ETYPE {
-        POINT,
-        LINE,
-        CIRCLE,
-        ARC,
-        ELLIPSE,
-        TRACE,
-        SOLID,
-        BLOCK,
-        INSERT,
-        LWPOLYLINE,
-        POLYLINE,
-        VERTEX,
-        SPLINE,
-        HATCH,
-        TEXT,
-        MTEXT,
         E3DFACE,
-        IMAGE,
-        LEADER,
+//        E3DSOLID, //encripted propietry data
+//        ACAD_PROXY_ENTITY,
+        ARC,
+//        ATTDEF,
+//        ATTRIB,
+        BLOCK,// and ENDBLK
+//        BODY, //encripted propietry data
+        CIRCLE,
         DIMENSION,
         DIMALIGNED,
         DIMLINEAR,
@@ -52,15 +44,51 @@ namespace DRW {
         DIMANGULAR,
         DIMANGULAR3P,
         DIMORDINATE,
-//        OVERLAYBOX,
-//        CONSTRUCTIONLINE,
+        ELLIPSE,
+        HATCH,
+//        HELIX,
+        IMAGE,
+        INSERT,
+        LEADER,
+//        LIGHT,
+        LINE,
+        LWPOLYLINE,
+//        MESH,
+//        MLINE,
+//        MLEADERSTYLE,
+//        MLEADER,
+        MTEXT,
+//        OLEFRAME,
+//        OLE2FRAME,
+        POINT,
+        POLYLINE,
         RAY,
-        XLINE,
+//        REGION, //encripted propietry data
+//        SECTION,
+//        SEQEND,//not needed?? used in polyline and insert/attrib and dwg
+//        SHAPE,
+        SOLID,
+        SPLINE,
+//        SUN,
+//        SURFACE, //encripted propietry data can be four types
+//        TABLE,
+        TEXT,
+//        TOLERANCE,
+        TRACE,
+        UNDERLAY,
+        VERTEX,
         VIEWPORT,
+//        WIPEOUT, //WIPEOUTVARIABLE
+        XLINE,
         UNKNOWN
     };
 
 }
+//only in DWG: MINSERT, 5 types of vertex, 4 types of polylines: 2d, 3d, pface & mesh
+//shape, dictionary, MLEADER, MLEADERSTYLE
+
+#define SETENTFRIENDS  friend class dxfRW; \
+                       friend class dwgReader;
 
 //! Base class for entities
 /*!
@@ -68,61 +96,137 @@ namespace DRW {
 *  @author Rallaz
 */
 class DRW_Entity {
+    SETENTFRIENDS
 public:
     //initializes default values
     DRW_Entity() {
         eType = DRW::UNKNOWN;
+        handle = parentHandle = DRW::NoHandle; //no handle (0)
         lineType = "BYLAYER";
-        color = 256; // default BYLAYER (256)
+        color = DRW::ColorByLayer; // default BYLAYER (256)
         ltypeScale = 1.0;
         visible = true;
         layer = "0";
         lWeight = DRW_LW_Conv::widthByLayer; // default BYLAYER  (dxf -1, dwg 29)
-        handleBlock = space = 0; // default ModelSpace (0) & handleBlock = no handle (0)
+        space = DRW::ModelSpace; // default ModelSpace (0)
         haveExtrusion = false;
         color24 = -1; //default -1 not set
+        numProxyGraph = 0;
+        shadow = DRW::CastAndReceieveShadows;
+        material = DRW::MaterialByLayer;
+        plotStyle = DRW::DefaultPlotStyle;
+        transparency = DRW::Opaque;
+        nextEntLink = prevEntLink = 0;
+        numReactors = xDictFlag = 0;
+        curr = NULL;
+        ownerHandle= false;
     }
-    virtual~DRW_Entity() {}
 
-    DRW_Entity(const DRW_Entity& d) {
-        eType = d.eType;
-        handle = d.handle;
-        handleBlock = d.handleBlock;
-        layer = d.layer;
-        lineType = d.lineType;
-        color = d.color;
-        color24 = d.color24;
-        colorName = d.colorName;
-        ltypeScale = d.ltypeScale;
-        visible = d.visible;
-        lWeight = d.lWeight;
-        space = d.space;
-        haveExtrusion = d.haveExtrusion;
+    DRW_Entity(const DRW_Entity& e) {
+        eType = e.eType;
+        handle = e.handle;
+        parentHandle = e.parentHandle; //no handle (0)
+        lineType = e.lineType;
+        color = e.color; // default BYLAYER (256)
+        ltypeScale = e.ltypeScale;
+        visible = e.visible;
+        layer = e.layer;
+        lWeight = e.lWeight;
+        space = e.space;
+        haveExtrusion = e.haveExtrusion;
+        color24 = e.color24; //default -1 not set
+        numProxyGraph = e.numProxyGraph;
+        shadow = e.shadow;
+        material = e.material;
+        plotStyle = e.plotStyle;
+        transparency = e.transparency;
+        nextEntLink = e.nextEntLink;
+        prevEntLink = e.prevEntLink;
+        numReactors = e.numReactors;
+        xDictFlag = e.xDictFlag;
+        curr = NULL;
+        ownerHandle= false;
+//        curr = e.curr;
+        for (std::vector<DRW_Variant*>::const_iterator it=e.extData.begin(); it!=e.extData.end(); ++it){
+            extData.push_back(new DRW_Variant(*(*it)));
+        }
+    }
+
+    virtual ~DRW_Entity() {
+        for (std::vector<DRW_Variant*>::iterator it=extData.begin(); it!=extData.end(); ++it)
+            delete *it;
+
+        extData.clear();
+    }
+
+    void reset(){
+        for (std::vector<DRW_Variant*>::iterator it=extData.begin(); it!=extData.end(); ++it)
+            delete *it;
+        extData.clear();
     }
 
     virtual void applyExtrusion() = 0;
+
 protected:
-    void parseCode(int code, dxfReader *reader);
+    //parses dxf pair to read entity
+    bool parseCode(int code, dxfReader *reader);
+    //calculates extrusion axis (normal vector)
     void calculateAxis(DRW_Coord extPoint);
+    //apply extrusion to @extPoint and return data in @point
     void extrudePoint(DRW_Coord extPoint, DRW_Coord *point);
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0)=0;
+    //parses dwg common start part to read entity
+    bool parseDwg(DRW::Version version, dwgBuffer *buf, dwgBuffer* strBuf, duint32 bs=0);
+    //parses dwg common handles part to read entity
+    bool parseDwgEntHandle(DRW::Version version, dwgBuffer *buf);
+
+    //parses dxf 102 groups to read entity
+    bool parseDxfGroups(int code, dxfReader *reader);
 
 public:
     enum DRW::ETYPE eType;     /*!< enum: entity type, code 0 */
-    int handle;                /*!< entity identifier, code 5 */
-    int handleBlock;           /*!< Soft-pointer ID/handle to owner BLOCK_RECORD object, code 330 */
-    UTF8STRING layer;              /*!< layer name, code 8 */
-    UTF8STRING lineType;           /*!< line type, code 6 */
+    duint32 handle;            /*!< entity identifier, code 5 */
+    std::list<std::list<DRW_Variant> > appData; /*!< list of application data, code 102 */
+    duint32 parentHandle;      /*!< Soft-pointer ID/handle to owner BLOCK_RECORD object, code 330 */
+    DRW::Space space;          /*!< space indicator, code 67*/
+    UTF8STRING layer;          /*!< layer name, code 8 */
+    UTF8STRING lineType;       /*!< line type, code 6 */
+    duint32 material;          /*!< hard pointer id to material object, code 347 */
     int color;                 /*!< entity color, code 62 */
     enum DRW_LW_Conv::lineWidth lWeight; /*!< entity lineweight, code 370 */
     double ltypeScale;         /*!< linetype scale, code 48 */
     bool visible;              /*!< entity visibility, code 60 */
+    int numProxyGraph;         /*!< Number of bytes in proxy graphics, code 92 */
+    std::string proxyGraphics; /*!< proxy graphics bytes, code 310 */
     int color24;               /*!< 24-bit color, code 420 */
     std::string colorName;     /*!< color name, code 430 */
-    int space;                 /*!< space indicator 0 = model, 1 paper, code 67*/
+    int transparency;          /*!< transparency, code 440 */
+    int plotStyle;             /*!< hard pointer id to plot style object, code 390 */
+    DRW::ShadowMode shadow;    /*!< shadow mode, code 284 */
     bool haveExtrusion;        /*!< set to true if the entity have extrusion*/
+    std::vector<DRW_Variant*> extData; /*!< FIFO list of extended data, codes 1000 to 1071*/
+
+protected: //only for read dwg
+    duint8 haveNextLinks; //aka nolinks //B
+    duint8 plotFlags; //presence of plot style //BB
+    duint8 ltFlags; //presence of linetype handle //BB
+    duint8 materialFlag; //presence of material handle //BB
+    duint8 shadowFlag; //presence of shadow handle ?? (in dwg may be plotflag)//RC
+    dwgHandle lTypeH;
+    dwgHandle layerH;
+    duint32 nextEntLink;
+    duint32 prevEntLink;
+    bool ownerHandle;
+
+    duint8 xDictFlag;
+    dint32 numReactors; //
+    duint32 objSize;  //RL 32bits object data size in bits
+    dint16 oType;
+
 private:
     DRW_Coord extAxisX;
     DRW_Coord extAxisY;
+    DRW_Variant* curr;
 };
 
 
@@ -132,6 +236,7 @@ private:
 *  @author Rallaz
 */
 class DRW_Point : public DRW_Entity {
+    SETENTFRIENDS
 public:
     DRW_Point() {
         eType = DRW::POINT;
@@ -142,12 +247,16 @@ public:
 
     virtual void applyExtrusion(){}
 
+protected:
     void parseCode(int code, dxfReader *reader);
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 
 public:
     DRW_Coord basePoint;      /*!<  base point, code 10, 20 & 30 */
     double thickness;         /*!< thickness, code 39 */
     DRW_Coord extPoint;       /*!<  Dir extrusion normal vector, code 210, 220 & 230 */
+    // TNick: we're not handling code 50 - Angle of the X axis for
+    // the UCS in effect when the point was drawn
 };
 
 //! Class to handle line entity
@@ -156,6 +265,7 @@ public:
 *  @author Rallaz
 */
 class DRW_Line : public DRW_Point {
+    SETENTFRIENDS
 public:
     DRW_Line() {
         eType = DRW::LINE;
@@ -163,7 +273,10 @@ public:
     }
 
     virtual void applyExtrusion(){}
+
+protected:
     void parseCode(int code, dxfReader *reader);
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 
 public:
     DRW_Coord secPoint;        /*!< second point, code 11, 21 & 31 */
@@ -175,10 +288,13 @@ public:
 *  @author Rallaz
 */
 class DRW_Ray : public DRW_Line {
+    SETENTFRIENDS
 public:
     DRW_Ray() {
         eType = DRW::RAY;
     }
+protected:
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 };
 
 //! Class to handle xline entity
@@ -186,7 +302,7 @@ public:
 *  Class to handle xline entity
 *  @author Rallaz
 */
-class DRW_Xline : public DRW_Line {
+class DRW_Xline : public DRW_Ray {
 public:
     DRW_Xline() {
         eType = DRW::XLINE;
@@ -199,13 +315,17 @@ public:
 *  @author Rallaz
 */
 class DRW_Circle : public DRW_Point {
+    SETENTFRIENDS
 public:
     DRW_Circle() {
         eType = DRW::CIRCLE;
     }
 
     virtual void applyExtrusion();
+
+protected:
     void parseCode(int code, dxfReader *reader);
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 
 public:
     double radious;                 /*!< radius, code 40 */
@@ -217,6 +337,7 @@ public:
 *  @author Rallaz
 */
 class DRW_Arc : public DRW_Circle {
+    SETENTFRIENDS
 public:
     DRW_Arc() {
         eType = DRW::ARC;
@@ -224,7 +345,25 @@ public:
     }
 
     virtual void applyExtrusion();
+
+    //! center point in OCS
+    const DRW_Coord & center() { return basePoint; }
+    //! the radius of the circle
+    double radius() { return radious; }
+    //! start angle in radians
+    double startAngle() { return staangle; }
+    //! end angle in radians
+    double endAngle() { return endangle; }
+    //! thickness
+    double thick() { return thickness; }
+    //! extrusion
+    const DRW_Coord & extrusion() { return extPoint; }
+
+protected:
+    //! interpret code in dxf reading process or dispatch to inherited class
     void parseCode(int code, dxfReader *reader);
+    //! interpret dwg data (was already determined to be part of this object)
+    virtual bool parseDwg(DRW::Version v, dwgBuffer *buf, duint32 bs=0);
 
 public:
     double staangle;            /*!< start angle, code 50 in radians*/
@@ -240,20 +379,29 @@ public:
 *  @author Rallaz
 */
 class DRW_Ellipse : public DRW_Line {
+    SETENTFRIENDS
 public:
     DRW_Ellipse() {
         eType = DRW::ELLIPSE;
         isccw = 1;
     }
 
-    void parseCode(int code, dxfReader *reader);
     void toPolyline(DRW_Polyline *pol, int parts = 128);
     virtual void applyExtrusion();
+
+protected:
+    //! interpret code in dxf reading process or dispatch to inherited class
+    void parseCode(int code, dxfReader *reader);
+    //! interpret dwg data (was already determined to be part of this object)
+    virtual bool parseDwg(DRW::Version v, dwgBuffer *buf, duint32 bs=0);
+
+private:
     void correctAxis();
+
 public:
-    double ratio;           /*!< ratio, code 40 */
-    double staparam;        /*!< start parameter, code 41, 0.0 for full ellipse*/
-    double endparam;        /*!< end parameter, code 42, 2*PI for full ellipse */
+    double ratio;        /*!< ratio, code 40 */
+    double staparam;     /*!< start parameter, code 41, 0.0 for full ellipse*/
+    double endparam;     /*!< end parameter, code 42, 2*PI for full ellipse */
     int isccw;           /*!< is counter clockwise arc?, only used in hatch, code 73 */
 };
 
@@ -263,6 +411,7 @@ public:
 *  @author Rallaz
 */
 class DRW_Trace : public DRW_Line {
+    SETENTFRIENDS
 public:
     DRW_Trace() {
         eType = DRW::TRACE;
@@ -271,7 +420,10 @@ public:
     }
 
     virtual void applyExtrusion();
+
+protected:
     void parseCode(int code, dxfReader *reader);
+    virtual bool parseDwg(DRW::Version v, dwgBuffer *buf, duint32 bs=0);
 
 public:
     DRW_Coord thirdPoint;        /*!< third point, code 12, 22 & 32 */
@@ -284,12 +436,34 @@ public:
 *  @author Rallaz
 */
 class DRW_Solid : public DRW_Trace {
+    SETENTFRIENDS
 public:
     DRW_Solid() {
         eType = DRW::SOLID;
     }
 
+protected:
+    //! interpret code in dxf reading process or dispatch to inherited class
     void parseCode(int code, dxfReader *reader);
+    //! interpret dwg data (was already determined to be part of this object)
+    virtual bool parseDwg(DRW::Version v, dwgBuffer *buf, duint32 bs=0);
+
+public:
+    //! first corner (2D)
+    const DRW_Coord & firstCorner() { return basePoint; }
+    //! second corner (2D)
+    const DRW_Coord & secondCorner() { return secPoint; }
+    //! third corner (2D)
+    const DRW_Coord & thirdCorner() { return thirdPoint; }
+    //! fourth corner (2D)
+    const DRW_Coord & fourthCorner() { return thirdPoint; }
+    //! thickness
+    double thick() { return thickness; }
+    //! elevation
+    double elevation() { return basePoint.z; }
+    //! extrusion
+    const DRW_Coord & extrusion() { return extPoint; }
+
 };
 
 //! Class to handle 3dface entity
@@ -298,14 +472,40 @@ public:
 *  @author Rallaz
 */
 class DRW_3Dface : public DRW_Trace {
+    SETENTFRIENDS
 public:
+    enum InvisibleEdgeFlags {
+        NoEdge = 0x00,
+        FirstEdge = 0x01,
+        SecodEdge = 0x02,
+        ThirdEdge = 0x04,
+        FourthEdge = 0x08,
+        AllEdges = 0x0F
+    };
+
     DRW_3Dface() {
         eType = DRW::E3DFACE;
         invisibleflag = 0;
     }
 
     virtual void applyExtrusion(){}
+
+    //! first corner in WCS
+    const DRW_Coord & firstCorner() { return basePoint; }
+    //! second corner in WCS
+    const DRW_Coord & secondCorner() { return secPoint; }
+    //! third corner in WCS
+    const DRW_Coord & thirdCorner() { return thirdPoint; }
+    //! fourth corner in WCS
+    const DRW_Coord & fourthCorner() { return fourPoint; }
+    //! edge visibility flags
+    InvisibleEdgeFlags edgeFlags() { return (InvisibleEdgeFlags)invisibleflag; }
+
+protected:
+    //! interpret code in dxf reading process or dispatch to inherited class
     void parseCode(int code, dxfReader *reader);
+    //! interpret dwg data (was already determined to be part of this object)
+    virtual bool parseDwg(DRW::Version v, dwgBuffer *buf, duint32 bs=0);
 
 public:
     int invisibleflag;       /*!< invisible edge flag, code 70 */
@@ -318,20 +518,27 @@ public:
 *  @author Rallaz
 */
 class DRW_Block : public DRW_Point {
+    SETENTFRIENDS
 public:
     DRW_Block() {
         eType = DRW::BLOCK;
         layer = "0";
         flags = 0;
         name = "*U0";
+        isEnd = false;
     }
 
     virtual void applyExtrusion(){}
+
+protected:
     void parseCode(int code, dxfReader *reader);
+    virtual bool parseDwg(DRW::Version v, dwgBuffer *buf, duint32 bs=0);
 
 public:
     UTF8STRING name;             /*!< block name, code 2 */
     int flags;                   /*!< block type, code 70 */
+private:
+    bool isEnd; //for dwg parsing
 };
 
 
@@ -341,6 +548,7 @@ public:
 *  @author Rallaz
 */
 class DRW_Insert : public DRW_Point {
+    SETENTFRIENDS
 public:
     DRW_Insert() {
         eType = DRW::INSERT;
@@ -355,18 +563,24 @@ public:
     }
 
     virtual void applyExtrusion(){DRW_Point::applyExtrusion();}
+
+protected:
     void parseCode(int code, dxfReader *reader);
+    virtual bool parseDwg(DRW::Version v, dwgBuffer *buf, duint32 bs=0);
 
 public:
     UTF8STRING name;         /*!< block name, code 2 */
     double xscale;           /*!< x scale factor, code 41 */
     double yscale;           /*!< y scale factor, code 42 */
     double zscale;           /*!< z scale factor, code 43 */
-    double angle;            /*!< rotation angle, code 50 */
+    double angle;            /*!< rotation angle in radians, code 50 */
     int colcount;            /*!< column count, code 70 */
     int rowcount;            /*!< row count, code 71 */
     double colspace;         /*!< column space, code 44 */
     double rowspace;         /*!< row space, code 45 */
+public: //only for read dwg
+    dwgHandle blockRecH;
+    dwgHandle seqendH; //RLZ: on implement attrib remove this handle from obj list (see pline/vertex code)
 };
 
 //! Class to handle lwpolyline entity
@@ -375,6 +589,7 @@ public:
 *  @author Rallaz
 */
 class DRW_LWPolyline : public DRW_Entity {
+    SETENTFRIENDS
 public:
     DRW_LWPolyline() {
         eType = DRW::LWPOLYLINE;
@@ -384,10 +599,25 @@ public:
         extPoint.z = 1;
         vertex = NULL;
     }
+    
+    DRW_LWPolyline(const DRW_LWPolyline& p):DRW_Entity(p){
+        this->eType = DRW::LWPOLYLINE;
+        this->elevation = p.elevation;
+        this->thickness = p.thickness;
+        this->width = p.width;
+        this->flags = p.flags;
+        this->extPoint = p.extPoint;
+        this->vertex = NULL;
+        for (unsigned i=0; i<p.vertlist.size(); i++)// RLZ ok or new
+          this->vertlist.push_back( new DRW_Vertex2D( *(p.vertlist.at(i)) ) );
+
+        this->vertex = NULL;
+    }
+
     ~DRW_LWPolyline() {
         while (!vertlist.empty()) {
-           vertlist.pop_back();
-         }
+            vertlist.pop_back();
+        }
     }
     virtual void applyExtrusion();
     void addVertex (DRW_Vertex2D v) {
@@ -408,7 +638,9 @@ public:
         return vert;
     }
 
+protected:
     void parseCode(int code, dxfReader *reader);
+     bool parseDwg(DRW::Version v, dwgBuffer *buf, duint32 bs=0);
 
 public:
     int vertexnum;            /*!< number of vertex, code 90 */
@@ -427,6 +659,7 @@ public:
 *  @author Rallaz
 */
 class DRW_Text : public DRW_Line {
+    SETENTFRIENDS
 public:
     //! Vertical alignments.
         enum VAlign {
@@ -458,7 +691,10 @@ public:
     }
 
     virtual void applyExtrusion(){} //RLZ TODO
+
+protected:
     void parseCode(int code, dxfReader *reader);
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 
 public:
     double height;             /*!< height text, code 40 */
@@ -470,6 +706,7 @@ public:
     int textgen;               /*!< text generation, code 71 */
     enum HAlign alignH;        /*!< horizontal align, code 72 */
     enum VAlign alignV;        /*!< vertical align, code 73 */
+    dwgHandle styleH;          /*!< handle for text style */
 };
 
 //! Class to handle insert entries
@@ -478,6 +715,7 @@ public:
 *  @author Rallaz
 */
 class DRW_MText : public DRW_Text {
+    SETENTFRIENDS
 public:
     //! Attachments.
     enum Attach {
@@ -500,8 +738,10 @@ public:
         haveXAxis = false;    //if true needed to recalculate angle
     }
 
+protected:
     void parseCode(int code, dxfReader *reader);
     void updateAngle();    //recalculate angle if 'haveXAxis' is true
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 
 public:
     double interlin;     /*!< width factor, code 44 */
@@ -515,6 +755,7 @@ private:
 *  @author Rallaz
 */
 class DRW_Vertex : public DRW_Point {
+    SETENTFRIENDS
 public:
     DRW_Vertex() {
         eType = DRW::VERTEX;
@@ -532,7 +773,11 @@ public:
         bulge = b;
     }
 
+protected:
     void parseCode(int code, dxfReader *reader);
+    bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0, double el=0);
+    virtual bool parseDwg(DRW::Version version, dwgBuffer* buf, duint32 bs=0){
+        DRW_UNUSED(version); DRW_UNUSED(buf); DRW_UNUSED(bs); return true;}
 
 public:
     double stawidth;          /*!< Start width, code 40 */
@@ -554,6 +799,7 @@ public:
 *  @author Rallaz
 */
 class DRW_Polyline : public DRW_Point {
+    SETENTFRIENDS
 public:
     DRW_Polyline() {
         eType = DRW::POLYLINE;
@@ -581,7 +827,9 @@ public:
         vertlist.push_back(v);
     }
 
+protected:
     void parseCode(int code, dxfReader *reader);
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 
 public:
     int flags;               /*!< polyline flag, code 70, default 0 */
@@ -594,6 +842,12 @@ public:
     int curvetype;           /*!< curves & smooth surface type, code 75, default 0 */
 
     std::vector<DRW_Vertex *> vertlist;  /*!< vertex list */
+
+private:
+    std::list<duint32>hadlesList; //list of handles, only in 2004+
+    duint32 firstEH;      //handle of first entity, only in pre-2004
+    duint32 lastEH;       //handle of last entity, only in pre-2004
+    dwgHandle seqEndH;    //handle of SEQEND entity
 };
 
 
@@ -603,12 +857,11 @@ public:
 *  @author Rallaz
 */
 class DRW_Spline : public DRW_Entity {
+    SETENTFRIENDS
 public:
     DRW_Spline() {
         eType = DRW::SPLINE;
         flags = nknots = ncontrol = nfit = 0;
-        ex = ey = 0.0;
-        ez = 1.0;
         tolknot = tolcontrol = tolfit = 0.0000001;
 
     }
@@ -622,23 +875,28 @@ public:
     }
     virtual void applyExtrusion(){}
 
+protected:
     void parseCode(int code, dxfReader *reader);
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 
 public:
-    double ex;                /*!< normal vector x coordinate, code 210 */
-    double ey;                /*!< normal vector y coordinate, code 220 */
-    double ez;                /*!< normal vector z coordinate, code 230 */
-    double tgsx;              /*!< start tangent x coordinate, code 12 */
-    double tgsy;              /*!< start tangent y coordinate, code 22 */
-    double tgsz;              /*!< start tangent z coordinate, code 32 */
-    double tgex;              /*!< end tangent x coordinate, code 13 */
-    double tgey;              /*!< end tangent y coordinate, code 23 */
-    double tgez;              /*!< end tangent z coordinate, code 33 */
+//    double ex;                /*!< normal vector x coordinate, code 210 */
+//    double ey;                /*!< normal vector y coordinate, code 220 */
+//    double ez;                /*!< normal vector z coordinate, code 230 */
+    DRW_Coord normalVec;      /*!< normal vector, code 210, 220, 230 */
+    DRW_Coord tgStart;        /*!< start tangent, code 12, 22, 32 */
+//    double tgsx;              /*!< start tangent x coordinate, code 12 */
+//    double tgsy;              /*!< start tangent y coordinate, code 22 */
+//    double tgsz;              /*!< start tangent z coordinate, code 32 */
+    DRW_Coord tgEnd;          /*!< end tangent, code 13, 23, 33 */
+//    double tgex;              /*!< end tangent x coordinate, code 13 */
+//    double tgey;              /*!< end tangent y coordinate, code 23 */
+//    double tgez;              /*!< end tangent z coordinate, code 33 */
     int flags;                /*!< spline flag, code 70 */
     int degree;               /*!< degree of the spline, code 71 */
-    int nknots;               /*!< number of knots, code 72, default 0 */
-    int ncontrol;             /*!< number of control points, code 73, default 0 */
-    int nfit;                 /*!< number of fit points, code 74, default 0 */
+    dint32 nknots;            /*!< number of knots, code 72, default 0 */
+    dint32 ncontrol;          /*!< number of control points, code 73, default 0 */
+    dint32 nfit;              /*!< number of fit points, code 74, default 0 */
     double tolknot;           /*!< knot tolerance, code 42, default 0.0000001 */
     double tolcontrol;        /*!< control point tolerance, code 43, default 0.0000001 */
     double tolfit;            /*!< fit point tolerance, code 44, default 0.0000001 */
@@ -692,6 +950,7 @@ public:
 */
 //TODO: handle lwpolylines, splines and ellipses
 class DRW_Hatch : public DRW_Point {
+    SETENTFRIENDS
 public:
     DRW_Hatch() {
         eType = DRW::HATCH;
@@ -715,10 +974,13 @@ public:
     }
 
     virtual void applyExtrusion(){}
+
+protected:
     void parseCode(int code, dxfReader *reader);
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 
 public:
-    UTF8STRING name;               /*!< hatch pattern name, code 2 */
+    UTF8STRING name;           /*!< hatch pattern name, code 2 */
     int solid;                 /*!< solid fill flag, code 70, solid=1, pattern=0 */
     int associative;           /*!< associativity, code 71, associatve=1, non-assoc.=0 */
     int hstyle;                /*!< hatch style, code 75 */
@@ -791,20 +1053,24 @@ private:
 *  @author Rallaz
 */
 class DRW_Image : public DRW_Line {
+    SETENTFRIENDS
 public:
     DRW_Image() {
         eType = DRW::IMAGE;
-        vz = fade = clip = 0;
+        fade = clip = 0;
         brightness = contrast = 50;
     }
 
+protected:
     void parseCode(int code, dxfReader *reader);
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 
 public:
-    std::string ref;           /*!< Hard reference to imagedef object, code 340 */
-    double vx;                 /*!< V-vector of single pixel, x coordinate, code 12 */
-    double vy;                 /*!< V-vector of single pixel, y coordinate, code 22 */
-    double vz;                 /*!< V-vector of single pixel, z coordinate, code 32 */
+    duint32 ref;               /*!< Hard reference to imagedef object, code 340 */
+    DRW_Coord vVector;         /*!< V-vector of single pixel, x coordinate, code 12, 22 & 32 */
+//    double vx;                 /*!< V-vector of single pixel, x coordinate, code 12 */
+//    double vy;                 /*!< V-vector of single pixel, y coordinate, code 22 */
+//    double vz;                 /*!< V-vector of single pixel, z coordinate, code 32 */
     double sizeu;              /*!< image size in pixels, U value, code 13 */
     double sizev;              /*!< image size in pixels, V value, code 23 */
     double dz;                 /*!< z coordinate, code 33 */
@@ -822,9 +1088,11 @@ public:
 *  @author Rallaz
 */
 class DRW_Dimension : public DRW_Entity {
+    SETENTFRIENDS
 public:
     DRW_Dimension() {
         eType = DRW::DIMENSION;
+        type = 0;
         linesty = 1;
         linefactor = extPoint.z = 1.0;
         angle = oblique = rot = 0.0;
@@ -856,12 +1124,19 @@ public:
         arcPoint = d.arcPoint;
         circlePoint = d.circlePoint;
         length = d.length;
+        //RLZ needed a def value for this: hdir = ???
     }
     virtual ~DRW_Dimension() {}
 
-    void parseCode(int code, dxfReader *reader);
     virtual void applyExtrusion(){}
 
+protected:
+    void parseCode(int code, dxfReader *reader);
+    bool parseDwg(DRW::Version version, dwgBuffer *buf, dwgBuffer *sBuf);
+    virtual bool parseDwg(DRW::Version version, dwgBuffer* buf, duint32 bs=0){
+        DRW_UNUSED(version); DRW_UNUSED(buf); DRW_UNUSED(bs); return true;}
+
+public:
     DRW_Coord getDefPoint() const {return defPoint;}      /*!< Definition point, code 10, 20 & 30 */
     void setDefPoint(const DRW_Coord p) {defPoint =p;}
     DRW_Coord getTextPoint() const {return textPoint;}    /*!< Middle point of text, code 11, 21 & 31 */
@@ -905,18 +1180,18 @@ protected:
 public:
     int type;                  /*!< Dimension type, code 70 */
 private:
-    std::string name;               /*!< Name of the block that contains the entities, code 2 */
-    DRW_Coord defPoint;      /*!<  definition point, code 10, 20 & 30 (WCS) */
-    DRW_Coord textPoint;     /*!< Middle point of text, code 11, 21 & 31 (OCS) */
-    UTF8STRING text;               /*!< Dimension text explicitly entered by the user, code 1 */
-    UTF8STRING style;              /*!< Dimension style, code 3 */
+    std::string name;          /*!< Name of the block that contains the entities, code 2 */
+    DRW_Coord defPoint;        /*!<  definition point, code 10, 20 & 30 (WCS) */
+    DRW_Coord textPoint;       /*!< Middle point of text, code 11, 21 & 31 (OCS) */
+    UTF8STRING text;           /*!< Dimension text explicitly entered by the user, code 1 */
+    UTF8STRING style;          /*!< Dimension style, code 3 */
     int align;                 /*!< attachment point, code 71 */
     int linesty;               /*!< Dimension text line spacing style, code 72, default 1 */
     double linefactor;         /*!< Dimension text line spacing factor, code 41, default 1? (value range 0.25 to 4.00*/
     double rot;                /*!< rotation angle of the dimension text, code 53 */
-    DRW_Coord extPoint;       /*!<  extrusion normal vector, code 210, 220 & 230 */
+    DRW_Coord extPoint;        /*!<  extrusion normal vector, code 210, 220 & 230 */
 
-    //    double hdir;               /*!< horizontal direction for the dimension, code 51, default ? */
+    double hdir;               /*!< horizontal direction for the dimension, code 51, default ? */
     DRW_Coord clonePoint;      /*!< Insertion point for clones (Baseline & Continue), code 12, 22 & 32 (OCS) */
     DRW_Coord def1;            /*!< Definition point 1for linear & angular, code 13, 23 & 33 (WCS) */
     DRW_Coord def2;            /*!< Definition point 2, code 14, 24 & 34 (WCS) */
@@ -926,6 +1201,10 @@ private:
     DRW_Coord circlePoint;     /*!< Definition point for diameter, radius & angular dims code 15, 25 & 35 (WCS) */
     DRW_Coord arcPoint;        /*!< Point defining dimension arc, x coordinate, code 16, 26 & 36 (OCS) */
     double length;             /*!< Leader length, code 40 */
+
+protected:
+    dwgHandle dimStyleH;
+    dwgHandle blockH;
 };
 
 
@@ -935,6 +1214,7 @@ private:
 *  @author Rallaz
 */
 class DRW_DimAligned : public DRW_Dimension {
+    SETENTFRIENDS
 public:
     DRW_DimAligned(){
         eType = DRW::DIMALIGNED;
@@ -952,6 +1232,9 @@ public:
     void setDef1Point(const DRW_Coord p) {setPt3(p);}
     DRW_Coord getDef2Point() const {return getPt4();}       /*!< Definition point 2, code 14, 24 & 34 */
     void setDef2Point(const DRW_Coord p) {setPt4(p);}
+
+protected:
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 };
 
 //! Class to handle  linear or rotated dimension entity
@@ -980,6 +1263,7 @@ public:
 *  @author Rallaz
 */
 class DRW_DimRadial : public DRW_Dimension {
+    SETENTFRIENDS
 public:
     DRW_DimRadial() {
         eType = DRW::DIMRADIAL;
@@ -994,6 +1278,9 @@ public:
     void setDiameterPoint(const DRW_Coord p){setPt5(p);}
     double getLeaderLength() const {return getRa40();}         /*!< Leader length, code 40 */
     void setLeaderLength(const double d) {setRa40(d);}
+
+protected:
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 };
 
 //! Class to handle radial dimension entity
@@ -1002,6 +1289,7 @@ public:
 *  @author Rallaz
 */
 class DRW_DimDiametric : public DRW_Dimension {
+    SETENTFRIENDS
 public:
     DRW_DimDiametric() {
         eType = DRW::DIMDIAMETRIC;
@@ -1016,6 +1304,9 @@ public:
     void setDiameter2Point(const DRW_Coord p){setDefPoint(p);}
     double getLeaderLength() const {return getRa40();}          /*!< Leader length, code 40 */
     void setLeaderLength(const double d) {setRa40(d);}
+
+protected:
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 };
 
 //! Class to handle angular dimension entity
@@ -1024,6 +1315,7 @@ public:
 *  @author Rallaz
 */
 class DRW_DimAngular : public DRW_Dimension {
+    SETENTFRIENDS
 public:
     DRW_DimAngular() {
         eType = DRW::DIMANGULAR;
@@ -1042,6 +1334,9 @@ public:
     void setSecondLine2(const DRW_Coord p){setDefPoint(p);}
     DRW_Coord getDimPoint() const {return getPt6();}         /*!< Dimension definition point, code 16, 26 & 36 */
     void setDimPoint(const DRW_Coord p) {setPt6(p);}
+
+protected:
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 };
 
 
@@ -1051,6 +1346,7 @@ public:
 *  @author Rallaz
 */
 class DRW_DimAngular3p : public DRW_Dimension {
+    SETENTFRIENDS
 public:
     DRW_DimAngular3p() {
         eType = DRW::DIMANGULAR3P;
@@ -1067,6 +1363,9 @@ public:
     void SetVertexPoint(const DRW_Coord p) {setPt5(p);}
     DRW_Coord getDimPoint() const {return getDefPoint();}    /*!< Dimension definition point, code 10, 20 & 30 */
     void setDimPoint(const DRW_Coord p) {setDefPoint(p);}
+
+protected:
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 };
 
 //! Class to handle ordinate dimension entity
@@ -1075,6 +1374,7 @@ public:
 *  @author Rallaz
 */
 class DRW_DimOrdinate : public DRW_Dimension {
+    SETENTFRIENDS
 public:
     DRW_DimOrdinate() {
         eType = DRW::DIMORDINATE;
@@ -1089,6 +1389,9 @@ public:
     void setFirstLine(const DRW_Coord p) {setPt3(p);}
     DRW_Coord getSecondLine() const {return getPt4();}         /*!< Leader end point, code 14, 24 & 34 */
     void setSecondLine(const DRW_Coord p) {setPt4(p);}
+
+protected:
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 };
 
 
@@ -1098,6 +1401,7 @@ public:
 *  @author Rallaz
 */
 class DRW_Leader : public DRW_Entity {
+    SETENTFRIENDS
 public:
     DRW_Leader() {
         eType = DRW::LEADER;
@@ -1114,7 +1418,10 @@ public:
     }
 
     virtual void applyExtrusion(){}
+
+protected:
     void parseCode(int code, dxfReader *reader);
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 
 public:
     UTF8STRING style;          /*!< Dimension style name, code 3 */
@@ -1127,7 +1434,7 @@ public:
     double textwidth;          /*!< Text annotation width, code 41 */
     int vertnum;               /*!< Number of vertices, code 76 */
     int coloruse;              /*!< Color to use if leader's DIMCLRD = BYBLOCK, code 77 */
-    std::string handle;        /*!< Hard reference to associated annotation, code 340 */
+    duint32 annotHandle;       /*!< Hard reference to associated annotation, code 340 */
     DRW_Coord extrusionPoint;  /*!< Normal vector, code 210, 220 & 230 */
     DRW_Coord horizdir;        /*!< "Horizontal" direction for leader, code 211, 221 & 231 */
     DRW_Coord offsetblock;     /*!< Offset of last leader vertex from block, code 212, 222 & 232 */
@@ -1137,6 +1444,8 @@ public:
 
 private:
     DRW_Coord *vertexpoint;   /*!< current control point to add data */
+    dwgHandle dimStyleH;
+    dwgHandle AnnotH;
 };
 
 //! Class to handle viewport entity
@@ -1145,6 +1454,7 @@ private:
 *  @author Rallaz
 */
 class DRW_Viewport : public DRW_Point {
+    SETENTFRIENDS
 public:
     DRW_Viewport() {
         eType = DRW::VIEWPORT;
@@ -1156,17 +1466,60 @@ public:
     }
 
     virtual void applyExtrusion(){}
+
+protected:
     void parseCode(int code, dxfReader *reader);
+    virtual bool parseDwg(DRW::Version version, dwgBuffer *buf, duint32 bs=0);
 
 public:
     double pswidth;           /*!< Width in paper space units, code 40 */
     double psheight;          /*!< Height in paper space units, code 41 */
     int vpstatus;             /*!< Viewport status, code 68 */
     int vpID;                 /*!< Viewport ID, code 69 */
-    double centerPX;          /*!< view center piont X, code 12 */
-    double centerPY;          /*!< view center piont Y, code 22 */
-};
+    double centerPX;          /*!< view center point X, code 12 */
+    double centerPY;          /*!< view center point Y, code 22 */
+    double snapPX;          /*!< Snap base point X, code 13 */
+    double snapPY;          /*!< Snap base point Y, code 23 */
+    double snapSpPX;          /*!< Snap spacing X, code 14 */
+    double snapSpPY;          /*!< Snap spacing Y, code 24 */
+    //TODO: complete in dxf
+    DRW_Coord viewDir;        /*!< View direction vector, code 16, 26 & 36 */
+    DRW_Coord viewTarget;     /*!< View target point, code 17, 27, 37 */
+    double viewLength;        /*!< Perspective lens length, code 42 */
+    double frontClip;         /*!< Front clip plane Z value, code 43 */
+    double backClip;          /*!< Back clip plane Z value, code 44 */
+    double viewHeight;        /*!< View height in model space units, code 45 */
+    double snapAngle;         /*!< Snap angle, code 50 */
+    double twistAngle;        /*!< view twist angle, code 51 */
 
+private:
+    duint32 frozenLyCount;
+};//RLZ: missing 15,25, 72, 331, 90, 340, 1, 281, 71, 74, 110, 120, 130, 111, 121,131, 112,122, 132, 345,346, and more...
+
+//used  //DRW_Coord basePoint;      /*!<  base point, code 10, 20 & 30 */
+
+//double thickness;         /*!< thickness, code 39 */
+//DRW_Coord extPoint;       /*!<  Dir extrusion normal vector, code 210, 220 & 230 */
+//enum DRW::ETYPE eType;     /*!< enum: entity type, code 0 */
+//duint32 handle;            /*!< entity identifier, code 5 */
+//std::list<std::list<DRW_Variant> > appData; /*!< list of application data, code 102 */
+//duint32 parentHandle;      /*!< Soft-pointer ID/handle to owner BLOCK_RECORD object, code 330 */
+//DRW::Space space;          /*!< space indicator, code 67*/
+//UTF8STRING layer;          /*!< layer name, code 8 */
+//UTF8STRING lineType;       /*!< line type, code 6 */
+//duint32 material;          /*!< hard pointer id to material object, code 347 */
+//int color;                 /*!< entity color, code 62 */
+//enum DRW_LW_Conv::lineWidth lWeight; /*!< entity lineweight, code 370 */
+//double ltypeScale;         /*!< linetype scale, code 48 */
+//bool visible;              /*!< entity visibility, code 60 */
+//int numProxyGraph;         /*!< Number of bytes in proxy graphics, code 92 */
+//std::string proxyGraphics; /*!< proxy graphics bytes, code 310 */
+//int color24;               /*!< 24-bit color, code 420 */
+//std::string colorName;     /*!< color name, code 430 */
+//int transparency;          /*!< transparency, code 440 */
+//int plotStyle;             /*!< hard pointer id to plot style object, code 390 */
+//DRW::ShadowMode shadow;    /*!< shadow mode, code 284 */
+//bool haveExtrusion;        /*!< set to true if the entity have extrusion*/
 
 #endif
 
