@@ -24,9 +24,10 @@
 **
 **********************************************************************/
 
-#include "rs_arc.h"
 #include <cmath>
+#include "rs_arc.h"
 
+#include "rs_line.h"
 #include "rs_constructionline.h"
 #include "rs_linetypepattern.h"
 #include "rs_information.h"
@@ -35,12 +36,46 @@
 #include "rs_painter.h"
 #include "lc_quadratic.h"
 #include "rs_painterqt.h"
+#include "rs_debug.h"
 
 
 #ifdef EMU_C99
 #include "emu_c99.h"
 #endif
 
+RS_ArcData::RS_ArcData(const RS_Vector& _center,
+					   double _radius,
+					   double _angle1, double _angle2,
+					   bool _reversed):
+	center(_center)
+  ,radius(_radius)
+  ,angle1(_angle1)
+  ,angle2(_angle2)
+  ,reversed(_reversed)
+{
+}
+
+void RS_ArcData::reset() {
+	center = RS_Vector(false);
+	radius = 0.0;
+	angle1 = 0.0;
+	angle2 = 0.0;
+	reversed = false;
+}
+
+bool RS_ArcData::isValid() const{
+	return (center.valid && radius>RS_TOLERANCE &&
+			fabs(remainder(angle1-angle2, 2.*M_PI))>RS_TOLERANCE_ANGLE);
+}
+
+std::ostream& operator << (std::ostream& os, const RS_ArcData& ad) {
+	os << "(" << ad.center <<
+		  "/" << ad.radius <<
+		  " " << ad.angle1 <<
+		  "," << ad.angle2 <<
+		  ")";
+	return os;
+}
 /**
  * Default constructor.
  */
@@ -51,7 +86,11 @@ RS_Arc::RS_Arc(RS_EntityContainer* parent,
     calculateBorders();
 }
 
-
+RS_Entity* RS_Arc::clone() const {
+	RS_Arc* a = new RS_Arc(*this);
+	a->initId();
+	return a;
+}
 
 /**
  * Creates this arc from 3 given points which define the arc line.
@@ -95,8 +134,7 @@ bool RS_Arc::createFrom2PDirectionRadius(const RS_Vector& startPoint,
         const RS_Vector& endPoint,
         double direction1, double radius) {
 
-    RS_Vector ortho;
-    ortho.setPolar(radius, direction1 + M_PI/2.0);
+	RS_Vector ortho = RS_Vector::polar(radius, direction1 + M_PI_2);
     RS_Vector center1 = startPoint + ortho;
     RS_Vector center2 = startPoint - ortho;
 
@@ -134,8 +172,7 @@ bool RS_Arc::createFrom2PDirectionAngle(const RS_Vector& startPoint,
     if( fabs(remainder( angleLength, M_PI))<RS_TOLERANCE_ANGLE ) return false;
     data.radius=0.5*startPoint.distanceTo(endPoint)/sin(0.5*angleLength);
 
-    RS_Vector ortho;
-    ortho.setPolar(data.radius, direction1 + M_PI/2.0);
+	RS_Vector ortho = RS_Vector::polar(data.radius, direction1 + M_PI_2);
     RS_Vector center1 = startPoint + ortho;
     RS_Vector center2 = startPoint - ortho;
 
@@ -182,9 +219,9 @@ bool RS_Arc::createFrom2PBulge(const RS_Vector& startPoint, const RS_Vector& end
     double angle = startPoint.angleTo(endPoint);
 
     if (bulge>0.0) {
-        angle+=M_PI/2.0;
+		angle+=M_PI_2;
     } else {
-        angle-=M_PI/2.0;
+		angle-=M_PI_2;
     }
 
     if (fabs(alpha)>M_PI) {
@@ -242,11 +279,32 @@ void RS_Arc::calculateBorders() {
 
 
 
-RS_VectorSolutions RS_Arc::getRefPoints() {
-    RS_VectorSolutions ret(startpoint, endpoint, data.center);
-    return ret;
+RS_VectorSolutions RS_Arc::getRefPoints() const
+{
+	//order: start, end, center
+	return {startpoint, endpoint, data.center};
 }
 
+double RS_Arc::getDirection1() const {
+	if (!data.reversed) {
+		return RS_Math::correctAngle(data.angle1+M_PI_2);
+	}
+	else {
+		return RS_Math::correctAngle(data.angle1-M_PI_2);
+	}
+}
+/**
+ * @return Direction 2. The angle at which the arc starts at
+ * the endpoint.
+ */
+double RS_Arc::getDirection2() const {
+	if (!data.reversed) {
+		return RS_Math::correctAngle(data.angle2-M_PI_2);
+	}
+	else {
+		return RS_Math::correctAngle(data.angle2+M_PI_2);
+	}
+}
 
 RS_Vector RS_Arc::getNearestEndpoint(const RS_Vector& coord, double* dist) const{
     double dist1, dist2;
@@ -255,12 +313,12 @@ RS_Vector RS_Arc::getNearestEndpoint(const RS_Vector& coord, double* dist) const
     dist2 = (endpoint-coord).squared();
 
     if (dist2<dist1) {
-        if (dist!=NULL) {
+		if (dist) {
             *dist = sqrt(dist2);
         }
          return endpoint;
     } else {
-        if (dist!=NULL) {
+		if (dist) {
             *dist = sqrt(dist1);
         }
         return startpoint;
@@ -313,10 +371,10 @@ RS_Vector RS_Arc::getTangentDirection(const RS_Vector& point) const {
 }
 
 RS_Vector RS_Arc::getNearestPointOnEntity(const RS_Vector& coord,
-        bool onEntity, double* dist, RS_Entity** entity)const {
+		bool onEntity, double* dist, RS_Entity** entity) const{
 
     RS_Vector vec(false);
-    if (entity!=NULL) {
+	if (entity) {
         *entity = const_cast<RS_Arc*>(this);
     }
 
@@ -326,10 +384,11 @@ RS_Vector RS_Arc::getNearestPointOnEntity(const RS_Vector& coord,
         vec.setPolar(data.radius, angle);
         vec+=data.center;
     } else {
-            vec=getNearestEndpoint(coord, dist);
+            return vec=getNearestEndpoint(coord, dist);
     }
-    if (dist!=NULL) {
-        *dist = fabs((vec-data.center).magnitude()-data.radius);
+	if (dist) {
+        *dist = vec.distanceTo(coord);
+//        RS_DEBUG->print(RS_Debug::D_ERROR, "distance to (%g, %g)=%g\n", coord.x,coord.y,*dist);
     }
 
     return vec;
@@ -338,8 +397,8 @@ RS_Vector RS_Arc::getNearestPointOnEntity(const RS_Vector& coord,
 
 
 RS_Vector RS_Arc::getNearestCenter(const RS_Vector& coord,
-                                   double* dist) {
-    if (dist!=NULL) {
+								   double* dist) const{
+	if (dist) {
         *dist = coord.distanceTo(data.center);
     }
     return data.center;
@@ -364,9 +423,9 @@ RS_Vector RS_Arc::getNearestMiddle(const RS_Vector& coord,
         double amin=getAngle1();
         double amax=getAngle2();
         //std::cout<<"RS_Arc::getNearestMiddle(): middlePoints="<<middlePoints<<std::endl;
-        if( !(/*std::*/isnormal(amin) || /*std::*/isnormal(amax))){
+		if( !(isnormal(amin) || isnormal(amax))){
                 //whole circle, no middle point
-                if(dist != NULL) {
+				if(dist) {
                         *dist=RS_MAXDOUBLE;
                 }
                 return RS_Vector(false);
@@ -388,7 +447,7 @@ RS_Vector RS_Arc::getNearestMiddle(const RS_Vector& coord,
         vp.setPolar(getRadius(), angle);
         vp.move(getCenter());
 
-    if (dist!=NULL) {
+	if (dist) {
         *dist = vp.distanceTo(coord);
     }
     RS_DEBUG->print("RS_Arc::getNearestMiddle(): end\n");
@@ -397,10 +456,10 @@ RS_Vector RS_Arc::getNearestMiddle(const RS_Vector& coord,
 
 RS_Vector RS_Arc::getNearestDist(double distance,
                                  const RS_Vector& coord,
-                                 double* dist) {
+								 double* dist) const{
 
     if (data.radius<RS_TOLERANCE) {
-        if (dist!=NULL) {
+		if (dist) {
             *dist = RS_MAXDOUBLE;
         }
         return RS_Vector(false);
@@ -416,8 +475,7 @@ RS_Vector RS_Arc::getNearestDist(double distance,
     }
 
 
-    RS_Vector ret;
-    ret.setPolar(data.radius, a);
+	RS_Vector ret = RS_Vector::polar(data.radius, a);
     ret += getCenter();
 
     return ret;
@@ -427,14 +485,13 @@ RS_Vector RS_Arc::getNearestDist(double distance,
 
 
 RS_Vector RS_Arc::getNearestDist(double distance,
-                                 bool startp) {
+								 bool startp) const{
 
     if (data.radius<RS_TOLERANCE) {
         return RS_Vector(false);
     }
 
     double a;
-    RS_Vector p;
     double aDist = distance / data.radius;
 
     if (isReversed()) {
@@ -451,7 +508,7 @@ RS_Vector RS_Arc::getNearestDist(double distance,
         }
     }
 
-    p.setPolar(data.radius, a);
+	RS_Vector p = RS_Vector::polar(data.radius, a);
     p += data.center;
 
     return p;
@@ -460,27 +517,26 @@ RS_Vector RS_Arc::getNearestDist(double distance,
 
 RS_Vector RS_Arc::getNearestOrthTan(const RS_Vector& coord,
                     const RS_Line& normal,
-                    bool onEntity )
+					bool onEntity ) const
 {
         if ( !coord.valid ) {
                 return RS_Vector(false);
         }
         double angle=normal.getAngle1();
-        RS_Vector vp;
-        vp.setPolar(getRadius(),angle);
-        QList<RS_Vector> sol;
+		RS_Vector vp = RS_Vector::polar(getRadius(),angle);
+		std::vector<RS_Vector> sol;
         for(int i=0;i <= 1;i++){
                 if(!onEntity ||
                    RS_Math::isAngleBetween(angle,getAngle1(),getAngle2(),isReversed())) {
                 if(i){
-                sol.append(- vp);
+				sol.push_back(- vp);
                 }else {
-                sol.append(vp);
+				sol.push_back(vp);
                 }
         }
                 angle=RS_Math::correctAngle(angle+M_PI);
         }
-        switch(sol.count()) {
+		switch(sol.size()) {
                 case 0:
                         return RS_Vector(false);
                 case 2:
@@ -494,51 +550,11 @@ RS_Vector RS_Arc::getNearestOrthTan(const RS_Vector& coord,
         return getCenter()+vp;
 }
 
-
-double RS_Arc::getDistanceToPoint(const RS_Vector& coord,
-                                  RS_Entity** entity,
-                                  RS2::ResolveLevel,
-                                  double) const {
-    if (entity!=NULL) {
-        *entity = const_cast<RS_Arc*>(this);
-    }
-
-    // check endpoints first:
-    double dist = coord.distanceTo(getStartpoint());
-    if (dist<1.0e-4) {
-        return dist;
-    }
-    dist = coord.distanceTo(getEndpoint());
-    if (dist<1.0e-4) {
-        return dist;
-    }
-
-    if (RS_Math::isAngleBetween(data.center.angleTo(coord),
-                                data.angle1, data.angle2,
-                                isReversed())) {
-
-        // RVT 6 Jan 2011 : Added selection by center point of arc
-        double dToEdge=fabs((coord-data.center).magnitude() - data.radius);
-        double dToCenter=data.center.distanceTo(coord);
-
-        if (dToEdge<dToCenter) {
-            return dToEdge;
-        } else {
-            return dToCenter;
-        }
-
-    } else {
-        return RS_MAXDOUBLE;
-    }
-}
-
-
-
 void RS_Arc::moveStartpoint(const RS_Vector& pos) {
     // polyline arcs: move point not angle:
-    //if (parent!=NULL && parent->rtti()==RS2::EntityPolyline) {
+	//if (parent && parent->rtti()==RS2::EntityPolyline) {
     double bulge = getBulge();
-    if(fabs(bulge - M_PI/2.)<RS_TOLERANCE_ANGLE) return;
+	if(fabs(bulge - M_PI_2)<RS_TOLERANCE_ANGLE) return;
 
     createFrom2PBulge(pos, getEndpoint(), bulge);
     correctAngles(); // make sure angleLength is no more than 2*M_PI
@@ -556,7 +572,7 @@ void RS_Arc::moveStartpoint(const RS_Vector& pos) {
 
 void RS_Arc::moveEndpoint(const RS_Vector& pos) {
     // polyline arcs: move point not angle:
-    //if (parent!=NULL && parent->rtti()==RS2::EntityPolyline) {
+	//if (parent && parent->rtti()==RS2::EntityPolyline) {
     double bulge = getBulge();
     createFrom2PBulge(getStartpoint(), pos, bulge);
     correctAngles(); // make sure angleLength is no more than 2*M_PI
@@ -593,12 +609,12 @@ bool RS_Arc::offset(const RS_Vector& coord, const double& distance) {
     calculateBorders();
     return true;
 }
-QVector<RS_Entity* > RS_Arc::offsetTwoSides(const double& distance) const
+std::vector<RS_Entity* > RS_Arc::offsetTwoSides(const double& distance) const
 {
-    QVector<RS_Entity*> ret(0,NULL);
-    ret<<new RS_Arc(NULL,RS_ArcData(getCenter(),getRadius()+distance,getAngle1(),getAngle2(),isReversed()));
+	std::vector<RS_Entity*> ret(0,nullptr);
+	ret.push_back(new RS_Arc(nullptr,RS_ArcData(getCenter(),getRadius()+distance,getAngle1(),getAngle2(),isReversed())));
     if(getRadius()>distance)
-    ret<<new RS_Arc(NULL,RS_ArcData(getCenter(),getRadius()-distance,getAngle1(),getAngle2(),isReversed()));
+	ret.push_back(new RS_Arc(nullptr,RS_ArcData(getCenter(),getRadius()-distance,getAngle1(),getAngle2(),isReversed())));
     return ret;
 }
 
@@ -639,59 +655,119 @@ void RS_Arc::trimEndpoint(const RS_Vector& pos) {
 
 /**
   *@ trimCoord, mouse point
-  *@  trimPoint, trim to this point
+  *@  trimPoint, trim to this intersection point
   */
 RS2::Ending RS_Arc::getTrimPoint(const RS_Vector& trimCoord,
-                                 const RS_Vector& trimPoint) {
+                                 const RS_Vector& /*trimPoint*/) {
 
     //double angEl = data.center.angleTo(trimPoint);
     double angMouse = data.center.angleTo(trimCoord);
-    double angTrim = data.center.angleTo(trimPoint);
-
-    if( RS_Math::isAngleBetween(angMouse , data.angle1, angTrim, isReversed())) {
-
-        return RS2::EndingEnd;
-    } else {
-
+//    double angTrim = data.center.angleTo(trimPoint);
+    if( fabs(remainder(angMouse-data.angle1, 2.*M_PI))< fabs(remainder(angMouse-data.angle2, 2.*M_PI)))
         return RS2::EndingStart;
-    }
+    else
+        return RS2::EndingEnd;
+
+//    if( RS_Math::isAngleBetween(angMouse , data.angle1, angTrim, isReversed())) {
+
+//        return RS2::EndingEnd;
+//    } else {
+
+//        return RS2::EndingStart;
+//    }
 }
 
-RS_Vector RS_Arc::prepareTrim(const RS_Vector& mousePoint,
+RS_Vector RS_Arc::prepareTrim(const RS_Vector& trimCoord,
                               const RS_VectorSolutions& trimSol) {
-//special trimming for ellipse arc
-    if( ! trimSol.hasValid() ) return (RS_Vector(false));
-    if( trimSol.size() == 1 ) return (trimSol.get(0));
-    double aMin=getAngle1();
-    double aMax=getAngle2();
-    if(isReversed()) qSwap(aMin, aMax);
-    const double angleMouse=getArcAngle(mousePoint);
-    RS_Vector vp=trimSol.at(0);
-    double da=fabs(remainder(getArcAngle(vp) - angleMouse, 2.*M_PI));
-
-    for(size_t i=1; i<trimSol.size(); i++){
-        const double da1=fabs(remainder(getArcAngle(trimSol.at(i)) - angleMouse, 2.*M_PI));
-        if(da1<da){
-            vp=trimSol.at(i);
-            da=da1;
+    //special trimming for ellipse arc
+            RS_DEBUG->print("RS_Ellipse::prepareTrim()");
+        if( ! trimSol.hasValid() ) return (RS_Vector(false));
+        if( trimSol.getNumber() == 1 ) return (trimSol.get(0));
+        double am=getArcAngle(trimCoord);
+		std::vector<double> ias;
+        double ia(0.),ia2(0.);
+        RS_Vector is,is2;
+		for(size_t ii=0; ii<trimSol.getNumber(); ++ii) { //find closest according ellipse angle
+			ias.push_back(getArcAngle(trimSol.get(ii)));
+            if( !ii ||  fabs( remainder( ias[ii] - am, 2*M_PI)) < fabs( remainder( ia -am, 2*M_PI)) ) {
+                ia = ias[ii];
+                is = trimSol.get(ii);
+            }
         }
-    }
-
-    if( da < fabs(remainder(aMin - angleMouse, 2.*M_PI)) && da < fabs(remainder(aMax - angleMouse, 2.*M_PI))) return vp;
-    bool revDirection=( da > fabs(remainder(aMin - angleMouse, 2.*M_PI)))?true:false;
-
-    vp=trimSol.at(0);
-    da=RS_Math::getAngleDifference(angleMouse, getArcAngle(vp), revDirection);
-
-    for(size_t i=1; i<trimSol.size(); i++){
-        const double da1=RS_Math::getAngleDifference(angleMouse, getArcAngle(trimSol.at(i)), revDirection);
-        if(da1<da){
-            vp=trimSol.at(i);
-            da=da1;
+        std::sort(ias.begin(),ias.end());
+		for(size_t ii=0; ii<trimSol.getNumber(); ++ii) { //find segment to enclude trimCoord
+            if ( ! RS_Math::isSameDirection(ia,ias[ii],RS_TOLERANCE)) continue;
+            if( RS_Math::isAngleBetween(am,ias[(ii+trimSol.getNumber()-1)% trimSol.getNumber()],ia,false))  {
+                ia2=ias[(ii+trimSol.getNumber()-1)% trimSol.getNumber()];
+            } else {
+                ia2=ias[(ii+1)% trimSol.getNumber()];
+            }
+            break;
         }
-    }
-    return vp;
+		for(const RS_Vector& vp: trimSol) { //find segment to enclude trimCoord
+			if ( ! RS_Math::isSameDirection(ia2,getArcAngle(vp),RS_TOLERANCE)) continue;
+			is2=vp;
+            break;
+        }
+//        if(RS_Math::isSameDirection(getAngle1(),getAngle2(),RS_TOLERANCE_ANGLE)
+//                ||  RS_Math::isSameDirection(ia2,ia,RS_TOLERANCE) ) {
+//            //whole ellipse
+//            if( !RS_Math::isAngleBetween(am,ia,ia2,isReversed())) {
+//                std::swap(ia,ia2);
+//                std::swap(is,is2);
+//            }
+//            setAngle1(ia);
+//            setAngle2(ia2);
+//            double da1=fabs(remainder(getAngle1()-am,2*M_PI));
+//            double da2=fabs(remainder(getAngle2()-am,2*M_PI));
+//            if(da2<da1) {
+//                std::swap(is,is2);
+//            }
 
+//        } else {
+            double dia=fabs(remainder(ia-am,2*M_PI));
+            double dia2=fabs(remainder(ia2-am,2*M_PI));
+            double ai_min=std::min(dia,dia2);
+            double da1=fabs(remainder(getAngle1()-am,2*M_PI));
+            double da2=fabs(remainder(getAngle2()-am,2*M_PI));
+            double da_min=std::min(da1,da2);
+            if( da_min < ai_min ) {
+                //trimming one end of arc
+                bool irev= RS_Math::isAngleBetween(am,ia2,ia, isReversed()) ;
+                if ( RS_Math::isAngleBetween(ia,getAngle1(),getAngle2(), isReversed()) &&
+                        RS_Math::isAngleBetween(ia2,getAngle1(),getAngle2(), isReversed()) ) { //
+                    if(irev) {
+                        setAngle2(ia);
+                        setAngle1(ia2);
+                    } else {
+                        setAngle1(ia);
+                        setAngle2(ia2);
+                    }
+                    da1=fabs(remainder(getAngle1()-am,2*M_PI));
+                    da2=fabs(remainder(getAngle2()-am,2*M_PI));
+                }
+                if( ((da1 < da2) && (RS_Math::isAngleBetween(ia2,ia,getAngle1(),isReversed()))) ||
+                        ((da1 > da2) && (RS_Math::isAngleBetween(ia2,getAngle2(),ia,isReversed())))
+                  ) {
+                    std::swap(is,is2);
+                    //std::cout<<"reset: angle1="<<getAngle1()<<" angle2="<<getAngle2()<<" am="<< am<<" is="<<getArcAngle(is)<<" ia2="<<ia2<<std::endl;
+                }
+            } else {
+                //choose intersection as new end
+                if( dia > dia2) {
+                    std::swap(is,is2);
+                    std::swap(ia,ia2);
+                }
+                if(RS_Math::isAngleBetween(ia,getAngle1(),getAngle2(),isReversed())) {
+                    if(RS_Math::isAngleBetween(am,getAngle1(),ia,isReversed())) {
+                        setAngle2(ia);
+                    } else {
+                        setAngle1(ia);
+                    }
+                }
+            }
+//        }
+        return is;
 }
 
 
@@ -775,16 +851,31 @@ void RS_Arc::mirror(const RS_Vector& axisPoint1, const RS_Vector& axisPoint2) {
 
 
 
-void RS_Arc::moveRef(const RS_Vector& ref, const RS_Vector& offset) {
-    if(fabs(fabs(getAngleLength()-M_PI)-M_PI)<RS_TOLERANCE_ANGLE){
+void RS_Arc::moveRef(const RS_Vector& ref, const RS_Vector& offset)
+{
+	//avoid moving start/end points for full circle arcs
+	//as start/end points coincident
+	if (fabs(fabs(getAngleLength()-M_PI)-M_PI) < RS_TOLERANCE_ANGLE){
         move(offset);
         return;
-    }
-    if (ref.distanceTo(startpoint)<1.0e-4) {
-        moveStartpoint(startpoint+offset);
-    }else if (ref.distanceTo(endpoint)<1.0e-4) {
-        moveEndpoint(endpoint+offset);
-    }
+	}
+	auto const refs = getRefPoints();
+	double dMin;
+	size_t index;
+	RS_Vector const vp = refs.getClosest(ref, &dMin, &index);
+
+	//reference points must be by the order: start, end, center
+	switch (index) {
+	case 0:
+		moveStartpoint(vp + offset);
+		return;
+	case 1:
+		moveEndpoint(vp + offset);
+		return;
+	default:
+		move(offset);
+	}
+
     correctAngles(); // make sure angleLength is no more than 2*M_PI
 }
 
@@ -815,6 +906,7 @@ void RS_Arc::stretch(const RS_Vector& firstCorner,
 /** find the visible part of the arc, and call drawVisible() to draw */
 void RS_Arc::draw(RS_Painter* painter, RS_GraphicView* view,
                   double& patternOffset) {
+	if (!( painter && view)) return;
 
     //only draw the visible portion of line
     RS_Vector vpMin(view->toGraph(0,view->getHeight()));
@@ -824,25 +916,25 @@ void RS_Arc::draw(RS_Painter* painter, RS_GraphicView* view,
     RS_Vector vpStart(isReversed()?getEndpoint():getStartpoint());
     RS_Vector vpEnd(isReversed()?getStartpoint():getEndpoint());
 
-    QVector<RS_Vector> vertex(0);
+	std::vector<RS_Vector> vertex(0);
     for(unsigned short i=0;i<4;i++){
         const QPointF& vp(visualBox.at(i));
-        vertex<<RS_Vector(vp.x(),vp.y());
+		vertex.push_back(RS_Vector(vp.x(),vp.y()));
     }
     /** angles at cross points */
-    QVector<double> crossPoints(0);
+	std::vector<double> crossPoints(0);
 
     double baseAngle=isReversed()?getAngle2():getAngle1();
     for(unsigned short i=0;i<4;i++){
-        RS_Line line(NULL,RS_LineData(vertex.at(i),vertex.at((i+1)%4)));
-        auto&& vpIts=RS_Information::getIntersection(
+		RS_Line line{vertex.at(i),vertex.at((i+1)%4)};
+		auto vpIts=RS_Information::getIntersection(
                     static_cast<RS_Entity*>(this),
                     &line,
                     true);
         if( vpIts.size()==0) continue;
-        foreach(RS_Vector vp, vpIts.getVector()){
-            auto&& ap1=getTangentDirection(vp).angle();
-            auto&& ap2=line.getTangentDirection(vp).angle();
+		for(const RS_Vector& vp: vpIts){
+			auto ap1=getTangentDirection(vp).angle();
+			auto ap2=line.getTangentDirection(vp).angle();
             //ignore tangent points, because the arc doesn't cross over
             if( fabs( remainder(ap2 - ap1, M_PI) ) < RS_TOLERANCE_ANGLE) continue;
             crossPoints.push_back(
@@ -860,9 +952,9 @@ void RS_Arc::draw(RS_Painter* painter, RS_GraphicView* view,
     arc.setPen(getPen());
     arc.setSelected(isSelected());
     arc.setReversed(false);
-    for(int i=0;i<crossPoints.size()-1;i+=2){
-        arc.setAngle1(baseAngle+crossPoints[i]);
-        arc.setAngle2(baseAngle+crossPoints[i+1]);
+	for(size_t i=1;i<crossPoints.size();i+=2){
+		arc.setAngle1(baseAngle+crossPoints[i-1]);
+		arc.setAngle2(baseAngle+crossPoints[i]);
         arc.drawVisible(painter,view,patternOffset);
     }
 
@@ -872,9 +964,7 @@ void RS_Arc::draw(RS_Painter* painter, RS_GraphicView* view,
 void RS_Arc::drawVisible(RS_Painter* painter, RS_GraphicView* view,
                   double& patternOffset) {
 
-    if (painter==NULL || view==NULL) {
-        return;
-    }
+	if (!( painter && view)) return;
     //visible in grahic view
     if(isVisibleInWindow(view)==false) return;
 
@@ -904,15 +994,15 @@ void RS_Arc::drawVisible(RS_Painter* painter, RS_GraphicView* view,
     //        }
 
     // Pattern:
-    RS_LineTypePattern* pat;
+    const RS_LineTypePattern* pat;
     if (isSelected()) {
-        pat = &patternSelected;
+        pat = &RS_LineTypePattern::patternSelected;
     } else {
         pat = view->getPattern(getPen().getLineType());
     }
 
-    if (pat==NULL|| ra<0.5) {//avoid division by zero from small ra
-        RS_DEBUG->print(RS_Debug::D_WARNING, "Invalid line pattern, drawing arc using solid line");
+	if (!pat || ra<0.5) {//avoid division by zero from small ra
+		RS_DEBUG->print("%s: Invalid line pattern or radius too small, drawing arc using solid line", __func__);
         painter->drawArc(cp, ra,
                          getAngle1(),getAngle2(),
                          isReversed());
@@ -933,10 +1023,10 @@ void RS_Arc::drawVisible(RS_Painter* painter, RS_GraphicView* view,
 
 
     // create scaled pattern:
-    QVector<double> da(0);
+	std::vector<double> da(0);
     double patternSegmentLength(pat->totalLength);
     double ira=1./ra;
-    int i(0);          // index counter
+	size_t i(0);          // index counter
     if(pat->num>0) {
         double dpmm=static_cast<RS_PainterQt*>(painter)->getDpmm();
         da.resize(pat->num);
@@ -1074,6 +1164,22 @@ LC_Quadratic RS_Arc::getQuadratic() const
     return ret;
 }
 
+/**
+ * @brief areaLineIntegral, line integral for contour area calculation by Green's Theorem
+ * Contour Area =\oint x dy
+ * @return line integral \oint x dy along the entity
+ * \oint x dy = c_x r \sin t + \frac{1}{4}r^2\sin 2t +  \frac{1}{2}r^2 t
+ */
+double RS_Arc::areaLineIntegral() const
+{
+    const double& r=data.radius;
+    const double& a0=data.angle1;
+    const double& a1=data.angle2;
+    const double r2=0.25*r*r;
+    const double fStart=data.center.x*r*sin(a0)+r2*sin(a0+a0);
+    const double fEnd=data.center.x*r*sin(a1)+r2*sin(a1+a1);
+    return (isReversed()?fStart-fEnd:fEnd-fStart) + 2.*r2*getAngleLength();
+}
 
 /**
  * Dumps the point's data to stdout.
