@@ -2,6 +2,7 @@
 **
 ** This file is part of the LibreCAD project, a 2D CAD program
 **
+** Copyright (C) 2015 A. Stebich (librecad@mail.lordofbikes.de)
 ** Copyright (C) 2010 R. van Twisk (librecad@rvt.dds.nl)
 ** Copyright (C) 2001-2003 RibbonSoft. All rights reserved.
 **
@@ -25,11 +26,14 @@
 **********************************************************************/
 
 
-#include "rs_entity.h"
-
 #include <iostream>
+#include <utility>
+#include <QPolygon>
+#include <QString>
 
+#include "rs_entity.h"
 #include "rs_arc.h"
+#include "rs_block.h"
 #include "rs_circle.h"
 #include "rs_ellipse.h"
 #include "rs_graphic.h"
@@ -41,9 +45,10 @@
 #include "rs_point.h"
 #include "rs_polyline.h"
 #include "rs_text.h"
+#include "rs_vector.h"
 #include "rs_information.h"
 #include "lc_quadratic.h"
-#include <QPolygon>
+#include "rs_debug.h"
 
 /**
  * Default constructor.
@@ -72,15 +77,6 @@ RS_Entity::RS_Entity(RS_EntityContainer* parent) {
     pen = e.pen;
 }*/
 
-
-
-/**
- * Destructor.
- */
-RS_Entity::~RS_Entity() {}
-
-
-
 /**
  * Initialisation. Called from all constructors.
  */
@@ -88,7 +84,7 @@ void RS_Entity::init() {
     resetBorders();
 
     setFlag(RS2::FlagVisible);
-    //layer = NULL;
+	//layer = nullptr;
     //pen = RS_Pen();
         updateEnabled = true;
     setLayerToActive();
@@ -117,6 +113,15 @@ void RS_Entity::resetBorders() {
 }
 
 
+void RS_Entity::moveBorders(const RS_Vector& offset){
+	minV.move(offset);
+	maxV.move(offset);
+}
+void RS_Entity::scaleBorders(const RS_Vector& center, const RS_Vector& factor){
+	minV.scale(center,factor);
+	maxV.scale(center,factor);
+}
+
 
 /**
  * Selects or deselects this entity.
@@ -164,15 +169,16 @@ bool RS_Entity::isSelected() const {
 /**
  * @return true if a parent entity of this entity is selected.
  */
-bool RS_Entity::isParentSelected() {
-    RS_Entity* p = this;
+bool RS_Entity::isParentSelected() const
+{
+	RS_Entity const* p = this;
 
-    do {
-        p = p->getParent();
-        if (p!=NULL && p->isSelected()==true) {
-            return true;
-        }
-    } while(p!=NULL);
+	while(p) {
+		p = p->getParent();
+		if (p && p->isSelected()==true) {
+			return true;
+		}
+	}
 
     return false;
 }
@@ -219,7 +225,7 @@ void RS_Entity::undoStateChanged(bool /*undone*/) {
  * @return true if this entity or any parent entities are undone.
  */
 bool RS_Entity::isUndone() const {
-        if (parent==NULL) {
+		if (!parent) {
                 return RS_Undoable::isUndone();
         }
         else {
@@ -231,7 +237,8 @@ bool RS_Entity::isUndone() const {
 /**
  * @return True if the entity is in the given range.
  */
-bool RS_Entity::isInWindow(RS_Vector v1, RS_Vector v2) {
+bool RS_Entity::isInWindow(RS_Vector v1, RS_Vector v2) const
+{
     double right, left, top, bottom;
 
     right = std::max(v1.x, v2.x);
@@ -245,6 +252,37 @@ bool RS_Entity::isInWindow(RS_Vector v1, RS_Vector v2) {
             getMax().y<=top);
 }
 
+double RS_Entity::areaLineIntegral() const
+{
+	return 0.;
+}
+
+bool RS_Entity::isArc() const
+{
+	switch (rtti()) {
+	case RS2::EntityArc:
+	case RS2::EntityCircle:
+		//ellipse implements its own test
+	case RS2::EntityEllipse:
+		return true;
+	default:
+		return false;
+	}
+}
+
+ bool RS_Entity::isArcCircleLine() const
+ {
+	 switch (rtti()) {
+	 case RS2::EntityArc:
+	 case RS2::EntityCircle:
+	 case RS2::EntityLine:
+     case RS2::EntityPoint:
+         return true;
+	 default:
+		 return false;
+	 }
+ }
+
 /** whether the entity's bounding box intersects with visible portion of graphic view */
 bool RS_Entity::isVisibleInWindow(RS_GraphicView* view) const
 {
@@ -253,14 +291,14 @@ bool RS_Entity::isVisibleInWindow(RS_GraphicView* view) const
     if( getStartpoint().isInWindowOrdered(vpMin, vpMax) ) return true;
     if( getEndpoint().isInWindowOrdered(vpMin, vpMax) ) return true;
     QPolygonF visualBox(QRectF(vpMin.x,vpMin.y,vpMax.x-vpMin.x, vpMax.y-vpMin.y));
-    QVector<RS_Vector> vps;
+	std::vector<RS_Vector> vps;
     for(unsigned short i=0;i<4;i++){
         const QPointF& vp(visualBox.at(i));
-        vps<<RS_Vector(vp.x(),vp.y());
+		vps.emplace_back(vp.x(),vp.y());
     }
     for(unsigned short i=0;i<4;i++){
-        RS_Line line(NULL,RS_LineData(vps.at(i),vps.at((i+1)%4)));
-        if( RS_Information::getIntersection(const_cast<RS_Entity*>(this), &line, true).size()>0) return true;
+		RS_Line const line{vps.at(i),vps.at((i+1)%4)};
+		if( RS_Information::getIntersection(this, &line, true).size()>0) return true;
     }
     if( minV.isInWindowOrdered(vpMin,vpMax)||maxV.isInWindowOrdered(vpMin,vpMax)) return true;
     return false;
@@ -274,19 +312,37 @@ bool RS_Entity::isVisibleInWindow(RS_GraphicView* view) const
  */
 bool RS_Entity::isPointOnEntity(const RS_Vector& coord,
                                 double tolerance) const {
-    double dist = getDistanceToPoint(coord, NULL, RS2::ResolveNone);
+	double dist = getDistanceToPoint(coord, nullptr, RS2::ResolveNone);
     return (dist<=fabs(tolerance));
 }
 
+double RS_Entity::getDistanceToPoint(const RS_Vector& coord,
+                                  RS_Entity** entity,
+                                  RS2::ResolveLevel /*level*/,
+                                  double /*solidDist*/) const
+{
+	if (entity) {
+        *entity=const_cast<RS_Entity*>(this);
+    }
+    double dToEntity = RS_MAXDOUBLE;
+    (void) getNearestPointOnEntity(coord, true, &dToEntity, entity);
+
+    // RVT 6 Jan 2011 : Add selection by center point
+    if(getCenter().valid){
+        double dToCenter=getCenter().distanceTo(coord);
+        return std::min(dToEntity,dToCenter);
+    }else
+        return dToEntity;
+}
 
 /**
  * Is this entity visible?
  *
  * @return true Only if the entity and the layer it is on are visible.
- * The Layer might also be NULL. In that case the layer visiblity
+ * The Layer might also be nullptr. In that case the layer visiblity
 * is ignored.
  */
-bool RS_Entity::isVisible() {
+bool RS_Entity::isVisible() const{
 
     if (!getFlag(RS2::FlagVisible)) {
         return false;
@@ -297,11 +353,11 @@ bool RS_Entity::isVisible() {
     }
 
         /*RS_EntityCotnainer* parent = getParent();
-        if (parent!=NULL && parent->isUndone()) {
+        if (parent && parent->isUndone()) {
                 return false;
         }*/
 
-    if (getLayer()==NULL) {
+	if (!getLayer()) {
         return true;
     }
 
@@ -316,7 +372,7 @@ bool RS_Entity::isVisible() {
         return true;
     }
 
-    if (layer!=NULL /*&& layer->getName()!="ByBlock"*/) {
+    if (layer /*&& layer->getName()!="ByBlock"*/) {
 
         if (!layer->isFrozen()) {
             return true;
@@ -325,8 +381,8 @@ bool RS_Entity::isVisible() {
         }
     }
 
-    if (layer==NULL /*&& getLayer()->getName()!="ByBlock"*/) {
-        if (getLayer()==NULL) {
+	if (!layer /*&& getLayer()->getName()!="ByBlock"*/) {
+		if (!getLayer()) {
             return true;
         } else {
             if (!getLayer()->isFrozen()) {
@@ -337,31 +393,33 @@ bool RS_Entity::isVisible() {
         }
     }
 
-    if (getBlockOrInsert()==NULL) {
+	if (!getBlockOrInsert()) {
         return true;
     }
 
     if (getBlockOrInsert()->rtti()==RS2::EntityBlock) {
-        if (getLayer(false)==NULL || !getLayer(false)->isFrozen()) {
-            return true;
-        } else {
-            return false;
-        }
+		return !(getLayer(false) && getLayer(false)->isFrozen());
     }
 
 
-    if (getBlockOrInsert()->getLayer()==NULL) {
+	if (!getBlockOrInsert()->getLayer()) {
         return true;
     }
 
-    if(!getBlockOrInsert()->getLayer()->isFrozen()) {
+	if (!getBlockOrInsert()->getLayer()->isFrozen()) {
         return true;
     }
 
     return false;
 }
 
-
+void RS_Entity::setVisible(bool v) {
+	if (v) {
+		setFlag(RS2::FlagVisible);
+	} else {
+		delFlag(RS2::FlagVisible);
+	}
+}
 
 /**
  * Sets the highlight status of the entity. Highlighted entities
@@ -375,59 +433,79 @@ void RS_Entity::setHighlighted(bool on) {
     }
 }
 
+RS_Vector RS_Entity::getStartpoint() const {
+	return {};
+}
 
+RS_Vector RS_Entity::getEndpoint() const {
+	return {};
+}
 
+RS_VectorSolutions RS_Entity::getTangentPoint(const RS_Vector& /*point*/) const {
+	return {};
+}
+
+RS_Vector RS_Entity::getTangentDirection(const RS_Vector& /*point*/)const{
+	return {};
+}
 /**
  * @return true if the entity is highlighted.
  */
-bool RS_Entity::isHighlighted() {
+bool RS_Entity::isHighlighted() const{
     return getFlag(RS2::FlagHighlighted);
 }
 
 
+RS_Vector RS_Entity::getSize() const {
+	return maxV-minV;
+}
 
 /**
  * @return true if the layer this entity is on is locked.
  */
-bool RS_Entity::isLocked() {
-    if (getLayer(true)!=NULL && getLayer()->isLocked()) {
-        return true;
-    } else {
-        return false;
-    }
+bool RS_Entity::isLocked() const
+{
+	return getLayer(true) && getLayer()->isLocked();
 }
 
+RS_Vector RS_Entity::getCenter() const {
+	return RS_Vector{};
+}
+
+double RS_Entity::getRadius() const {
+	return RS_MAXDOUBLE;
+}
 
 /**
  * @return The parent graphic in which this entity is stored
- * or the parent's parent graphic or NULL if none of the parents
+ * or the parent's parent graphic or nullptr if none of the parents
  * are stored in a graphic.
  */
-RS_Graphic* RS_Entity::getGraphic() {
+RS_Graphic* RS_Entity::getGraphic() const{
     if (rtti()==RS2::EntityGraphic) {
-        return (RS_Graphic*)this;
-    } else if (parent==NULL) {
-        return NULL;
-    } else {
-        return parent->getGraphic();
-    }
+		RS_Graphic const* ret=static_cast<RS_Graphic const*>(this);
+		return const_cast<RS_Graphic*>(ret);
+	} else if (!parent) {
+		return nullptr;
+	}
+	return parent->getGraphic();
 }
 
 
 
 /**
  * @return The parent block in which this entity is stored
- * or the parent's parent block or NULL if none of the parents
+ * or the parent's parent block or nullptr if none of the parents
  * are stored in a block.
  */
-RS_Block* RS_Entity::getBlock() {
+RS_Block* RS_Entity::getBlock() const{
     if (rtti()==RS2::EntityBlock) {
-        return (RS_Block*)this;
-    } else if (parent==NULL) {
-        return NULL;
-    } else {
-        return parent->getBlock();
-    }
+		RS_Block const* ret=static_cast<RS_Block const*>(this);
+		return const_cast<RS_Block*>(ret);
+	} else if (!parent) {
+		return nullptr;
+	}
+	return parent->getBlock();
 }
 
 
@@ -442,57 +520,61 @@ m0 x + m1 y + m2 =0
 **/
 LC_Quadratic RS_Entity::getQuadratic() const
 {
-        return LC_Quadratic();
+		return LC_Quadratic{};
 }
 
 /**
  * @return The parent insert in which this entity is stored
- * or the parent's parent block or NULL if none of the parents
+ * or the parent's parent block or nullptr if none of the parents
  * are stored in a block.
  */
-RS_Insert* RS_Entity::getInsert() {
+RS_Insert* RS_Entity::getInsert() const
+{
     if (rtti()==RS2::EntityInsert) {
-        return (RS_Insert*)this;
-    } else if (parent==NULL) {
-        return NULL;
+		RS_Insert const* ret=static_cast<RS_Insert const*>(this);
+		return const_cast<RS_Insert*>(ret);
+	} else if (!parent) {
+		return nullptr;
     } else {
         return parent->getInsert();
     }
 }
 
-
-
 /**
  * @return The parent block or insert in which this entity is stored
- * or the parent's parent block or insert or NULL if none of the parents
+ * or the parent's parent block or insert or nullptr if none of the parents
  * are stored in a block or insert.
  */
-RS_Entity* RS_Entity::getBlockOrInsert() {
-    if (rtti()==RS2::EntityBlock || rtti()==RS2::EntityInsert) {
-        return this;
-    } else if (parent==NULL) {
-        return NULL;
-    } else {
-        return parent->getBlockOrInsert();
-    }
+RS_Entity* RS_Entity::getBlockOrInsert() const
+{
+	RS_Entity* ret{nullptr};
+	switch(rtti()){
+	case RS2::EntityBlock:
+	case RS2::EntityInsert:
+		ret=const_cast<RS_Entity*>(this);
+		break;
+	default:
+		if(parent) {
+			return parent->getBlockOrInsert();
+		}
+	}
+	return ret;
 }
 
-
-
 /**
  * @return The parent document in which this entity is stored
- * or the parent's parent document or NULL if none of the parents
+ * or the parent's parent document or nullptr if none of the parents
  * are stored in a document. Note that a document is usually
  * either a Graphic or a Block.
  */
-RS_Document* RS_Entity::getDocument() {
-    if (isDocument()==true) {
-        return (RS_Document*)this;
-    } else if (parent==NULL) {
-        return NULL;
-    } else {
-        return parent->getDocument();
-    }
+RS_Document* RS_Entity::getDocument() const{
+	if (isDocument()) {
+		RS_Document const* ret=static_cast<RS_Document const*>(this);
+		return const_cast<RS_Document*>(ret);
+	} else if (!parent) {
+		return nullptr;
+	}
+	return parent->getDocument();
 }
 
 
@@ -505,7 +587,7 @@ RS_Document* RS_Entity::getDocument() {
  */
 void RS_Entity::addGraphicVariable(const QString& key, double val, int code) {
     RS_Graphic* graphic = getGraphic();
-    if (graphic!=NULL) {
+    if (graphic) {
         graphic->addVariable(key, val, code);
     }
 }
@@ -520,7 +602,7 @@ void RS_Entity::addGraphicVariable(const QString& key, double val, int code) {
  */
 void RS_Entity::addGraphicVariable(const QString& key, int val, int code) {
     RS_Graphic* graphic = getGraphic();
-    if (graphic!=NULL) {
+    if (graphic) {
         graphic->addVariable(key, val, code);
     }
 }
@@ -536,7 +618,7 @@ void RS_Entity::addGraphicVariable(const QString& key, int val, int code) {
 void RS_Entity::addGraphicVariable(const QString& key,
                                    const QString& val, int code) {
     RS_Graphic* graphic = getGraphic();
-    if (graphic!=NULL) {
+    if (graphic) {
         graphic->addVariable(key, val, code);
     }
 }
@@ -555,7 +637,7 @@ void RS_Entity::addGraphicVariable(const QString& key,
 double RS_Entity::getGraphicVariableDouble(const QString& key, double def) {
     RS_Graphic* graphic = getGraphic();
     double ret=def;
-    if (graphic!=NULL) {
+    if (graphic) {
         ret = graphic->getVariableDouble(key, def);
     }
     return ret;
@@ -572,10 +654,10 @@ double RS_Entity::getGraphicVariableDouble(const QString& key, double def) {
  * @return value of variable or default value if the given variable
  *    doesn't exist.
  */
-int RS_Entity::getGraphicVariableInt(const QString& key, int def) {
+int RS_Entity::getGraphicVariableInt(const QString& key, int def) const{
     RS_Graphic* graphic = getGraphic();
     int ret=def;
-    if (graphic!=NULL) {
+	if (graphic) {
         ret = graphic->getVariableInt(key, def);
     }
     return ret;
@@ -593,10 +675,11 @@ int RS_Entity::getGraphicVariableInt(const QString& key, int def) {
  *    doesn't exist.
  */
 QString RS_Entity::getGraphicVariableString(const QString& key,
-        const QString&  def) {
+		const QString&  def) const
+{
     RS_Graphic* graphic = getGraphic();
     QString ret=def;
-    if (graphic!=NULL) {
+	if (graphic) {
         ret = graphic->getVariableString(key, def);
     }
     return ret;
@@ -608,10 +691,11 @@ QString RS_Entity::getGraphicVariableString(const QString& key,
  * @return The unit the parent graphic works on or None if there's no
  * parent graphic.
  */
-RS2::Unit RS_Entity::getGraphicUnit() {
+RS2::Unit RS_Entity::getGraphicUnit() const
+{
     RS_Graphic* graphic = getGraphic();
     RS2::Unit ret = RS2::None;
-    if (graphic!=NULL) {
+	if (graphic) {
         ret = graphic->getUnit();
     }
     return ret;
@@ -620,31 +704,31 @@ RS2::Unit RS_Entity::getGraphicUnit() {
 
 
 /**
- * Returns a pointer to the layer this entity is on or NULL.
+ * Returns a pointer to the layer this entity is on or nullptr.
  *
  * @para resolve true: if the layer is ByBlock, the layer of the
  *               block this entity is in is returned.
  *               false: the layer of the entity is returned.
  *
  * @return pointer to the layer this entity is on. If the layer
- * is set to NULL the layer of the next parent that is not on
- * layer NULL is returned. If all parents are on layer NULL, NULL
+ * is set to nullptr the layer of the next parent that is not on
+ * layer nullptr is returned. If all parents are on layer nullptr, nullptr
  * is returned.
  */
 RS_Layer* RS_Entity::getLayer(bool resolve) const {
     if (resolve) {
         // we have no layer but a parent that might have one.
         // return parent's layer instead:
-        if (layer==NULL /*|| layer->getName()=="ByBlock"*/) {
-            if (parent!=NULL) {
+		if (!layer /*|| layer->getName()=="ByBlock"*/) {
+            if (parent) {
                 return parent->getLayer(true);
             } else {
-                return NULL;
+				return nullptr;
             }
         }
     }
 
-    // return our layer. might still be NULL:
+	// return our layer. might still be nullptr:
     return layer;
 }
 
@@ -655,10 +739,10 @@ RS_Layer* RS_Entity::getLayer(bool resolve) const {
  */
 void RS_Entity::setLayer(const QString& name) {
     RS_Graphic* graphic = getGraphic();
-    if (graphic!=NULL) {
+    if (graphic) {
         layer = graphic->findLayer(name);
     } else {
-        layer = NULL;
+		layer = nullptr;
     }
 }
 
@@ -676,15 +760,15 @@ void RS_Entity::setLayer(RS_Layer* l) {
 /**
  * Sets the layer of this entity to the current layer of
  * the graphic this entity is in. If this entity (and none
- * of its parents) are in a graphic the layer is set to NULL.
+ * of its parents) are in a graphic the layer is set to nullptr.
  */
 void RS_Entity::setLayerToActive() {
     RS_Graphic* graphic = getGraphic();
 
-    if (graphic!=NULL) {
+    if (graphic) {
         layer = graphic->getActiveLayer();
     } else {
-        layer = NULL;
+		layer = nullptr;
     }
 }
 
@@ -712,19 +796,40 @@ RS_Pen RS_Entity::getPen(bool resolve) const {
 
         // use parental attributes (e.g. vertex of a polyline, block
         // entities when they are drawn in block documents):
-        if (!p.isValid() || p.getColor().isByBlock()) {
-            if (parent!=NULL) {
+        if (parent) {
+            //if pen is invalid gets all from parent
+            if (!p.isValid() ) {
                 p = parent->getPen();
             }
+            //pen is valid, verify byBlock parts
+            RS_EntityContainer* ep = parent;
+            //If parent is byblock check parent.parent (nested blocks)
+            while (p.getColor().isByBlock()){
+                if (ep) {
+                    p.setColor(parent->getPen().getColor());
+                    ep = ep->parent;
+                } else
+                    break;
+            }
+            ep = parent;
+            while (p.getWidth()==RS2::WidthByBlock){
+                if (ep) {
+                    p.setWidth(parent->getPen().getWidth());
+                    ep = ep->parent;
+                } else
+                    break;
+            }
+            ep = parent;
+            while (p.getLineType()==RS2::LineByBlock){
+                if (ep) {
+                    p.setLineType(parent->getPen().getLineType());
+                    ep = ep->parent;
+                } else
+                    break;
+            }
         }
-        // use layer attributes:
-        else if (l!=NULL) {
-
-            // layer is "ByBlock":
-            /*if (layer->getName()=="ByBlock" && getBlockOrInsert()!=NULL) {
-                p = getBlockOrInsert()->getPen();
-        } else {*/
-
+        // check byLayer attributes:
+        if (l) {
             // use layer's color:
             if (p.getColor().isByLayer()) {
                 p.setColor(l->getPen().getColor());
@@ -755,7 +860,7 @@ RS_Pen RS_Entity::getPen(bool resolve) const {
  */
 void RS_Entity::setPenToActive() {
     RS_Document* doc = getDocument();
-    if (doc!=NULL) {
+    if (doc) {
         pen = doc->getActivePen();
     } else {
         //RS_DEBUG->print(RS_Debug::D_WARNING, "RS_Entity::setPenToActive(): "
@@ -794,7 +899,7 @@ void RS_Entity::stretch(const RS_Vector& firstCorner,
 double RS_Entity::getStyleFactor(RS_GraphicView* view) {
     double styleFactor = 1.0;
 
-    if (view!=NULL) {
+    if (view) {
         if (view->isPrinting()==false && view->isDraftMode()) {
             styleFactor = 1.0/view->getFactor().x;
         } else {
@@ -802,7 +907,7 @@ double RS_Entity::getStyleFactor(RS_GraphicView* view) {
             // the factor caused by the unit:
             RS2::Unit unit = RS2::None;
             RS_Graphic* g = getGraphic();
-            if (g!=NULL) {
+            if (g) {
                 unit = g->getUnit();
                 //double scale = g->getPaperScale();
                 styleFactor = RS_Units::convert(1.0, RS2::Millimeter, unit);
@@ -819,7 +924,7 @@ double RS_Entity::getStyleFactor(RS_GraphicView* view) {
 
         if (view->isPrinting() || view->isPrintPreview() || view->isDraftMode()==false) {
             RS_Graphic* graphic = getGraphic();
-            if (graphic!=NULL && graphic->getPaperScale()>1.0e-6) {
+            if (graphic && graphic->getPaperScale()>1.0e-6) {
                 styleFactor /= graphic->getPaperScale();
             }
         }
@@ -837,10 +942,12 @@ double RS_Entity::getStyleFactor(RS_GraphicView* view) {
 
 
 /**
- * @return User defined variable connected to this entity or NULL if not found.
+ * @return User defined variable connected to this entity or nullptr if not found.
  */
 QString RS_Entity::getUserDefVar(const QString& key) const {
-    return varList.value(key, NULL);
+	auto it=varList.find(key);
+	if(it==varList.end()) return nullptr;
+	return varList.at(key);
 }
 /*
  * @coord
@@ -850,7 +957,7 @@ QString RS_Entity::getUserDefVar(const QString& key) const {
  */
 RS_Vector RS_Entity::getNearestOrthTan(const RS_Vector& /*coord*/,
                     const RS_Line& /*normal*/,
-                    bool /*onEntity = false*/){
+					bool /*onEntity = false*/) const{
         return RS_Vector(false);
 }
 
@@ -859,39 +966,81 @@ RS_Vector RS_Entity::getNearestOrthTan(const RS_Vector& /*coord*/,
  * Add a user defined variable to this entity.
  */
 void RS_Entity::setUserDefVar(QString key, QString val) {
-    varList.insert(key, val);
+	varList.insert(std::make_pair(key, val));
 }
 
-
-
 /**
  * Deletes the given user defined variable.
  */
 void RS_Entity::delUserDefVar(QString key) {
-    varList.remove(key);
+	varList.erase(key);
 }
 
-
-
 /**
  * @return A list of all keys connected to this entity.
  */
-QList<QString> RS_Entity::getAllKeys() {
-    return varList.keys();
+std::vector<QString> RS_Entity::getAllKeys() const{
+	std::vector<QString> ret(0);
+	for(auto const& v: varList){
+		ret.push_back(v.first);
+	}
+	return ret;
 }
 
 //! constructionLayer contains entities of infinite length, constructionLayer doesn't show up in print
-bool RS_Entity::isConstructionLayer(bool typeCheck) const  {
-    if(     typeCheck
-        &&  getParent() != NULL
-        &&  RS2::EntityLine != rtti() ){
+bool RS_Entity::isConstruction(bool typeCheck) const{
+	if(typeCheck
+		&&  getParent()
+		&&  rtti() != RS2::EntityLine){
             // do not expand entities on construction layers, except lines
             return false;
     }
-    if(layer != NULL) return layer->isConstructionLayer();
+	if (layer) return layer->isConstruction();
     return false;
 }
 
+//! whether printing is enabled or disabled for the entity's layer
+bool RS_Entity::isPrint(void) const{
+    if (nullptr != layer) return layer->isPrint();
+    return true;
+}
+
+bool RS_Entity::trimmable() const
+{
+    switch(rtti()){
+    case RS2::EntityArc:
+    case RS2::EntityCircle:
+    case RS2::EntityEllipse:
+    case RS2::EntityLine:
+    case RS2::EntitySplinePoints:
+        return true;
+    default:
+        return false;
+    }
+}
+
+RS_VectorSolutions RS_Entity::getRefPoints() const
+{
+	return RS_VectorSolutions();
+}
+
+RS_Vector RS_Entity::getNearestRef(const RS_Vector& coord,
+								   double* dist) const{
+	RS_VectorSolutions const&& s = getRefPoints();
+
+	return s.getClosest(coord, dist);
+}
+
+RS_Vector RS_Entity::getNearestSelectedRef(const RS_Vector& coord,
+										   double* dist) const{
+	if (isSelected()) {
+		return getNearestRef(coord, dist);
+	}
+	else {
+		return RS_Vector(false);
+	}
+}
+
 /**
  * Dumps the elements data to stdout.
  */
@@ -900,7 +1049,7 @@ std::ostream& operator << (std::ostream& os, RS_Entity& e) {
     //return os;
 
     os << " {Entity id: " << e.id;
-    if (e.parent!=NULL) {
+	if (e.parent) {
         os << " | parent id: " << e.parent->getId() << "\n";
     } else {
         os << " | no parent\n";
@@ -911,8 +1060,8 @@ std::ostream& operator << (std::ostream& os, RS_Entity& e) {
     os << (e.getFlag(RS2::FlagSelected) ? " RS2::FlagSelected" : "");
     os << "\n";
 
-    if (e.layer==NULL) {
-        os << " layer: NULL ";
+	if (!e.layer) {
+		os << " layer: nullptr ";
     } else {
         os << " layer: " << e.layer->getName().toLatin1().data() << " ";
         os << " layer address: " << e.layer << " ";
@@ -921,11 +1070,11 @@ std::ostream& operator << (std::ostream& os, RS_Entity& e) {
     os << e.pen << "\n";
 
         os << "variable list:\n";
-    QHash<QString, QString>::const_iterator it = e.varList.constBegin();
-    while (it != e.varList.constEnd() ) {
-        os << it.key().toLatin1().data() << ": " << it.value().toLatin1().data() << ", ";
-        ++it;
-    }
+	for(auto const& v: e.varList){
+		os << v.first.toLatin1().data()<< ": "
+		   << v.second.toLatin1().data()
+			   << ", ";
+	}
 
     // There should be a better way then this...
     switch(e.rtti()) {
