@@ -24,10 +24,11 @@
 **
 **********************************************************************/
 
+#include <iostream>
+#include <cmath>
 
 #include "rs_vector.h"
 
-//#include <values.h>
 
 #include "rs_debug.h"
 #include "rs_math.h"
@@ -37,84 +38,52 @@
 #include "emu_c99.h" /* remainder() */
 #endif
 
-/**
- * Constructor for a point with default coordinates.
- */
-RS_Vector::RS_Vector() {
-    //RS_DEBUG->print("RS_Vector::RS_Vector");
-
-#ifdef  RS_VECTOR2D
-    set(0.0, 0.0);
-#else
-    set(0.0, 0.0, 0.0);
-#endif
-}
-
-
-
 /**
  * Constructor for a point with given coordinates.
  */
 #ifdef  RS_VECTOR2D
-RS_Vector::RS_Vector(double vx, double vy) {
-    //RS_DEBUG->print("RS_Vector::RS_Vector");
-    set(vx, vy);
+RS_Vector::RS_Vector(double vx, double vy):
+	x(vx)
+  ,y(vy)
+  ,valid(true)
+{
 }
 #else
-RS_Vector::RS_Vector(double vx, double vy, double vz) {
-    //RS_DEBUG->print("RS_Vector::RS_Vector");
-    set(vx, vy, vz);
+RS_Vector::RS_Vector(double vx, double vy, double vz):
+	x(vx)
+  ,y(vy)
+  ,z(vz)
+  ,valid(true)
+{
 }
 #endif
 
 /**
  * Constructor for a unit vector with given angle
  */
-RS_Vector::RS_Vector(double angle) {
-    //RS_DEBUG->print("RS_Vector::RS_Vector");
-    x = cos(angle);
-    y = sin(angle);
-#ifndef RS_VECTOR2D
-    z = 0.0;
-#endif
-    valid = true;
+RS_Vector::RS_Vector(double angle):
+	x(cos(angle))
+  ,y(sin(angle))
+  ,valid(true)
+{
 }
 
-
-/**
- * Constructor for a point with given coordinates in an array
- * or three doubles.
- */
-//RS_Vector::RS_Vector(double v[]) {
-//    set(v[0], v[1], v[2]);
-//}
-
-
 /**
  * Constructor for a point with given valid flag.
  *
  * @param valid true: a valid vector with default coordinates is created.
  *              false: an invalid vector is created
  */
-RS_Vector::RS_Vector(bool valid) {
-    //RS_DEBUG->print("RS_Vector::RS_Vector");
-#ifdef  RS_VECTOR2D
-    set(0.0, 0.0);
-#else
-    set(0.0, 0.0, 0.0);
-#endif
-    this->valid = valid;
+RS_Vector::RS_Vector(bool valid):
+	valid(valid)
+{
 }
 
-
-/**
- * Destructor.
- */
-RS_Vector::~RS_Vector() {
-    //RS_DEBUG->print("RS_Vector::~RS_Vector");
+RS_Vector::operator bool() const
+{
+	return valid;
 }
 
-
 /**
  * Sets to a unit vector by the direction angle
  */
@@ -127,7 +96,6 @@ void RS_Vector::set(double angle) {
     valid = true;
 }
 
-
 /**
  * Sets a new position for the vector.
  */
@@ -144,7 +112,6 @@ void RS_Vector::set(double vx, double vy, double vz) {
     valid = true;
 }
 
-
 /**
  * Sets a new position for the vector in polar coordinates.
  */
@@ -157,49 +124,27 @@ void RS_Vector::setPolar(double radius, double angle) {
     valid = true;
 }
 
-
+RS_Vector RS_Vector::polar(double rho, double theta){
+	return RS_Vector(rho*cos(theta), rho*sin(theta)
+				 #ifndef RS_VECTOR2D
+					 , 0.
+				 #endif
+					 );
+}
 
 /**
  * @return The angle from zero to this vector (in rad).
  */
 double RS_Vector::angle() const {
-    return RS_Math::correctAngle(atan2(y,x));
-//    double ret = 0.0;
-//    double m = magnitude();
-//
-//    if (m>1.0e-6) {
-//		double dp = dotP(*this, RS_Vector(1.0, 0.0));
-//		RS_DEBUG->print("RS_Vector::angle: dp/m: %f/%f", dp, m);
-//		if (dp/m>=1.0) {
-//			ret = 0.0;
-//		}
-//		else if (dp/m<-1.0) {
-//			ret = M_PI;
-//		}
-//		else {
-//        	ret = acos( dp / m);
-//		}
-//        if (y<0.0) {
-//            ret = 2*M_PI - ret;
-//        }
-//    }
-//    //std::cout<<"New angle="<<fmod(2*M_PI+atan2(y,x),2*M_PI)<<"\tatan2("<<y<<','<<x<<")"<<atan2(y,x)<<std::endl;
-//
-//    return ret;
+	return RS_Math::correctAngle(atan2(y,x));
 }
 
-
-
 /**
  * @return The angle from this and the given coordinate (in rad).
  */
 double RS_Vector::angleTo(const RS_Vector& v) const {
-    if (!valid || !v.valid) {
-        return 0.0;
-    }
-    else {
-        return (v-(*this)).angle();
-    }
+	if (!valid || !v.valid) return 0.0;
+	return (v-(*this)).angle();
 }
 
 /**
@@ -207,22 +152,12 @@ double RS_Vector::angleTo(const RS_Vector& v) const {
  * return 0, if the angle is not well defined
  */
 double RS_Vector::angleBetween(const RS_Vector& v1, const RS_Vector& v2) const {
-    if (!valid || !v1.valid || !v2.valid) {
-        return 0.0;
-    }
-    else {
-        RS_Vector vStart(v1- (*this));
-        RS_Vector vEnd(v2- (*this));
-        //        if( vStart.magnitude() < RS_TOLERANCE
-        //                || vEnd.magnitude() < RS_TOLERANCE) return 0.0;
-        return RS_Math::correctAngle( atan2( vStart.x*vEnd.y-vStart.y*vEnd.x, vStart.x*vEnd.x+vStart.y*vEnd.y));
-
-        //         std::cout<<"old algorithm:: "<<RS_Math::correctAngle(vEnd.angle() - vStart.angle())<<std::endl;
-//        return RS_Math::correctAngle(vEnd.angle() - vStart.angle());
-    }
+	if (!valid || !v1.valid || !v2.valid) return 0.0;
+	RS_Vector const vStart(v1- (*this));
+	RS_Vector const vEnd(v2- (*this));
+	return RS_Math::correctAngle( atan2( vStart.x*vEnd.y-vStart.y*vEnd.x, vStart.x*vEnd.x+vStart.y*vEnd.y));
 }
 
-
 /**
  * @return Magnitude (length) of the vector.
  */
@@ -275,7 +210,6 @@ RS_Vector RS_Vector::lerp(const RS_Vector& v, double t) const {
     return RS_Vector(x+(v.x-x)*t, y+(v.y-y)*t);
 }
 
-
 /**
  * @return The distance between this and the given coordinate.
  */
@@ -288,18 +222,16 @@ double RS_Vector::distanceTo(const RS_Vector& v) const {
     }
 }
 
-
-
 /**
  * @return true is this vector is within the given range.
  */
 bool RS_Vector::isInWindow(const RS_Vector& firstCorner,
-                           const RS_Vector& secondCorner) const {
-    RS_Vector vLow( std::min(firstCorner.x, secondCorner.x), std::min(firstCorner.y, secondCorner.y));
-    RS_Vector vHigh( std::max(firstCorner.x, secondCorner.x), std::max(firstCorner.y, secondCorner.y));
+						   const RS_Vector& secondCorner) const {
+	RS_Vector vLow( std::min(firstCorner.x, secondCorner.x), std::min(firstCorner.y, secondCorner.y));
+	RS_Vector vHigh( std::max(firstCorner.x, secondCorner.x), std::max(firstCorner.y, secondCorner.y));
 
-if(valid==false) return false;
-    return isInWindowOrdered(vLow,vHigh);
+	if(!valid) return false;
+	return isInWindowOrdered(vLow,vHigh);
 }
 
 /**
@@ -307,17 +239,17 @@ if(valid==false) return false;
  * of ordered vectors
  */
 bool RS_Vector::isInWindowOrdered(const RS_Vector& vLow,
-                           const RS_Vector& vHigh) const {
-if(valid==false) return false;
-    return (x>=vLow.x && x<=vHigh.x && y>=vLow.y && y<=vHigh.y);
+								  const RS_Vector& vHigh) const {
+	if(!valid) return false;
+	return (x>=vLow.x && x<=vHigh.x && y>=vLow.y && y<=vHigh.y);
 }
 
 /**
  * move to the closest integer point
  */
 RS_Vector RS_Vector::toInteger() {
-    x= x - remainder(x,1.);
-    y= y - remainder(y,1.);
+	x = rint(x);
+	y = rint(y);
     return *this;
 }
 
@@ -329,27 +261,10 @@ RS_Vector RS_Vector::move(const RS_Vector& offset) {
     return *this;
 }
 
-
-
 /**
  * Rotates this vector around 0/0 by the given angle.
  */
 RS_Vector RS_Vector::rotate(const double& ang) {
-//    RS_DEBUG->print("RS_Vector::rotate: angle: %f", ang);
-
-//    double r = magnitude();
-
-//    RS_DEBUG->print("RS_Vector::rotate: r: %f", r);
-
-//    double a = angle() + ang;
-
-//    RS_DEBUG->print("RS_Vector::rotate: a: %f", a);
-
-    //    x = cos(a) * r;
-    //    y = sin(a) * r;
-
-    //    RS_DEBUG->print("RS_Vector::rotate: x/y: %f/%f", x, y);
-    // rotate by direction vector
     rotate(RS_Vector(ang));
     return *this;
 }
@@ -360,18 +275,13 @@ RS_Vector RS_Vector::rotate(const double& ang) {
  * 0/0 by the angle of the vector
  */
 RS_Vector RS_Vector::rotate(const RS_Vector& angleVector) {
-//        RS_DEBUG->print("RS_Vector::rotate: rotating Vecotr: %g/%g", x,y);
-//        RS_DEBUG->print("RS_Vector::rotate: rotating by Vecotr: %g/%g", angleVector.x,angleVector.y);
-        double x0 = x * angleVector.x - y * angleVector.y;
-        y = x * angleVector.y + y * angleVector.x;
-        x = x0;
+	double x0 = x * angleVector.x - y * angleVector.y;
+	y = x * angleVector.y + y * angleVector.x;
+	x = x0;
 
-//        RS_DEBUG->print("RS_Vector::rotate: rotated x/y: %f/%f", x, y);
-
-    return *this;
+	return *this;
 }
 
-
 /**
  * Rotates this vector around the given center by the given angle.
  */
@@ -402,6 +312,10 @@ RS_Vector RS_Vector::scale(const RS_Vector& factor) {
     return *this;
 }
 
+RS_Vector RS_Vector::scale(const RS_Vector& factor) const{
+	return RS_Vector(x*factor.x, y*factor.y);
+}
+
 /**
  * Scales this vector by the given factors with the given center.
  */
@@ -416,14 +330,7 @@ RS_Vector RS_Vector::scale(const RS_Vector& center, const RS_Vector& factor) {
  * Mirrors this vector at the given axis, defined by two points on axis.
  */
 RS_Vector RS_Vector::mirror(const RS_Vector& axisPoint1, const RS_Vector& axisPoint2) {
-    /*
-    RS_ConstructionLine axis(NULL,
-        RS_ConstructionLineData(axisPoint1, axisPoint2));
 
-    RS_Vector xp = axis.getNearestPointOnEntity(*this);
-    xp = xp - (*this);
-    (*this) += (xp*2);
-    */
     RS_Vector direction(axisPoint2-axisPoint1);
     double a= direction.squared();
     RS_Vector ret(false);
@@ -436,8 +343,6 @@ RS_Vector RS_Vector::mirror(const RS_Vector& axisPoint1, const RS_Vector& axisPo
     return *this;
 }
 
-
-
 /**
  * Streams the vector components to stdout. e.g.: "1/4/0"
  */
@@ -480,6 +385,44 @@ RS_Vector RS_Vector::operator - (const RS_Vector& v) const {
 #endif
 }
 
+RS_Vector RS_Vector::operator + (double d) const {
+#ifdef  RS_VECTOR2D
+	return RS_Vector(x + d, y + d);
+#else
+	return RS_Vector(x + d, y + d, z + d);
+#endif
+}
+
+RS_Vector RS_Vector::operator - (double d) const {
+#ifdef  RS_VECTOR2D
+	return RS_Vector(x - d, y - d);
+#else
+	return RS_Vector(x - d, y - d, z - d);
+#endif
+}
+
+RS_Vector RS_Vector::operator * (const RS_Vector& v) const {
+#ifdef  RS_VECTOR2D
+	return RS_Vector(x * v.x, y * v.y);
+#else
+	return RS_Vector(x * v.x, y * v.y, z * v.z);
+#endif
+}
+
+RS_Vector RS_Vector::operator / (const RS_Vector& v) const {
+	if(fabs(v.x)> RS_TOLERANCE && fabs(v.y)>RS_TOLERANCE
+#ifndef  RS_VECTOR2D
+			&& fabs(v.z)
+#endif
+			){
+#ifdef  RS_VECTOR2D
+	return RS_Vector(x / v.x, y / v.y);
+#else
+	return RS_Vector(x / v.x, y / v.y, z / v.z);
+#endif
+	}
+	return *this;
+}
 
 /**
  * binary * operator.
@@ -492,21 +435,20 @@ RS_Vector RS_Vector::operator * (const double& s) const {
 #endif
 }
 
-
-
 /**
  * binary / operator.
  */
 RS_Vector RS_Vector::operator / (const double& s) const {
+	if(fabs(s)> RS_TOLERANCE){
 #ifdef  RS_VECTOR2D
-    return RS_Vector(x / s, y / s);
+		return RS_Vector(x / s, y / s);
 #else
-    return RS_Vector(x / s, y / s, z / s);
+		return RS_Vector(x / s, y / s, z / s);
 #endif
+	}
+	return *this;
 }
 
-
-
 /**
  * unary - operator.
  */
@@ -518,12 +460,10 @@ RS_Vector RS_Vector::operator - () const {
 #endif
 }
 
-
-
 /**
  * Scalarproduct (dot product).
  */
-double RS_Vector::dotP(const RS_Vector& v1)
+double RS_Vector::dotP(const RS_Vector& v1) const
 {
     return x*v1.x+y*v1.y;
 }
@@ -536,7 +476,6 @@ double RS_Vector::dotP(const RS_Vector& v1, const RS_Vector& v2) {
 #endif
 }
 
-
 /** switch x,y for all vectors */
 RS_Vector RS_Vector::flipXY(void) const{
         return RS_Vector(y,x);
@@ -545,42 +484,66 @@ RS_Vector RS_Vector::flipXY(void) const{
 /**
  * += operator. Assert: both vectors must be valid.
  */
-void RS_Vector::operator += (const RS_Vector& v) {
+RS_Vector RS_Vector::operator += (const RS_Vector& v) {
     x += v.x;
     y += v.y;
 #ifndef RS_VECTOR2D
     z += v.z;
 #endif
+	return *this;
 }
 
-
 /**
  * -= operator
  */
-void RS_Vector::operator -= (const RS_Vector& v) {
+RS_Vector RS_Vector::operator -= (const RS_Vector& v) {
     x -= v.x;
     y -= v.y;
 #ifndef RS_VECTOR2D
     z -= v.z;
 #endif
+	return *this;
 }
 
+RS_Vector RS_Vector::operator *= (const RS_Vector& v) {
+	x *= v.x;
+	y *= v.y;
+#ifndef RS_VECTOR2D
+	z *= v.z;
+#endif
+	return *this;
+}
 
+RS_Vector RS_Vector::operator /= (const RS_Vector& v) {
+	if(fabs(v.x)> RS_TOLERANCE && fabs(v.y)>RS_TOLERANCE
+#ifndef  RS_VECTOR2D
+			&& fabs(v.z)
+#endif
+			){
+		x /= v.x;
+		y /= v.y;
+#ifndef RS_VECTOR2D
+		z /= v.z;
+#endif
+	}
+	return *this;
+}
 
 /**
  * *= operator
  */
-void RS_Vector::operator *= (const double& s) {
+RS_Vector RS_Vector::operator *= (const double& s) {
     x *= s;
     y *= s;
 #ifndef RS_VECTOR2D
     z *= s;
 #endif
+	return *this;
 }
 /**
  * /= operator
  */
-void RS_Vector::operator /= (const double& s) {
+RS_Vector RS_Vector::operator /= (const double& s) {
     if(fabs(s)>RS_TOLERANCE) {
     x /= s;
     y /= s;
@@ -588,10 +551,9 @@ void RS_Vector::operator /= (const double& s) {
     z /= s;
 #endif
     }
+	return *this;
 }
 
-
-
 /**
  * == operator
  */
@@ -603,7 +565,15 @@ bool RS_Vector::operator == (const RS_Vector& v) const {
 #endif
 }
 
+bool RS_Vector::operator == (bool valid) const
+{
+	return this->valid == valid;
+}
 
+bool RS_Vector::operator != (bool valid) const
+{
+	return this->valid != valid;
+}
 
 /**
  * @return A vector with the minimum components from the vectors v1 and v2.
@@ -618,8 +588,6 @@ RS_Vector RS_Vector::minimum (const RS_Vector& v1, const RS_Vector& v2) {
                       );
 }
 
-
-
 /**
  * @return A vector with the maximum values from the vectors v1 and v2
  */
@@ -632,8 +600,6 @@ RS_Vector RS_Vector::maximum (const RS_Vector& v1, const RS_Vector& v2) {
                       );
 }
 
-
-
 /**
  * @return Cross product of two vectors.
  *  we don't need cross product for 2D vectors
@@ -646,138 +612,75 @@ RS_Vector RS_Vector::crossP(const RS_Vector& v1, const RS_Vector& v2) {
 }
 #endif
 
-
 /**
  * Constructor for no solution.
  */
-RS_VectorSolutions::RS_VectorSolutions() {
-    vector.clear();
-    tangent=false;
+RS_VectorSolutions::RS_VectorSolutions():
+	vector(0)
+  ,tangent(false)
+{
 }
 
-
-
-/**
- * Copy constructor
- */
-RS_VectorSolutions::RS_VectorSolutions(const RS_VectorSolutions& s)
-    {
-    setTangent(s.isTangent());
-    vector=s.vector;
+RS_VectorSolutions::RS_VectorSolutions(const std::vector<RS_Vector>& l):
+	vector( l.begin(), l.end())
+  ,tangent(false)
+{
 }
 
-
-
 /**
  * Constructor for num solutions.
  */
-RS_VectorSolutions::RS_VectorSolutions(int num) {
-#if QT_VERSION >= 0x040700
-    vector.reserve(num);
-#else
-        for(int i=vector.size();i<num;i++){
-            vector.push_back(RS_Vector(false));
-        }
-#endif
+RS_VectorSolutions::RS_VectorSolutions(int num):
+	vector(num, RS_Vector(false))
+  ,tangent(false)
+{
 }
 
-
-
-/**
- * Constructor for one solution.
- */
-RS_VectorSolutions::RS_VectorSolutions(const RS_Vector& v1) {
-    vector.push_back(v1);
-    tangent = false;
+RS_VectorSolutions::RS_VectorSolutions(std::initializer_list<RS_Vector> const& l):
+	vector(l)
+  ,tangent(false)
+{
 }
 
-
-
-/**
- * Constructor for two solutions.
- */
-RS_VectorSolutions::RS_VectorSolutions(const RS_Vector& v1,
-                                       const RS_Vector& v2) {
-    vector.push_back(v1);
-    vector.push_back(v2);
-    tangent = false;
-}
-
-
-
-/**
- * Constructor for three solutions.
- */
-RS_VectorSolutions::RS_VectorSolutions(const RS_Vector& v1,
-                                       const RS_Vector& v2,
-                                       const RS_Vector& v3) {
-    vector.push_back(v1);
-    vector.push_back(v2);
-    vector.push_back(v3);
-    tangent = false;
-}
-
-
-/**
- * Constructor for four solutions.
- */
-RS_VectorSolutions::RS_VectorSolutions(const RS_Vector& v1,
-                                       const RS_Vector& v2,
-                                       const RS_Vector& v3,
-                                       const RS_Vector& v4) {
-    vector.push_back(v1);
-    vector.push_back(v2);
-    vector.push_back(v3);
-    vector.push_back(v4);
-    tangent = false;
-}
-
-
-/**
- * Constructor for four solutions.
- */
-RS_VectorSolutions::RS_VectorSolutions(const RS_Vector& v1,
-                                       const RS_Vector& v2,
-                                       const RS_Vector& v3,
-                                       const RS_Vector& v4,
-                                       const RS_Vector& v5) {
-    vector.push_back(v1);
-    vector.push_back(v2);
-    vector.push_back(v3);
-    vector.push_back(v4);
-    vector.push_back(v5);
-    tangent = false;
-}
-
-
-
-/**
- * Destructor.
- */
-RS_VectorSolutions::~RS_VectorSolutions() {
-    vector.clear();
-}
-
-
 /**
  * Allocates 'num' vectors.
  */
-void RS_VectorSolutions::alloc(int num) {
-#if QT_VERSION >= 0x040700
-    vector.reserve(num);
-#else
-    if(vector.size() <num) {
-        for(int i=vector.size();i<num;i++){
-            vector.push_back(RS_Vector(false));
-        }
-    }
-#endif
-    if(vector.size()>num) {
-        vector.erase(vector.begin()+num, vector.end());
-    }
-   // tangent = false;
+void RS_VectorSolutions::alloc(size_t num) {
+	if(num<=vector.size()){
+		vector.resize(num);
+	}else{
+		const std::vector<RS_Vector> v(num - vector.size(), RS_Vector(false));
+		vector.insert(vector.end(), v.begin(), v.end());
+	}
 }
 
+void RS_VectorSolutions::clean()
+{
+	vector.clear();
+	tangent = false;
+}
+
+RS_Vector RS_VectorSolutions::get(size_t i) const
+{
+	if(i<vector.size())
+		return vector.at(i);
+	return RS_Vector(false);
+}
+
+const RS_Vector&  RS_VectorSolutions::operator [] (const size_t i) const
+{
+	return vector[i];
+}
+
+RS_Vector&  RS_VectorSolutions::operator [] (const size_t i)
+{
+	return vector[i];
+}
+
+size_t RS_VectorSolutions::size() const
+{
+	return vector.size();
+}
 /**
  * Deletes vector array and resets everything.
  */
@@ -786,41 +689,28 @@ void RS_VectorSolutions::clear() {
     tangent = false;
 }
 
-
-
 /**
  * @return vector solution number i or an invalid vector if there
  * are less solutions.
  */
-RS_Vector RS_VectorSolutions::at(int i) const {
-    if (i<vector.size()) {
-        return vector[i];
-    } else {
-        return RS_Vector(false);
-    }
+const RS_Vector& RS_VectorSolutions::at(size_t i) const {
+		return vector.at(i);
 }
 
-
-
 /**
  * @return Number of solutions available.
  */
-int RS_VectorSolutions::getNumber() const {
+size_t RS_VectorSolutions::getNumber() const {
     return vector.size();
 }
 
-
-
 /**
  * @retval true There's at least one valid solution.
  * @retval false There's no valid solution.
  */
 bool RS_VectorSolutions::hasValid() const {
-    for (int i=0; i<vector.size(); i++) {
-        if (vector[i].valid) {
-            return true;
-        }
-    }
+	for(const RS_Vector& v: vector)
+		if (v.valid)  return true;
 
     return false;
 }
@@ -829,21 +719,41 @@ void RS_VectorSolutions::resize(size_t n){
     vector.resize(n);
 }
 
-QVector<RS_Vector> RS_VectorSolutions::getVector() const {
+const std::vector<RS_Vector>& RS_VectorSolutions::getVector() const {
     return vector;
 }
 
+std::vector<RS_Vector>::const_iterator RS_VectorSolutions::begin() const
+{
+	return vector.begin();
+}
+
+std::vector<RS_Vector>::const_iterator RS_VectorSolutions::end() const
+{
+	return vector.end();
+}
+
+std::vector<RS_Vector>::iterator RS_VectorSolutions::begin()
+{
+	return vector.begin();
+}
+
+std::vector<RS_Vector>::iterator RS_VectorSolutions::end()
+{
+	return vector.end();
+}
+
 void RS_VectorSolutions::push_back(const RS_Vector& v) {
         vector.push_back(v);
 }
 
-void RS_VectorSolutions::removeAt(const int i){
-    if (vector.size()> i)
-        vector.remove(i);
+void RS_VectorSolutions::removeAt(const size_t i){
+	if (vector.size()> i)
+		vector.erase(vector.begin()+i);
 }
 
 RS_VectorSolutions RS_VectorSolutions::appendTo(const RS_VectorSolutions& v) {
-    vector += v.getVector();
+	vector.insert(vector.end(), v.begin(), v.end());
     return *this;
 }
 
@@ -852,18 +762,16 @@ RS_VectorSolutions RS_VectorSolutions::appendTo(const RS_VectorSolutions& v) {
  * If i is greater than the current number of solutions available,
  * nothing happens.
  */
-void RS_VectorSolutions::set(int i, const RS_Vector& v) {
+void RS_VectorSolutions::set(size_t i, const RS_Vector& v) {
     if (i<vector.size()) {
         vector[i] = v;
     }else{
 //            RS_DEBUG->print(RS_Debug::D_ERROR, "set member in vector in RS_VectorSolutions: out of range, %d to size of %d", i,vector.size());
-        for(int j=vector.size();j<=i;j++)
+		for(size_t j=vector.size();j<=i;++j)
             vector.push_back(v);
     }
 }
 
-
-
 /**
  * Sets the tangent flag.
  */
@@ -871,8 +779,6 @@ void RS_VectorSolutions::setTangent(bool t) {
     tangent = t;
 }
 
-
-
 /**
  * @return true if at least one of the solutions is a double solution
  * (tangent).
@@ -881,92 +787,92 @@ bool RS_VectorSolutions::isTangent() const {
     return tangent;
 }
 
-
 /**
  * Rotates all vectors around (0,0) by the given angle.
  */
 void RS_VectorSolutions::rotate(const double& ang) {
     RS_Vector angleVector(ang);
-    for (int i=0; i<vector.size(); i++) {
-        if (vector[i].valid) {
-            vector[i].rotate(angleVector);
-        }
-    }
+	for (RS_Vector& vp: vector) {
+		if (vp.valid) {
+			vp.rotate(angleVector);
+		}
+	}
 }
 
 /**
  * Rotates all vectors around (0,0) by the given angleVector.
  */
 void RS_VectorSolutions::rotate(const RS_Vector& angleVector) {
-    for (int i=0; i<vector.size(); i++) {
-        if (vector[i].valid) {
-                //To be a real rotation, the determinant of angleVector has to be 1 for a pure rotation
-            vector[i].rotate(angleVector);
-        }
-    }
+	for (RS_Vector& vp: vector) {
+		if (vp.valid) {
+			vp.rotate(angleVector);
+		}
+	}
 }
 
 /**
  * Rotates all vectors around the given center by the given angle.
  */
 void RS_VectorSolutions::rotate(const RS_Vector& center, const double& ang) {
-    RS_Vector angleVector(ang);
-    for (int i=0; i<vector.size(); i++) {
-        if (vector[i].valid) {
-            vector[i].rotate(center,angleVector);
-        }
-    }
+	const RS_Vector angleVector(ang);
+	for (RS_Vector& vp: vector) {
+		if (vp.valid) {
+			vp.rotate(center,angleVector);
+		}
+	}
 }
+
 void RS_VectorSolutions::rotate(const RS_Vector& center, const RS_Vector& angleVector) {
-    for (int i=0; i<vector.size(); i++) {
-        if (vector[i].valid) {
-            vector[i].rotate(center,angleVector);
-        }
-    }
+	for (RS_Vector& vp: vector) {
+		if (vp.valid) {
+			vp.rotate(center,angleVector);
+		}
+	}
 }
 
 /**
  * Move all vectors around the given center by the given vector.
  */
 void RS_VectorSolutions::move(const RS_Vector& vp) {
-    for (int i=0; i<vector.size(); i++) {
-        if (vector[i].valid) vector[i].move(vp);
-    }
+	for (RS_Vector& v: vector) {
+		if (v.valid) {
+			v.move(vp);
+		}
+	}
 }
 
-
 /**
  * Scales all vectors by the given factors with the given center.
  */
 void RS_VectorSolutions::scale(const RS_Vector& center, const RS_Vector& factor) {
-    for (int i=0; i<vector.size(); i++) {
-        if (vector[i].valid) {
-            vector[i].scale(center, factor);
-        }
-    }
-}
-void RS_VectorSolutions::scale( const RS_Vector& factor) {
-    for (int i=0; i<vector.size(); i++) {
-        if (vector[i].valid) {
-            vector[i].scale(factor);
-        }
-    }
+	for (RS_Vector& vp: vector) {
+		if (vp.valid) {
+			vp.scale(center, factor);
+		}
+	}
 }
 
+void RS_VectorSolutions::scale( const RS_Vector& factor) {
+	for (RS_Vector& vp: vector) {
+		if (vp.valid) {
+			vp.scale(factor);
+        }
+    }
+}
 
 /**
  * @return vector solution which is the closest to the given coordinate.
  * dist will contain the distance if it doesn't point to NULL (default).
  */
 RS_Vector RS_VectorSolutions::getClosest(const RS_Vector& coord,
-                                         double* dist, int* index) const {
+										 double* dist, size_t* index) const {
 
     double curDist(0.);
     double minDist = RS_MAXDOUBLE;
     RS_Vector closestPoint(false);
     int pos(0);
 
-    for (int i=0; i<vector.size(); i++) {
+	for (size_t i=0; i<vector.size(); i++) {
         if (vector[i].valid) {
             curDist = (coord - vector[i]).squared();
 
@@ -977,14 +883,15 @@ RS_Vector RS_VectorSolutions::getClosest(const RS_Vector& coord,
             }
         }
     }
-    if (dist!=NULL) {
+	if (dist) {
         *dist = sqrt(minDist);
     }
-    if (index!=NULL) {
+	if (index) {
         *index = pos;
     }
     return closestPoint;
 }
+
 /**
   *@ return the closest distance from the first counts rs_vectors
   *@coord, distance to this point
@@ -995,22 +902,25 @@ double RS_VectorSolutions::getClosestDistance(const RS_Vector& coord,
 {
     double ret=RS_MAXDOUBLE*RS_MAXDOUBLE;
     int i=vector.size();
-    if (counts<i && counts>=0) i=counts;
-    for(int j=0; j<i; j++) {
-        if(vector[j].valid) {
-            double d=(coord - vector[j]).squared();
-            if(d<ret) ret=d;
-        }
-    }
-    return sqrt(ret);
+	if (counts < i && counts >= 0) i=counts;
+	std::for_each(vector.begin(), vector.begin() + i,
+				  [&ret, &coord](RS_Vector const& vp) {
+		if(vp.valid) {
+			double d=(coord - vp).squared();
+			if(d<ret) ret=d;
+		}
+	}
+	);
+
+	return sqrt(ret);
 }
 
 /** switch x,y for all vectors */
 RS_VectorSolutions RS_VectorSolutions::flipXY(void) const
 {
         RS_VectorSolutions ret;
-        const int counts=vector.size();
-        for(int i=0;i<counts;i++) ret.push_back(vector[i].flipXY());
+		for(const RS_Vector& vp: vector)
+			ret.push_back(vp.flipXY());
         return ret;
 }
 
@@ -1021,14 +931,11 @@ RS_VectorSolutions RS_VectorSolutions::operator = (const RS_VectorSolutions& s)
     return *this;
 }
 
-
 std::ostream& operator << (std::ostream& os,
                            const RS_VectorSolutions& s) {
-    for (int i=0; i<s.getNumber(); ++i) {
-        os << "(" << s.get(i) << ")\n";
+	for (const RS_Vector& vp: s){
+		os << "(" << vp << ")\n";
     }
     os << " tangent: " << (int)s.isTangent() << "\n";
     return os;
 }
-
-
