@@ -26,7 +26,9 @@
 
 #include "qg_actionfactory.h"
 
+#include <cassert>
 #include <QDockWidget>
+#include <QMenu>
 #include <QToolBar>
 
 #include "rs_actionblockscreate.h"
@@ -81,11 +83,13 @@
 #include "rs_actiondrawlineorthtan.h"
 #include "rs_actiondrawpoint.h"
 #include "rs_actiondrawspline.h"
+#include "lc_actiondrawsplinepoints.h"
 #include "rs_actiondrawtext.h"
 #include "rs_actiondrawmtext.h"
 #include "rs_actioneditcopy.h"
 #include "rs_actioneditpaste.h"
 #include "rs_actioneditundo.h"
+#include "lc_actionfileexportmakercam.h"
 #include "rs_actionfilenew.h"
 #include "rs_actionfilenewtemplate.h"
 #include "rs_actionfileopen.h"
@@ -103,6 +107,8 @@
 #include "rs_actionlayersremove.h"
 #include "rs_actionlayerstogglelock.h"
 #include "rs_actionlayerstoggleview.h"
+#include "rs_actionlayerstoggleprint.h"
+#include "lc_actionlayerstoggleconstruction.h"
 #include "rs_actionlockrelativezero.h"
 #include "rs_actionmodifyattributes.h"
 #include "rs_actionmodifybevel.h"
@@ -122,6 +128,7 @@
 #include "rs_actionmodifystretch.h"
 #include "rs_actionmodifytrim.h"
 #include "rs_actionmodifytrimamount.h"
+#include "rs_actionmodifyoffset.h"
 #include "rs_actionmodifyexplodetext.h"
 #include "rs_actionoptionsdrawing.h"
 #include "rs_actionprintpreview.h"
@@ -151,6 +158,8 @@
 #include "rs_actionpolylineequidistant.h"
 #include "rs_actionpolylinesegment.h"
 #include "rs_actionorder.h"
+#include "qg_cadtoolbar.h"
+#include "rs_debug.h"
 
 /**
  * Constructor.
@@ -158,20 +167,13 @@
  * @param ah Action handler which provides the slots.
  * @param w Widget through which the events come in.
  */
-QG_ActionFactory::QG_ActionFactory(QG_ActionHandler* ah, QWidget* w) {
-    actionHandler = ah;
-    widget = w;
+QG_ActionFactory::QG_ActionFactory(QG_ActionHandler* ah, QWidget* w, QG_CadToolBar* toolbar):
+    actionHandler(ah)
+  ,widget(w)
+  ,m_pCADToolBar(toolbar)
+{
 }
 
-
-
-/**
- * Destructor
- */
-QG_ActionFactory::~QG_ActionFactory() {}
-
-
-
 /* *
  *	Description:	- Creates a new action object and links it to the
  *						  appropriate slot(s).
@@ -195,7 +197,7 @@ QG_ActionFactory::~QG_ActionFactory() {}
  *	*/
 
 QAction* QG_ActionFactory::createAction(	RS2::ActionType id, QObject* obj,
-                                                                                                                QObject* obj2)
+                                                                                                                QObject* obj2) const
 {
     // assert that action handler is not invalid:
     if (actionHandler==NULL) {
@@ -206,14 +208,14 @@ QAction* QG_ActionFactory::createAction(	RS2::ActionType id, QObject* obj,
     }
 
     QWidget* mw = widget;
-    QAction* action = NULL;
-    QPixmap icon;
+    QAction* action = nullptr;
+//    QPixmap icon;
 
     if (mw==NULL) {
         RS_DEBUG->print(RS_Debug::D_WARNING,
                 "QG_ActionFactory::createAction: "
                         "No valid main window available to create action. id: %d ", id);
-        return NULL;
+        return nullptr;
     }
 
     // create requested action
@@ -252,12 +254,8 @@ QAction* QG_ActionFactory::createAction(	RS2::ActionType id, QObject* obj,
         break;
 
     case RS2::ActionFileExport:
-                        // tr("Export Drawing")
-                        action = new QAction(tr("&Export..."), NULL);
-                        //action->zetStatusTip(tr("Exports the current drawing as bitmap"));
-
-        connect(action, SIGNAL(triggered()),
-                obj, SLOT(slotFileExport()));
+		action = new QAction( QIcon(":/actions/fileexport.png"), tr("&Export as image"), NULL);
+        connect( action, SIGNAL( triggered()), obj, SLOT(slotFileExport()));
         break;
 
     case RS2::ActionFileClose:
@@ -286,6 +284,17 @@ QAction* QG_ActionFactory::createAction(	RS2::ActionType id, QObject* obj,
                 obj, SLOT(slotFilePrint()));
         break;
 
+    case RS2::ActionFilePrintPDF:
+                        // tr("Print Drawing")
+                        action = new QAction(tr("Export as PDF"), mw);
+                        action->setIcon(QIcon(":/actions/fileexportpdf.png"));
+//                        action->setShortcut(QKeySequence::Print);
+                        //action->zetStatusTip(tr("Prints out the current drawing"));
+
+        connect(action, SIGNAL(triggered()),
+                obj, SLOT(slotFilePrintPDF()));
+        break;
+
     case RS2::ActionFilePrintPreview:
                 action = RS_ActionPrintPreview::createGUIAction(id, mw);
                 action->setCheckable(true);
@@ -293,6 +302,11 @@ QAction* QG_ActionFactory::createAction(	RS2::ActionType id, QObject* obj,
                 obj, SLOT(slotFilePrintPreview(bool)));
         break;
 
+    case RS2::ActionFileExportMakerCam:
+		action = LC_ActionFileExportMakerCam::createGUIAction(id, mw);
+        connect(action, SIGNAL(triggered()), obj, SLOT(slotFileExportMakerCam()));
+        break;
+
     case RS2::ActionFileQuit:
                         action = new QAction(tr("&Quit"), mw);
 #if QT_VERSION >= 0x040600
@@ -312,7 +326,7 @@ QAction* QG_ActionFactory::createAction(	RS2::ActionType id, QObject* obj,
                         // tr("Grid")
                         action = new QAction(tr("&Grid"), mw);
                         action->setIcon(QIcon(":/actions/viewgrid.png"));
-                        action->setShortcut(tr("CTRL-G"));
+                        action->setShortcut(QKeySequence(tr("Ctrl+G", "Toggle Grid")));
                         //action->zetStatusTip(tr("Enables/disables the grid"));
                         action->setCheckable(true);
                         connect(action, SIGNAL(toggled(bool)),
@@ -332,6 +346,8 @@ QAction* QG_ActionFactory::createAction(	RS2::ActionType id, QObject* obj,
         action = new QAction(tr("&Statusbar"), mw);
         //action->zetStatusTip(tr("Enables/disables the statusbar"));
         action->setCheckable(true);
+        // StatusBar is displayed by default
+        action->setChecked(true);
 
         connect(action, SIGNAL(toggled(bool)),
                 obj, SLOT(slotViewStatusBar(bool)));
@@ -355,6 +371,9 @@ QAction* QG_ActionFactory::createAction(	RS2::ActionType id, QObject* obj,
         if (obj2) {
             action=((QToolBar *)obj2)->toggleViewAction();
         }
+        if(id==RS2::ActionViewCadToolbar){
+            action->setText(tr("CAD ToolBar"));
+        }
         break;
 
         // Tools:
@@ -796,6 +815,12 @@ QAction* QG_ActionFactory::createAction(	RS2::ActionType id, QObject* obj,
                 obj, SLOT(slotDrawSpline()));
         break;
 
+    case RS2::ActionDrawSplinePoints:
+                action = LC_ActionDrawSplinePoints::createGUIAction(id, mw);
+        connect(action, SIGNAL(triggered()),
+                obj, SLOT(slotDrawSplinePoints()));
+        break;
+
         case RS2::ActionPolylineAdd:
                 action = RS_ActionPolylineAdd::createGUIAction(id, mw);
         connect(action, SIGNAL(triggered()),
@@ -1008,6 +1033,12 @@ QAction* QG_ActionFactory::createAction(	RS2::ActionType id, QObject* obj,
                 obj, SLOT(slotModifyTrimAmount()));
         break;
 
+    case RS2::ActionModifyOffset:
+                action = RS_ActionModifyOffset::createGUIAction(id, mw);
+        connect(action, SIGNAL(triggered()),
+                obj, SLOT(slotModifyOffset()));
+        break;
+
     case RS2::ActionModifyCut:
                 action = RS_ActionModifyCut::createGUIAction(id, mw);
         connect(action, SIGNAL(triggered()),
@@ -1301,6 +1332,16 @@ QAction* QG_ActionFactory::createAction(	RS2::ActionType id, QObject* obj,
                 obj, SLOT(slotLayersToggleView()));
         break;
 
+    case RS2::ActionLayersTogglePrint:
+        action = RS_ActionLayersTogglePrint::createGUIAction(id, mw);
+        connect(action, SIGNAL(triggered()), obj, SLOT(slotLayersTogglePrint()));
+        break;
+
+    case RS2::ActionLayersToggleConstruction:
+        action = LC_ActionLayersToggleConstruction::createGUIAction(id, mw);
+        connect(action, SIGNAL(triggered()), obj, SLOT(slotLayersToggleConstruction()));
+        break;
+
         // Block actions:
         //
     case RS2::ActionBlocksDefreezeAll:
@@ -1358,6 +1399,11 @@ QAction* QG_ActionFactory::createAction(	RS2::ActionType id, QObject* obj,
         connect(action, SIGNAL(triggered()),
                 obj, SLOT(slotBlocksExplode()));
         break;
+    case RS2::ActionBlocksImport:
+        action = new QAction(QIcon(":/ui/blockinsert.png"), tr("&Block"), obj);
+        connect(action, SIGNAL(triggered()),
+                obj, SLOT(slotImportBlock()));
+        break;
 
 
         // Options actions:
@@ -1425,3 +1471,68 @@ QAction* QG_ActionFactory::createAction(	RS2::ActionType id, QObject* obj,
 }
 
 
+QAction*  QG_ActionFactory::addGUI(QMenu* menu, QObject* obj, RS2::ActionType id,
+								   RS2::ToolBarId toolbarId ) const
+{
+    QAction* const action=createAction(id, obj);
+    if(action) menu->addAction(action);
+	if(m_pCADToolBar && toolbarId != RS2::ToolBarNone){
+		m_pCADToolBar->populateSubToolBar({action}, toolbarId);
+	   }
+    return action;
+}
+
+void QG_ActionFactory::addGUI(QMenu* menu, QObject* obj,
+							  const std::initializer_list<RS2::ActionType>& list,
+							  RS2::ToolBarId id) const
+{
+	std::vector<QAction*> actions;
+	for(RS2::ActionType type: list){
+		actions.push_back(addGUI(menu, obj, type));
+	}
+	if(actions.size() && m_pCADToolBar && id != RS2::ToolBarNone){
+		m_pCADToolBar->populateSubToolBar(actions, id);
+	}
+}
+
+QAction*  QG_ActionFactory::addGUI(QMenu* menu, QObject* obj, QObject* obj2, RS2::ActionType id) const
+{
+    QAction* const action=createAction(id, obj, obj2);
+    if(action) menu->addAction(action);
+    return action;
+}
+
+QAction*  QG_ActionFactory::addGUI(QMenu* menu, QToolBar* toolbar, QObject* obj, RS2::ActionType id) const
+{
+    QAction* const action=createAction(id, obj);
+    if(action){
+        menu->addAction(action);
+        toolbar->addAction(action);
+    }
+    return action;
+}
+
+void QG_ActionFactory::addGUI(QMenu* menu, QToolBar* toolbar, QObject* obj, const std::initializer_list<RS2::ActionType>& list) const
+{
+    for(RS2::ActionType type: list)
+        addGUI(menu, toolbar, obj, type);
+}
+
+QAction* QG_ActionFactory::addGUI(QMenu* menu, QToolBar* toolbar, QObject* obj, QObject* obj2, RS2::ActionType id) const
+{
+    QAction* const action=createAction(id, obj, obj2);
+    if(action){
+        menu->addAction(action);
+        toolbar->addAction(action);
+    }
+    return action;
+}
+
+
+void QG_ActionFactory::setCADToolBar(QG_CadToolBar* toolbar)
+{
+	m_pCADToolBar=toolbar;
+}
+
+
+
