@@ -2,6 +2,7 @@
 **
 ** This file is part of the LibreCAD project, a 2D CAD program
 **
+** Copyright (C) 2015 A. Stebich (librecad@mail.lordofbikes.de)
 ** Copyright (C) 2010 R. van Twisk (librecad@rvt.dds.nl)
 ** Copyright (C) 2001-2003 RibbonSoft. All rights reserved.
 **
@@ -24,6 +25,7 @@
 **
 **********************************************************************/
 
+#include<cmath>
 #include "qg_actionhandler.h"
 
 #include "rs_dialogfactory.h"
@@ -83,10 +85,12 @@
 #include "rs_actiondrawmtext.h"
 #include "rs_actiondrawpoint.h"
 #include "rs_actiondrawspline.h"
+#include "lc_actiondrawsplinepoints.h"
 #include "rs_actiondrawtext.h"
 #include "rs_actioneditcopy.h"
 #include "rs_actioneditpaste.h"
 #include "rs_actioneditundo.h"
+#include "lc_actionfileexportmakercam.h"
 #include "rs_actionfilenewtemplate.h"
 #include "rs_actionfileopen.h"
 #include "rs_actionfilesaveas.h"
@@ -103,6 +107,7 @@
 #include "rs_actionlayerstogglelock.h"
 #include "rs_actionlayerstoggleview.h"
 #include "rs_actionlayerstoggleprint.h"
+#include "lc_actionlayerstoggleconstruction.h"
 #include "rs_actionlibraryinsert.h"
 #include "rs_actionlockrelativezero.h"
 #include "rs_actionmodifyattributes.h"
@@ -159,52 +164,20 @@
 
 #include "qg_mainwindowinterface.h"
 #include "qg_snaptoolbar.h"
-
-//a list of EntityTypes which support actionOffset
-QVector<RS2::EntityType> QG_ActionHandler::offsetEntities(0);
+#include "qc_applicationwindow.h"
+#include "rs_debug.h"
 
 /**
  * Constructor
  */
-QG_ActionHandler::QG_ActionHandler(QG_MainWindowInterface* mw) {
-    RS_DEBUG->print("QG_ActionHandler::QG_ActionHandler");
-    mainWindow = mw;
-
-//    snapFree               = NULL;
-//    snapGrid               = NULL;
-//    snapEndpoint           = NULL;
-//    snapOnEntity           = NULL;
-//    snapCenter             = NULL;
-//    snapMiddle             = NULL;
-//    snapDistance               = NULL;
-//    snapIntersection       = NULL;
-//    snapIntersectionManual = NULL;
-
-    snapToolBar= NULL;
-
-//    restrictNothing = NULL;
-//    restrictOrthogonal = NULL;
-//    restrictHorizontal = NULL;
-//    restrictVertical = NULL;
-
-//    lockRelativeZero = NULL;
-//    lockedRelZero=false;
-    orderType = RS2::ActionOrderTop;
+QG_ActionHandler::QG_ActionHandler(QG_MainWindowInterface* mw):
+	mainWindow(mw)
+  ,orderType(RS2::ActionOrderTop)
+{
+	RS_DEBUG->print("QG_ActionHandler::QG_ActionHandler");
     RS_DEBUG->print("QG_ActionHandler::QG_ActionHandler: OK");
 }
 
-
-
-/**
- * Destructor
- */
-QG_ActionHandler::~QG_ActionHandler() {
-    RS_DEBUG->print("QG_ActionHandler::~QG_ActionHandler");
-    RS_DEBUG->print("QG_ActionHandler::~QG_ActionHandler: OK");
-}
-
-
-
 /**
  * Kills all running selection actions. Called when a selection action
   * is launched to reduce confusion.
@@ -212,12 +185,18 @@ QG_ActionHandler::~QG_ActionHandler() {
 void QG_ActionHandler::killSelectActions() {
     RS_GraphicView* gv = mainWindow->getGraphicView();
 
-    if (gv!=NULL) {
+	if (gv) {
         gv->killSelectActions();
     }
 }
 
+void QG_ActionHandler::killAllActions() {
+	RS_GraphicView* gv = mainWindow->getGraphicView();
 
+	if (gv) {
+		gv->killAllActions();
+	}
+}
 
 /**
  * @return Current action or NULL.
@@ -225,15 +204,13 @@ void QG_ActionHandler::killSelectActions() {
 RS_ActionInterface* QG_ActionHandler::getCurrentAction() {
     RS_GraphicView* gv = mainWindow->getGraphicView();
 
-    if (gv!=NULL) {
+	if (gv) {
         return gv->getCurrentAction();
     } else {
         return NULL;
     }
 }
 
-
-
 /**
  * Sets current action.
  *
@@ -275,11 +252,14 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
     case RS2::ActionFileSaveAs:
         a = new RS_ActionFileSaveAs(*doc, *gv);
         break;
+    case RS2::ActionFileExportMakerCam:
+		a = new LC_ActionFileExportMakerCam(*doc, *gv);
+        break;
 
         // Editing actions:
         //
     case RS2::ActionEditKillAllActions:
-        if (gv!=NULL) {
+		if (gv) {
             // DO we need to call some form of a 'clean' function?
             gv->killAllActions();
             RS_DIALOGFACTORY->requestToolBar(RS2::ToolBarMain);
@@ -296,14 +276,18 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
         a = new RS_ActionEditUndo(false, *doc, *gv);
         break;
     case RS2::ActionEditCut:
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionEditCutNoSelect);
-        break;
+		if(!doc->countSelected()){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionEditCutNoSelect);
+			break;
+		}
     case RS2::ActionEditCutNoSelect:
         a = new RS_ActionEditCopy(false, *doc, *gv);
         break;
-    case RS2::ActionEditCopy:
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionEditCopyNoSelect);
-        break;
+	case RS2::ActionEditCopy:
+		if(!doc->countSelected()){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionEditCopyNoSelect);
+			break;
+		}
     case RS2::ActionEditCopyNoSelect:
         a = new RS_ActionEditCopy(true, *doc, *gv);
         break;
@@ -323,9 +307,11 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
         a = new RS_ActionSelect(*doc, *gv, RS2::ActionOrderNoSelect);
         break;
     case RS2::ActionOrderTop:
-        orderType = RS2::ActionOrderTop;
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionOrderNoSelect);
-        break;
+		if(!doc->countSelected()){
+			orderType = RS2::ActionOrderTop;
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionOrderNoSelect);
+			break;
+		}
     case RS2::ActionOrderNoSelect:
         a = new RS_ActionOrder(*doc, *gv, orderType);
         break;
@@ -423,7 +409,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
         a = new RS_ActionDrawLineHorVert(*doc, *gv);
         break;
     case RS2::ActionDrawLineVertical:
-        a = new RS_ActionDrawLineAngle(*doc, *gv, M_PI/2.0, true,
+        a = new RS_ActionDrawLineAngle(*doc, *gv, M_PI_2, true,
                                        RS2::ActionDrawLineVertical);
         break;
     case RS2::ActionDrawLineFree:
@@ -452,10 +438,10 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
         a = new RS_ActionDrawLineTangent2(*doc, *gv);
         break;
     case RS2::ActionDrawLineOrthogonal:
-        a = new RS_ActionDrawLineRelAngle(*doc, *gv, M_PI/2.0, true);
+        a = new RS_ActionDrawLineRelAngle(*doc, *gv, M_PI_2, true);
         break;
     case RS2::ActionDrawLineRelAngle:
-        a = new RS_ActionDrawLineRelAngle(*doc, *gv, M_PI/2.0, false);
+        a = new RS_ActionDrawLineRelAngle(*doc, *gv, M_PI_2, false);
         break;
     case RS2::ActionDrawPolyline:
         a = new RS_ActionDrawPolyline(*doc, *gv);
@@ -557,6 +543,9 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
     case RS2::ActionDrawSpline:
         a = new RS_ActionDrawSpline(*doc, *gv);
         break;
+    case RS2::ActionDrawSplinePoints:
+        a = new LC_ActionDrawSplinePoints(*doc, *gv);
+        break;
     case RS2::ActionDrawMText:
         a = new RS_ActionDrawMText(*doc, *gv);
         break;
@@ -566,8 +555,12 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
     case RS2::ActionDrawHatch:
         a = new RS_ActionSelect(*doc, *gv, RS2::ActionDrawHatchNoSelect);
         break;
-    case RS2::ActionDrawHatchNoSelect:
-        a = new RS_ActionDrawHatch(*doc, *gv);
+	case RS2::ActionDrawHatchNoSelect:
+	{
+		auto p = new RS_ActionDrawHatch(*doc, *gv);
+		p->setShowArea(true);
+		a=p;
+	}
         break;
     case RS2::ActionDrawImage:
         a = new RS_ActionDrawImage(*doc, *gv);
@@ -585,7 +578,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
         a = new RS_ActionDimLinear(*doc, *gv, 0.0, true, RS2::ActionDimLinearHor);
         break;
     case RS2::ActionDimLinearVer:
-        a = new RS_ActionDimLinear(*doc, *gv, M_PI/2.0, true, RS2::ActionDimLinearVer);
+        a = new RS_ActionDimLinear(*doc, *gv, M_PI_2, true, RS2::ActionDimLinearVer);
         break;
     case RS2::ActionDimRadial:
         a = new RS_ActionDimRadial(*doc, *gv);
@@ -603,8 +596,10 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
         // Modifying actions:
         //
     case RS2::ActionModifyAttributes:
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyAttributesNoSelect);
-        break;
+		if(!doc->countSelected()){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyAttributesNoSelect);
+			break;
+		}
     case RS2::ActionModifyAttributesNoSelect:
         a = new RS_ActionModifyAttributes(*doc, *gv);
         break;
@@ -621,51 +616,65 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
         a = new RS_ActionModifyDeleteFree(*doc, *gv);
         break;
     case RS2::ActionModifyMove:
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyMoveNoSelect);
-        break;
+		if(!doc->countSelected()){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyMoveNoSelect);
+			break;
+		}
     case RS2::ActionModifyMoveNoSelect:
         a = new RS_ActionModifyMove(*doc, *gv);
         break;
 	case RS2::ActionModifyRevertDirection:
-		a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyRevertDirectionNoSelect);
-		break;
+		if(!doc->countSelected()){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyRevertDirectionNoSelect);
+			break;
+		}
 	case RS2::ActionModifyRevertDirectionNoSelect:
 		a = new RS_ActionModifyRevertDirection(*doc, *gv);
 		break;
 	case RS2::ActionModifyRotate:
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyRotateNoSelect);
-        break;
+		if(!doc->countSelected()){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyRotateNoSelect);
+			break;
+		}
     case RS2::ActionModifyRotateNoSelect:
         a = new RS_ActionModifyRotate(*doc, *gv);
         break;
     case RS2::ActionModifyScale:
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyScaleNoSelect);
-        break;
+		if(!doc->countSelected()){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyScaleNoSelect);
+			break;
+		}
     case RS2::ActionModifyScaleNoSelect:
-        a = new RS_ActionModifyScale(*doc, *gv);
-        break;
+		a = new RS_ActionModifyScale(*doc, *gv);
+		break;
     case RS2::ActionModifyMirror:
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyMirrorNoSelect);
-        break;
+		if(!doc->countSelected()){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyMirrorNoSelect);
+			break;
+		}
     case RS2::ActionModifyMirrorNoSelect:
         a = new RS_ActionModifyMirror(*doc, *gv);
         break;
-    case RS2::ActionModifyMoveRotate:
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyMoveRotateNoSelect);
-        break;
+	case RS2::ActionModifyMoveRotate:
+		if(!doc->countSelected()){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyMoveRotateNoSelect);
+			break;
+		}
     case RS2::ActionModifyMoveRotateNoSelect:
         a = new RS_ActionModifyMoveRotate(*doc, *gv);
         break;
-    case RS2::ActionModifyRotate2:
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyRotate2NoSelect);
-        break;
+	case RS2::ActionModifyRotate2:
+		if(!doc->countSelected()){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyRotate2NoSelect);
+			break;
+		}
     case RS2::ActionModifyRotate2NoSelect:
         a = new RS_ActionModifyRotate2(*doc, *gv);
-        break;
-    case RS2::ActionModifyEntity:
-        a = new RS_ActionModifyEntity(*doc, *gv);
-        break;
-    case RS2::ActionModifyTrim:
+		break;
+	case RS2::ActionModifyEntity:
+		a = new RS_ActionModifyEntity(*doc, *gv);
+		break;
+	case RS2::ActionModifyTrim:
         a = new RS_ActionModifyTrim(*doc, *gv, false);
         a->setActionType(id);
         break;
@@ -689,22 +698,21 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
         a = new RS_ActionModifyRound(*doc, *gv);
         break;
     case RS2::ActionModifyOffset:
-    if (offsetEntities.size() == 0){
-        //list all supported Entity types here
-        //fixme, handle this initialization better
-        offsetEntities.push_back(RS2::EntityArc);
-        offsetEntities.push_back(RS2::EntityCircle);
-        offsetEntities.push_back(RS2::EntityLine);
-        offsetEntities.push_back(RS2::EntityPolyline);
-    }
-        a = new RS_ActionSelect(*doc, *gv,RS2::ActionModifyOffsetNoSelect,&offsetEntities);
-        break;
+    {
+		auto allowedOffsetTypes={RS2::EntityArc, RS2::EntityCircle, RS2::EntityLine, RS2::EntityPolyline};
+		if(!doc->countSelected(true, allowedOffsetTypes)){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyOffsetNoSelect, allowedOffsetTypes);
+			break;
+		}
+	}
     case RS2::ActionModifyOffsetNoSelect:
         a = new RS_ActionModifyOffset(*doc, *gv);
-        break;
-    case RS2::ActionModifyExplodeText:
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyExplodeTextNoSelect);
-        break;
+		break;
+	case RS2::ActionModifyExplodeText:
+		if(!doc->countSelected(false, {RS2::EntityText, RS2::EntityMText})){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionModifyExplodeTextNoSelect);
+			break;
+		}
     case RS2::ActionModifyExplodeTextNoSelect:
         a = new RS_ActionModifyExplodeText(*doc, *gv);
         break;
@@ -792,9 +800,11 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
     case RS2::ActionInfoAngle:
         a = new RS_ActionInfoAngle(*doc, *gv);
         break;
-    case RS2::ActionInfoTotalLength:
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionInfoTotalLengthNoSelect);
-        break;
+	case RS2::ActionInfoTotalLength:
+		if(!doc->countSelected()){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionInfoTotalLengthNoSelect);
+			break;
+		}
     case RS2::ActionInfoTotalLengthNoSelect:
         a = new RS_ActionInfoTotalLength(*doc, *gv);
         break;
@@ -828,6 +838,9 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
     case RS2::ActionLayersTogglePrint:
         a = new RS_ActionLayersTogglePrint(*doc, *gv);
         break;
+    case RS2::ActionLayersToggleConstruction:
+        a = new LC_ActionLayersToggleConstruction(*doc, *gv);
+        break;
         // Block actions:
         //
     case RS2::ActionBlocksDefreezeAll:
@@ -858,14 +871,18 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
         a = new RS_ActionBlocksToggleView(*doc, *gv);
         break;
     case RS2::ActionBlocksCreate:
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionBlocksCreateNoSelect);
-        break;
+		if(!doc->countSelected()){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionBlocksCreateNoSelect);
+			break;
+		}
     case RS2::ActionBlocksCreateNoSelect:
         a = new RS_ActionBlocksCreate(*doc, *gv);
         break;
-    case RS2::ActionBlocksExplode:
-        a = new RS_ActionSelect(*doc, *gv, RS2::ActionBlocksExplodeNoSelect);
-        break;
+	case RS2::ActionBlocksExplode:
+		if(!doc->countSelected(true, {RS2::EntityBlock})){
+			a = new RS_ActionSelect(*doc, *gv, RS2::ActionBlocksExplodeNoSelect);
+			break;
+		}
     case RS2::ActionBlocksExplodeNoSelect:
         a = new RS_ActionBlocksExplode(*doc, *gv);
         break;
@@ -893,7 +910,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
         break;
     }
 
-    if (a!=NULL) {
+	if (a) {
         gv->setCurrentAction(a);
     }
 
@@ -909,7 +926,7 @@ RS_ActionInterface* QG_ActionHandler::setCurrentAction(RS2::ActionType id) {
 QStringList QG_ActionHandler::getAvailableCommands() {
     RS_ActionInterface* currentAction = getCurrentAction();
 
-    if (currentAction!=NULL) {
+	if (currentAction) {
         return currentAction->getAvailableCommands();
     } else {
         QStringList cmd;
@@ -922,7 +939,9 @@ QStringList QG_ActionHandler::getAvailableCommands() {
 //get snap mode from snap toolbar
 RS_SnapMode QG_ActionHandler::getSnaps()
 {
-    if (snapToolBar != NULL) {
+	QG_SnapToolBar* snapToolBar=QC_ApplicationWindow::getAppWindow()->getSnapToolBar();
+
+	if (snapToolBar) {
         return snapToolBar->getSnaps();
     }
     //return a free snap mode
@@ -945,7 +964,7 @@ bool QG_ActionHandler::keycode(const QString& code) {
     //RS_keycodeEvent e(cmd);
 
     //RS_GraphicView* gv = mainWindow->getGraphicView();
-    //if (gv!=NULL) {
+	//if (gv) {
     //    gv->keycodeEvent(&e);
     //}
 
@@ -1070,12 +1089,17 @@ bool QG_ActionHandler::command(const QString& cmd) {
     RS_DEBUG->print("QG_ActionHandler::command: %s", cmd.toLatin1().data());
     QString c = cmd.toLower();
 
-    if (c=="\n") {
+    if (c=="\n" || c==tr("escape", "escape, go back from action steps")) {
         RS_GraphicView* gv = mainWindow->getGraphicView();
-        if (gv!=NULL) {
-            gv->back();
+		if (gv) {
+            if(c=="\n" ){
+                gv->enter();
+                RS_DEBUG->print("QG_ActionHandler::command: enter");
+            }else{
+                gv->back();
+                RS_DEBUG->print("QG_ActionHandler::command: back");
+            }
         }
-        RS_DEBUG->print("QG_ActionHandler::command: back");
         return true;
     }
 
@@ -1083,7 +1107,7 @@ bool QG_ActionHandler::command(const QString& cmd) {
     RS_CommandEvent e(cmd);
 
     RS_GraphicView* gv = mainWindow->getGraphicView();
-    if (gv!=NULL) {
+	if (gv) {
         RS_DEBUG->print("QG_ActionHandler::command: trigger command event in "
                         " graphic view");
         gv->commandEvent(&e);
@@ -1099,7 +1123,7 @@ bool QG_ActionHandler::command(const QString& cmd) {
         if (type!=RS2::ActionNone) {
             RS_DEBUG->print("QG_ActionHandler::command: setting current action");
              //special handling, currently needed for snap actions
-            if( commandLineActions(type)==false){
+			if (!commandLineActions(type)){
                 //not handled yet
                 setCurrentAction(type);
             }
@@ -1148,6 +1172,10 @@ void QG_ActionHandler::slotFilePrint() {
 }
 */
 
+void QG_ActionHandler::slotFileExportMakerCam() {
+    setCurrentAction(RS2::ActionFileExportMakerCam);
+}
+
 void QG_ActionHandler::slotZoomIn() {
     setCurrentAction(RS2::ActionZoomIn);
 }
@@ -1184,6 +1212,9 @@ void QG_ActionHandler::slotEditKillAllActions() {
     setCurrentAction(RS2::ActionEditKillAllActions);
 }
 void QG_ActionHandler::slotEditUndo() {
+	//to avoid operation on deleted entities, Undo action invalid all suspended
+	//actions
+	killAllActions();
     setCurrentAction(RS2::ActionEditUndo);
 }
 
@@ -1445,6 +1476,10 @@ void QG_ActionHandler::slotDrawSpline() {
     setCurrentAction(RS2::ActionDrawSpline);
 }
 
+void QG_ActionHandler::slotDrawSplinePoints() {
+    setCurrentAction(RS2::ActionDrawSplinePoints);
+}
+
 void QG_ActionHandler::slotDrawMText() {
     setCurrentAction(RS2::ActionDrawMText);
 }
@@ -1578,17 +1613,18 @@ void QG_ActionHandler::slotModifyExplodeText() {
     setCurrentAction(RS2::ActionModifyExplodeText);
 }
 
-void QG_ActionHandler::slotSetSnaps(RS_SnapMode s) {
+void QG_ActionHandler::slotSetSnaps(RS_SnapMode const& s) {
     RS_DEBUG->print("QG_ActionHandler::slotSetSnaps()");
-    updateSnapMode(s);
-    if(snapToolBar != NULL) {
+	QG_SnapToolBar* snapToolBar=QC_ApplicationWindow::getAppWindow()->getSnapToolBar();
+
+	if(snapToolBar ) {
     RS_DEBUG->print("QG_ActionHandler::slotSetSnaps(): set snapToolBar");
         snapToolBar->setSnaps(s);
     }else{
     RS_DEBUG->print("QG_ActionHandler::slotSetSnaps(): snapToolBar is NULL");
     }
     RS_GraphicView* view=mainWindow->getGraphicView();
-    if(view != NULL) {
+	if(view ) {
         view->setDefaultSnapMode(s);
     }
     RS_DEBUG->print("QG_ActionHandler::slotSetSnaps(): ok");
@@ -1656,10 +1692,10 @@ void QG_ActionHandler::slotSnapIntersection() {
 
 void QG_ActionHandler::slotSnapIntersectionManual() {
     //disableSnaps();
-    /*if (snapIntersectionManual!=NULL) {
+	/*if (snapIntersectionManual) {
         snapIntersectionManual->setChecked(true);
 }*/
-    /*if (snapToolBar!=NULL) {
+	/*if (snapToolBar) {
         snapToolBar->setSnapMode(RS2::SnapIntersectionManual);
 }*/
     //setCurrentAction(RS2::ActionSnapIntersectionManual);
@@ -1705,20 +1741,14 @@ void QG_ActionHandler::disableRestrictions() {
     slotSetSnaps(s);
 }
 
-
-/**
- * Updates the snap mode for the current document from the selected menu.
- * Used after the active window changed.
- */
-void QG_ActionHandler::updateSnapMode(RS_SnapMode& /*s*/) {
-}
-
 void QG_ActionHandler::slotSetRelativeZero() {
     setCurrentAction(RS2::ActionSetRelativeZero);
 }
 
 void QG_ActionHandler::slotLockRelativeZero(bool on) {
-    if (snapToolBar != NULL) {
+	QG_SnapToolBar* snapToolBar=QC_ApplicationWindow::getAppWindow()->getSnapToolBar();
+
+	if (snapToolBar) {
         snapToolBar->setLockedRelativeZero(on);
     }
     if (on) {
@@ -1784,6 +1814,10 @@ void QG_ActionHandler::slotLayersTogglePrint() {
     setCurrentAction(RS2::ActionLayersTogglePrint);
 }
 
+void QG_ActionHandler::slotLayersToggleConstruction() {
+    setCurrentAction(RS2::ActionLayersToggleConstruction);
+}
+
 
 void QG_ActionHandler::slotBlocksDefreezeAll() {
     setCurrentAction(RS2::ActionBlocksDefreezeAll);
@@ -1836,19 +1870,11 @@ void QG_ActionHandler::slotOptionsDrawing() {
 
 void QG_ActionHandler::slotFocusNormal() {
     //QG_GraphicView* gv = mainWindow->getGraphicView();
-    //if (gv!=NULL) {
+	//if (gv) {
         //gv->setFocus();
         mainWindow->setFocus2();
     //}
 }
 
-/**
-    * Creates link to snap tool bar so we can update the button
-    * state if the snapping action changes.
-    */
-void QG_ActionHandler::setSnapToolBar(QG_SnapToolBar* tb) {
-    snapToolBar = tb;
-}
-
 // EOF
 
