@@ -29,6 +29,9 @@
 #include <QGridLayout>
 #include <QLabel>
 #include <QDebug>
+#if QT_VERSION >= 0x050200
+#include <QNativeGestureEvent>
+#endif
 
 #include "rs_actionzoomin.h"
 #include "rs_actionzoompan.h"
@@ -38,30 +41,44 @@
 #include "rs_actionselectsingle.h"
 #include "rs_settings.h"
 #include "rs_painterqt.h"
-#include "qg_cadtoolbar.h"
 #include "rs_dialogfactory.h"
+#include "qg_cadtoolbar.h"
 #include "qg_dialogfactory.h"
 
 
 #include "qg_scrollbar.h"
+#include "rs_modification.h"
+#include "rs_debug.h"
 
 #define QG_SCROLLMARGIN 400
 
+#ifdef Q_OS_WIN32
+#define CURSOR_SIZE 16
+#else
+#define CURSOR_SIZE 15
+#endif
 
 /**
  * Constructor.
  */
 QG_GraphicView::QG_GraphicView(QWidget* parent, const char* name, Qt::WindowFlags f)
-        : QWidget(parent, f), RS_GraphicView() {
-
+        :QWidget(parent, f)
+        ,RS_GraphicView()
+        ,hScrollBar(new QG_ScrollBar(Qt::Horizontal, this))
+        ,vScrollBar(new QG_ScrollBar(Qt::Vertical, this))
+        ,layout(new QGridLayout(this))
+        ,gridStatus(new QLabel("-", this))
+        ,curCad(new QCursor(QPixmap(":ui/cur_cad_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
+        ,curDel(new QCursor(QPixmap(":ui/cur_del_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
+        ,curSelect(new QCursor(QPixmap(":ui/cur_select_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
+        ,curMagnifier(new QCursor(QPixmap(":ui/cur_glass_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
+        ,curHand(new QCursor(QPixmap(":ui/cur_hand_bmp.png"), CURSOR_SIZE, CURSOR_SIZE))
+        ,redrawMethod(RS2::RedrawAll)
+        ,isSmoothScrolling(false)
+{
     setObjectName(name);
     setBackground(background);
 
-    redrawMethod=RS2::RedrawAll;
-
-    PixmapLayer1=PixmapLayer2=PixmapLayer3=NULL;
-
-    layout = new QGridLayout(this);
     layout->setMargin(0);
     layout->setSpacing(0);
     layout->setColumnStretch(0, 1);
@@ -70,7 +87,6 @@ QG_GraphicView::QG_GraphicView(QWidget* parent, const char* name, Qt::WindowFlag
     layout->setRowStretch(0, 1);
     layout->setRowStretch(1, 0);
 
-    hScrollBar = new QG_ScrollBar(Qt::Horizontal, this);
     hScrollBar->setSingleStep(50);
     hScrollBar->setCursor(Qt::ArrowCursor);
     layout->addWidget(hScrollBar, 1, 0);
@@ -78,7 +94,6 @@ QG_GraphicView::QG_GraphicView(QWidget* parent, const char* name, Qt::WindowFlag
     connect(hScrollBar, SIGNAL(valueChanged(int)),
             this, SLOT(slotHScrolled(int)));
 
-    vScrollBar = new QG_ScrollBar(Qt::Vertical, this);
     vScrollBar->setSingleStep(50);
     vScrollBar->setCursor(Qt::ArrowCursor);
     layout->addWidget(vScrollBar, 0, 2);
@@ -86,31 +101,11 @@ QG_GraphicView::QG_GraphicView(QWidget* parent, const char* name, Qt::WindowFlag
     connect(vScrollBar, SIGNAL(valueChanged(int)),
             this, SLOT(slotVScrolled(int)));
 
-    // Mouse Cursors:
-    QPixmap cur1(":ui/cur_cad_bmp.png");
-    QPixmap cur2(":ui/cur_glass_bmp.png");
-    QPixmap cur3(":ui/cur_del_bmp.png");
-    QPixmap cur4(":ui/cur_select_bmp.png");
-    QPixmap cur5(":ui/cur_hand_bmp.png");
-#ifdef Q_OS_WIN32
-    curCad = new QCursor(cur1, 16, 16);
-    curMagnifier = new QCursor(cur2, 12, 12);
-    curDel = new QCursor(cur3, 16, 16);
-    curSelect = new QCursor(cur4, 16, 16);
-    curHand = new QCursor(cur5, 15, 15);
-#else
-    curCad = new QCursor(cur1, 15, 15);
-    curMagnifier = new QCursor(cur2, 12, 12);
-    curDel = new QCursor(cur3, 15, 15);
-    curSelect = new QCursor(cur4, 15, 15);
-    curHand = new QCursor(cur5, 15, 15);
-#endif
-
     // Dummy widgets for scrollbar corners:
     //layout->addWidget(new QWidget(this), 1, 1);
     //QWidget* w = new QWidget(this);
     //w->setEraseColor(QColor(255,0,0));
-    gridStatus = new QLabel("-", this);
+
     gridStatus->setAlignment(Qt::AlignRight);
     layout->addWidget(gridStatus, 1, 1, 1, 2);
     layout->addItem(new QSpacerItem(50, 0), 0, 1);
@@ -131,10 +126,7 @@ QG_GraphicView::QG_GraphicView(QWidget* parent, const char* name, Qt::WindowFlag
  * Destructor
  */
 QG_GraphicView::~QG_GraphicView() {
-    cleanUp();
-        delete PixmapLayer1;
-        delete PixmapLayer2;
-        delete PixmapLayer3;
+	cleanUp();
 }
 
 
@@ -142,7 +134,7 @@ QG_GraphicView::~QG_GraphicView() {
 /**
  * @return width of widget.
  */
-int QG_GraphicView::getWidth() {
+int QG_GraphicView::getWidth() const{
     return width() - vScrollBar->sizeHint().width();
 }
 
@@ -151,7 +143,7 @@ int QG_GraphicView::getWidth() {
 /**
  * @return height of widget.
  */
-int QG_GraphicView::getHeight() {
+int QG_GraphicView::getHeight() const{
     return height() - hScrollBar->sizeHint().height();
 }
 
@@ -326,7 +318,7 @@ void QG_GraphicView::mouseReleaseEvent(QMouseEvent* e) {
     //QWidget::mouseReleaseEvent(e);
 
     if (!e->isAccepted()) {
-        if (QG_DIALOGFACTORY!=NULL && QG_DIALOGFACTORY->getCadToolBar()!=NULL) {
+        if (QG_DIALOGFACTORY && QG_DIALOGFACTORY->getCadToolBar()) {
                         RS_DEBUG->print("QG_GraphicView::mouseReleaseEvent: "
                                 "fwd to cadtoolbar");
             QG_DIALOGFACTORY->getCadToolBar()->mouseReleaseEvent(e);
@@ -345,7 +337,7 @@ void QG_GraphicView::mouseMoveEvent(QMouseEvent* e) {
 
 #ifdef Q_OS_WIN32
         // make sure that we can still use hotkeys and the mouse wheel
-        if (parent()!=NULL) {
+        if (parent()) {
                 ((QWidget*)parent())->setFocus();
         }
 #endif
@@ -353,6 +345,36 @@ void QG_GraphicView::mouseMoveEvent(QMouseEvent* e) {
     //RS_DEBUG->print("QG_GraphicView::mouseMoveEvent end");
 }
 
+bool QG_GraphicView::event(QEvent *event) {
+#if QT_VERSION >= 0x050200
+    if (event->type() == QEvent::NativeGesture) {
+        QNativeGestureEvent *nge = static_cast<QNativeGestureEvent *>(event);
+
+        if (nge->gestureType() == Qt::ZoomNativeGesture) {
+            double v = nge->value();
+            RS2::ZoomDirection direction;
+            double factor;
+
+            if (v < 0) {
+                direction = RS2::Out;
+                factor = 1-v;
+            } else {
+                direction = RS2::In;
+                factor = 1+v;
+            }
+
+            // It seems the NativeGestureEvent::pos() incorrectly reports global coordinates
+            QPoint g = mapFromGlobal(nge->globalPos());
+            RS_Vector mouse = toGraph(RS_Vector(g.x(), g.y()));
+            setCurrentAction(new RS_ActionZoomIn(*container, *this, direction,
+                                                 RS2::Both, mouse, factor));
+        }
+
+        return true;
+    }
+#endif
+	return QWidget::event(event);
+}
 
 /**
  * support for the wacom graphic tablet.
@@ -362,7 +384,7 @@ void QG_GraphicView::tabletEvent(QTabletEvent* e) {
         switch (e->device()) {
         case QTabletEvent::Eraser:
             if (e->type()==QEvent::TabletRelease) {
-                if (container!=NULL) {
+                if (container) {
 
                     RS_ActionSelectSingle* a =
                         new RS_ActionSelectSingle(*container, *this);
@@ -460,7 +482,53 @@ void QG_GraphicView::wheelEvent(QWheelEvent *e) {
         return;
     }
 
-        RS_Vector mouse = toGraph(RS_Vector(e->x(), e->y()));
+    RS_Vector mouse = toGraph(RS_Vector(e->x(), e->y()));
+
+#if QT_VERSION >= 0x050200
+    QPoint numPixels = e->pixelDelta();
+
+    // high-resolution scrolling triggers Pan instead of Zoom logic
+    isSmoothScrolling |= !numPixels.isNull();
+
+    if (isSmoothScrolling) {
+        if (e->phase() == Qt::ScrollEnd) isSmoothScrolling = false;
+
+        if (!numPixels.isNull()) {
+            if (e->modifiers()==Qt::ControlModifier) {
+                // Hold ctrl to zoom. 1 % per pixel
+                double v = -numPixels.y() / 100.;
+                RS2::ZoomDirection direction;
+                double factor;
+
+                if (v < 0) {
+                    direction = RS2::Out; factor = 1-v;
+                } else {
+                    direction = RS2::In;  factor = 1+v;
+                }
+
+                setCurrentAction(new RS_ActionZoomIn(*container, *this, direction,
+                                                     RS2::Both, mouse, factor));
+            } else {
+                // otherwise, scroll
+				//scroll by scrollbars: issue #479
+				hScrollBar->setValue(hScrollBar->value() - numPixels.x());
+				vScrollBar->setValue(vScrollBar->value() - numPixels.y());
+
+//                setCurrentAction(new RS_ActionZoomScroll(numPixels.x(), numPixels.y(),
+//                                                         *container, *this));
+            }
+            redraw();
+        }
+        e->accept();
+        return;
+    }
+#endif
+
+    if (e->delta() == 0) {
+        // A zero delta event occurs when smooth scrolling is ended. Ignore this
+        e->accept();
+        return;
+    }
 
     bool scroll = false;
     RS2::Direction direction = RS2::Up;
@@ -492,8 +560,18 @@ void QG_GraphicView::wheelEvent(QWheelEvent *e) {
     }
 
     if (scroll) {
-        setCurrentAction(new RS_ActionZoomScroll(direction,
-                         *container, *this));
+		//scroll by scrollbars: issue #479
+		switch(direction){
+		case RS2::Left:
+		case RS2::Right:
+			hScrollBar->setValue(hScrollBar->value()+e->delta());
+			break;
+		default:
+			vScrollBar->setValue(vScrollBar->value()+e->delta());
+		}
+
+//        setCurrentAction(new RS_ActionZoomScroll(direction,
+//                         *container, *this));
     }
 
     // zoom in / out:
@@ -605,43 +683,32 @@ void QG_GraphicView::adjustOffsetControls() {
                 min.y < RS_MINDOUBLE ) {
         min = RS_Vector(-10,-10);
         max = RS_Vector(100,100);
-    }
-
-        int minVal = (int)(-ox-toGuiDX(getWidth())*0.5
-                        - QG_SCROLLMARGIN - getBorderLeft());
-        int maxVal = (int)(-ox+toGuiDX(getWidth())*0.5
-                        + QG_SCROLLMARGIN + getBorderRight());
-
-        hScrollBar->setValue(0);
-        if (minVal<=maxVal) {
-                hScrollBar->setRange(minVal, maxVal);
-        }
-    //hScrollBar->setMinValue(minVal);
-
-        //hScrollBar->setMaxValue(maxVal);
-
-        minVal = (int)(oy-toGuiDY(getHeight())*0.5
-                        - QG_SCROLLMARGIN - getBorderTop());
-        maxVal = (int)(oy+toGuiDY(getHeight())*0.5
-                       +QG_SCROLLMARGIN + getBorderBottom());
-
-        if (minVal<=maxVal) {
-                vScrollBar->setRange(minVal, maxVal);
-        }
-    //vScrollBar->setMaxValue((int)(QG_SCROLLMARGIN + getBorderBottom()
-     //                             - (min.y * getFactor().y)));
+	}
 
 
-    //vScrollBar->setMinValue((int)(getHeight() -
-     //                             max.y * getFactor().y
-     //                             - QG_SCROLLMARGIN - getBorderTop()));
+	int minVal = (int)(-ox-getWidth()*0.5
+					   - QG_SCROLLMARGIN - getBorderLeft());
+	int maxVal = (int)(-ox+getWidth()*0.5
+					   + QG_SCROLLMARGIN + getBorderRight());
 
+	if (minVal<=maxVal) {
+		hScrollBar->setRange(minVal, maxVal);
+	}
 
-    hScrollBar->setPageStep((int)(getWidth()));
-    vScrollBar->setPageStep((int)(getHeight()));
+	minVal = (int)(oy-getHeight()*0.5
+				   - QG_SCROLLMARGIN - getBorderTop());
+	maxVal = (int)(oy+getHeight()*0.5
+				   +QG_SCROLLMARGIN + getBorderBottom());
 
-    hScrollBar->setValue(-ox);
-    vScrollBar->setValue(oy);
+	if (minVal<=maxVal) {
+		vScrollBar->setRange(minVal, maxVal);
+	}
+
+	hScrollBar->setPageStep(getWidth());
+	vScrollBar->setPageStep(getHeight());
+
+	hScrollBar->setValue(-ox);
+	vScrollBar->setValue(oy);
 
 
     slotHScrolled(-ox);
@@ -651,7 +718,7 @@ void QG_GraphicView::adjustOffsetControls() {
     RS_DEBUG->print("H min: %d / max: %d / step: %d / value: %d\n",
                     hScrollBar->minimum(), hScrollBar->maximum(),
                     hScrollBar->pageStep(), ox);
-//    DEBUG_HEADER();
+//    DEBUG_HEADER
     RS_DEBUG->print(/*RS_Debug::D_WARNING, */"V min: %d / max: %d / step: %d / value: %d\n",
                     vScrollBar->minimum(), vScrollBar->maximum(),
                     vScrollBar->pageStep(), oy);
@@ -701,8 +768,8 @@ void QG_GraphicView::slotVScrolled(int value) {
     //static int running = false;
     //if (!running) {
     //running = true;
-//    DEBUG_HEADER();
-    RS_DEBUG->print(/*RS_Debug::D_WARNING,*/ "%s %s(): set vertical offset from %d to %d\n", __FILE__, __FUNCTION__, getOffsetY(), value);
+//    DEBUG_HEADER
+	RS_DEBUG->print(/*RS_Debug::D_WARNING,*/ "%s %s(): set vertical offset from %d to %d\n", __FILE__, __func__, getOffsetY(), value);
     if (vScrollBar->maximum()==vScrollBar->minimum()) {
         centerOffsetY();
     } else {
@@ -718,37 +785,49 @@ void QG_GraphicView::slotVScrolled(int value) {
  * @param oy, offset Y
  */
 void QG_GraphicView::setOffset(int ox, int oy) {
-//    DEBUG_HEADER();
+//    DEBUG_HEADER
 //    qDebug()<<"adjusting offset from ("<<getOffsetX()<<","<<getOffsetY()<<") to ("<<ox<<" , "<<oy<<")";
     RS_GraphicView::setOffset(ox, oy);
     // need to adjust offset control for scrollbars when setting graphicview offset
     adjustOffsetControls();
 }
 
-QPixmap* QG_GraphicView::getPixmapForView(QPixmap *pm)
+RS_Vector QG_GraphicView::getMousePosition() const
 {
+    //find mouse position
+    QPoint vp=mapFromGlobal(QCursor::pos());
+    //if cursor is not on widget, return the widget center position
+    if(!rect().contains(vp))
+        vp=QPoint(width()/2, height()/2);
+    return toGraph(RS_Vector(vp.x(), vp.y()));
+}
 
-        if (pm==NULL) {
-                return new QPixmap(getWidth(), getHeight());
-        } else if (pm->width()!=getWidth() || pm->height()!=getHeight()) {
-                delete pm;
-                return new QPixmap(getWidth(), getHeight());
-        } else {
-                return pm;
-        }
+void QG_GraphicView::getPixmapForView(std::unique_ptr<QPixmap>& pm)
+{
+	QSize const s0(getWidth(), getHeight());
+	if(pm && pm->size()==s0)
+		return;
+	pm.reset(new QPixmap(getWidth(), getHeight()));
 }
 
 void QG_GraphicView::layerActivated(RS_Layer *layer) {
+	RS_SETTINGS->beginGroup("/Modify");
+	bool toActivated= (RS_SETTINGS->readNumEntry("/ModifyEntitiesToActiveLayer", 0)==1);
+	RS_SETTINGS->endGroup();
+
+	if(!toActivated) return;
     RS_EntityContainer *container = this->getContainer();
-    RS_Entity *entity = container->firstEntity();
 
-    while (entity != NULL) {
-        if (entity->isSelected()) {
-            entity->setLayer(layer);
-        }
-
-        entity = container->nextEntity();
-    }
+	//allow undo cycle for layer change of selected
+	RS_AttributesData data;
+	data.pen = RS_Pen();
+	data.layer = layer->getName();
+	data.changeColor = false;
+	data.changeLineType = false;
+	data.changeWidth = false;
+	data.changeLayer = true;
+	RS_Modification m(*container, this);
+	m.changeAttributes(data);
 
     container->setSelected(false);
     redraw(RS2::RedrawDrawing);
@@ -760,62 +839,58 @@ void QG_GraphicView::layerActivated(RS_Layer *layer) {
  * usually that's very fast since we only paint the buffer we
  * have from the last call..
  */
-void QG_GraphicView::paintEvent(QPaintEvent *) {
+void QG_GraphicView::paintEvent(QPaintEvent *)
+{
     RS_DEBUG->print("QG_GraphicView::paintEvent begin");
 
-        RS_SETTINGS->beginGroup("/Appearance");
+    RS_SETTINGS->beginGroup("/Appearance");
     bool draftMode = (bool)RS_SETTINGS->readNumEntry("/DraftMode", 0);
     RS_SETTINGS->endGroup();
 
-
-        // Re-Create or get the layering pixmaps
-        PixmapLayer1=getPixmapForView(PixmapLayer1);
-        PixmapLayer2=getPixmapForView(PixmapLayer2);
-        PixmapLayer3=getPixmapForView(PixmapLayer3);
+    // Re-Create or get the layering pixmaps
+    getPixmapForView(PixmapLayer1);
+    getPixmapForView(PixmapLayer2);
+    getPixmapForView(PixmapLayer3);
 
     // Draw Layer 1
-        if (redrawMethod & RS2::RedrawGrid) {
-                PixmapLayer1->fill(background);
-                RS_PainterQt painter1(PixmapLayer1);
-                //painter1->setBackgroundMode(Qt::OpaqueMode);
-                //painter1->setBackgroundColor(background);
-                //painter1->eraseRect(0,0,getWidth(), getHeight());
-                drawLayer1((RS_Painter*)&painter1);
-                painter1.end();
-        }
+    if (redrawMethod & RS2::RedrawGrid)
+    {
+        PixmapLayer1->fill(background);
+        RS_PainterQt painter1(PixmapLayer1.get());
+        drawLayer1((RS_Painter*)&painter1);
+        painter1.end();
+    }
 
-
-        if (redrawMethod & RS2::RedrawDrawing) {
-                // DRaw layer 2
-                PixmapLayer2->fill(Qt::transparent);
-                RS_PainterQt painter2(PixmapLayer2);
-                painter2.setDrawingMode(drawingMode);
-                setDraftMode(draftMode);
+    if (redrawMethod & RS2::RedrawDrawing)
+    {
+        // DRaw layer 2
+        PixmapLayer2->fill(Qt::transparent);
+        RS_PainterQt painter2(PixmapLayer2.get());
+        painter2.setDrawingMode(drawingMode);
+        setDraftMode(draftMode);
         painter2.setDrawSelectedOnly(false);
         drawLayer2((RS_Painter*)&painter2);
         painter2.setDrawSelectedOnly(true);
         drawLayer2((RS_Painter*)&painter2);
-        //removed to solve bug #3470573
-//        setDraftMode(false);
-                painter2.end();
-        }
+        painter2.end();
+    }
 
-    if (redrawMethod & RS2::RedrawOverlay) {
+    if (redrawMethod & RS2::RedrawOverlay)
+    {
         PixmapLayer3->fill(Qt::transparent);
-        RS_PainterQt painter3(PixmapLayer3);
+        RS_PainterQt painter3(PixmapLayer3.get());
         drawLayer3((RS_Painter*)&painter3);
         painter3.end();
     }
 
-        // Finally paint the layers back on the screen, bitblk to the rescue!
-        RS_PainterQt wPainter(this);
-        //wPainter.setCompositionMode(QPainter::CompositionMode_Screen);
-        wPainter.drawPixmap(0,0,*PixmapLayer1);
-        wPainter.drawPixmap(0,0,*PixmapLayer2);
-        wPainter.drawPixmap(0,0,*PixmapLayer3);
-        wPainter.end();
+    // Finally paint the layers back on the screen, bitblk to the rescue!
+    RS_PainterQt wPainter(this);
+    wPainter.drawPixmap(0,0,*PixmapLayer1);
+    wPainter.drawPixmap(0,0,*PixmapLayer2);
+    wPainter.drawPixmap(0,0,*PixmapLayer3);
+    wPainter.end();
 
-        redrawMethod=RS2::RedrawNone;
+    redrawMethod=RS2::RedrawNone;
     RS_DEBUG->print("QG_GraphicView::paintEvent end");
 }
 
