@@ -50,268 +50,273 @@
 <context>
     <name>LC_List</name>
     <message>
-        <location filename="../list/list.cpp" line="24"/>
-        <location filename="../list/list.cpp" line="31"/>
+        <location filename="../list/list.cpp" line="23"/>
+        <location filename="../list/list.cpp" line="30"/>
         <source>List entities</source>
         <translation>Seznam prvků</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="47"/>
+        <location filename="../list/list.cpp" line="46"/>
         <source>n</source>
         <translation>č.</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="61"/>
+        <location filename="../list/list.cpp" line="60"/>
         <source>Empty Entity</source>
         <translation>Prázdný prvek</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="68"/>
+        <location filename="../list/list.cpp" line="67"/>
         <source>X</source>
         <translation>X</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="68"/>
+        <location filename="../list/list.cpp" line="67"/>
         <source>Y</source>
         <translation>Y</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="74"/>
+        <location filename="../list/list.cpp" line="73"/>
         <source>Layer</source>
         <translation>Hladina</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="76"/>
+        <location filename="../list/list.cpp" line="75"/>
         <source>Color</source>
         <translation>Barva</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="77"/>
+        <location filename="../list/list.cpp" line="76"/>
         <source>Line type</source>
         <translation>Druh čáry</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="78"/>
+        <location filename="../list/list.cpp" line="77"/>
         <source>Line thickness</source>
         <translation>Tloušťka čáry</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="79"/>
+        <location filename="../list/list.cpp" line="78"/>
         <source>ID</source>
         <translation>ID</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="85"/>
+        <location filename="../list/list.cpp" line="84"/>
         <source>POINT</source>
         <translation>BOD</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="86"/>
+        <location filename="../list/list.cpp" line="85"/>
         <location filename="../list/list.cpp" line="195"/>
         <source>in point</source>
         <translation>v bodě</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="91"/>
+        <location filename="../list/list.cpp" line="90"/>
         <source>LINE</source>
         <translation>ÚSEČKA</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="96"/>
+        <location filename="../list/list.cpp" line="95"/>
         <source>from point</source>
         <translation>z bodu</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="99"/>
+        <location filename="../list/list.cpp" line="98"/>
         <source>to point</source>
         <translation>do bodu</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="104"/>
-        <location filename="../list/list.cpp" line="128"/>
+        <location filename="../list/list.cpp" line="103"/>
+        <location filename="../list/list.cpp" line="127"/>
         <source>length</source>
         <translation>délka</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="109"/>
+        <location filename="../list/list.cpp" line="108"/>
         <source>Angle in XY plane</source>
         <translation>Úhel v rovině XY</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="110"/>
+        <location filename="../list/list.cpp" line="109"/>
         <source>Inc.</source>
         <translation>Rozdíl</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="115"/>
+        <location filename="../list/list.cpp" line="114"/>
         <source>ARC</source>
         <translation>OBLOUK</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="116"/>
-        <location filename="../list/list.cpp" line="132"/>
-        <location filename="../list/list.cpp" line="142"/>
+        <location filename="../list/list.cpp" line="115"/>
+        <location filename="../list/list.cpp" line="131"/>
+        <location filename="../list/list.cpp" line="141"/>
         <source>center point</source>
         <translation>střed</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="122"/>
-        <location filename="../list/list.cpp" line="136"/>
+        <location filename="../list/list.cpp" line="121"/>
+        <location filename="../list/list.cpp" line="135"/>
+        <location filename="../list/list.cpp" line="199"/>
         <source>radius</source>
         <translation>poloměr</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="123"/>
+        <location filename="../list/list.cpp" line="122"/>
         <source>initial angle</source>
         <translation>počáteční úhel</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="124"/>
+        <location filename="../list/list.cpp" line="123"/>
         <source>final angle</source>
         <translation>koncový úhel</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="131"/>
+        <location filename="../list/list.cpp" line="130"/>
         <source>CIRCLE</source>
         <translation>KRUŽNICE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="137"/>
+        <location filename="../list/list.cpp" line="136"/>
         <source>circumference</source>
         <translation>obvod</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="138"/>
+        <location filename="../list/list.cpp" line="137"/>
         <source>area</source>
         <translation>obsah</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="141"/>
+        <location filename="../list/list.cpp" line="140"/>
         <source>ELLIPSE</source>
         <translation>ELIPSA</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="145"/>
+        <location filename="../list/list.cpp" line="144"/>
         <source>major axis</source>
         <translation>hlavní osa</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="163"/>
+        <location filename="../list/list.cpp" line="162"/>
         <source>CONSTRUCTIONLINE</source>
         <translation>POMOCNÁ ÚSEČKA</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="166"/>
+        <location filename="../list/list.cpp" line="165"/>
         <source>OVERLAYBOX</source>
         <translation>OVERLAYBOX</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="169"/>
+        <location filename="../list/list.cpp" line="168"/>
         <source>SOLID</source>
         <translation>TĚLESO</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="173"/>
+        <location filename="../list/list.cpp" line="172"/>
         <source>MTEXT</source>
         <translation>VTEXT</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="176"/>
+        <location filename="../list/list.cpp" line="175"/>
         <source>TEXT</source>
         <translation>TEXT</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="179"/>
+        <location filename="../list/list.cpp" line="178"/>
         <source>INSERT</source>
         <translation>VLOŽENÉ</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="182"/>
+        <location filename="../list/list.cpp" line="181"/>
         <source>Name</source>
         <translation>Název</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="183"/>
+        <location filename="../list/list.cpp" line="182"/>
         <source>Insertion point</source>
         <translation>Bod vložení</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="188"/>
+        <location filename="../list/list.cpp" line="187"/>
         <source>POLYLINE</source>
         <translation>KŘIVKA</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="189"/>
+        <location filename="../list/list.cpp" line="188"/>
         <source>Closed</source>
         <translation>Uzavřená</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="190"/>
+        <location filename="../list/list.cpp" line="189"/>
         <source>No</source>
         <translation>Ne</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="190"/>
+        <location filename="../list/list.cpp" line="189"/>
         <source>Yes</source>
         <translation>Ano</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="191"/>
+        <location filename="../list/list.cpp" line="190"/>
         <source>Vertices</source>
         <translation>Uzly</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="199"/>
         <source>curvature</source>
-        <translation>křivost</translation>
+        <translation type="obsolete">křivost</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="203"/>
+        <location filename="../list/list.cpp" line="204"/>
         <source>IMAGE</source>
         <translation>OBRÁZEK</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="206"/>
+        <location filename="../list/list.cpp" line="207"/>
         <source>SPLINE</source>
         <translation>SPLAJNA</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="209"/>
+        <location filename="../list/list.cpp" line="210"/>
+        <source>SPLINEPOINTS</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../list/list.cpp" line="213"/>
         <source>HATCH</source>
         <translation>ŠRAFY</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="212"/>
+        <location filename="../list/list.cpp" line="216"/>
         <source>DIMLEADER</source>
         <translation>ODKAZ</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="215"/>
+        <location filename="../list/list.cpp" line="219"/>
         <source>DIMALIGNED</source>
         <translation>ZAROVNANÁ KÓTA</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="218"/>
+        <location filename="../list/list.cpp" line="222"/>
         <source>DIMLINEAR</source>
         <translation>PŘÍMÁ KÓTA</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="221"/>
+        <location filename="../list/list.cpp" line="225"/>
         <source>DIMRADIAL</source>
         <translation>KÓTA POLOMĚRU</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="224"/>
+        <location filename="../list/list.cpp" line="228"/>
         <source>DIMDIAMETRIC</source>
         <translation>KÓTA PRŮMĚRU</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="227"/>
+        <location filename="../list/list.cpp" line="231"/>
         <source>DIMANGULAR</source>
         <translation>KÓTA ÚHLU</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="230"/>
+        <location filename="../list/list.cpp" line="234"/>
         <source>UNKNOWN</source>
         <translation>NEZNÁMÉ</translation>
     </message>
@@ -344,6 +349,19 @@
         <translation>Ukázkový zásuvný modul</translation>
     </message>
 </context>
+<context>
+    <name>PicFile</name>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="38"/>
+        <source>Read PIC file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="44"/>
+        <source>import PIC file</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>dibPunto</name>
     <message>
@@ -686,7 +704,7 @@
 <context>
     <name>lc_Listdlg</name>
     <message>
-        <location filename="../list/list.cpp" line="240"/>
+        <location filename="../list/list.cpp" line="251"/>
         <source>List entities</source>
         <translation>Seznam prvků</translation>
     </message>
@@ -755,69 +773,155 @@
     </message>
 </context>
 <context>
-    <name>plot</name>
+    <name>picPunto</name>
     <message>
-        <location filename="../plotequation/plot.cpp" line="20"/>
-        <location filename="../plotequation/plot.cpp" line="27"/>
-        <source>Plot plugin</source>
+        <location filename="../picfile/picfile.cpp" line="67"/>
+        <source>File...</source>
+        <translation type="unfinished">Soubor...</translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="77"/>
+        <source>Scale:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../plotequation/plot.cpp" line="27"/>
-        <source>Draw</source>
+        <location filename="../picfile/picfile.cpp" line="81"/>
+        <source>Accept</source>
+        <translation type="unfinished">Přijmout</translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="85"/>
+        <source>Cancel</source>
+        <translation type="unfinished">Zrušit</translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="113"/>
+        <source>Select file</source>
+        <translation type="unfinished">Vyberte soubor</translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="121"/>
+        <source>Scale Factor is empty or invalid</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="134"/>
+        <source>The file %1 not exist</source>
+        <translation type="unfinished">Soubor %1 neexistuje</translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="139"/>
+        <source>Can&apos;t open the file %1</source>
+        <translation type="unfinished">Nelze otevřít soubor %1</translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="146"/>
+        <source>%1 objects imported</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="168"/>
+        <source>picPunto drawLine: first point is empty %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="181"/>
+        <source>picPunto drawLine: next point is empty %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="260"/>
+        <location filename="../picfile/picfile.cpp" line="269"/>
+        <source>format error in %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>plot</name>
+    <message>
+        <location filename="../plotequation/plot.cpp" line="21"/>
+        <location filename="../plotequation/plot.cpp" line="28"/>
+        <source>Plot plugin</source>
+        <translation>Zásuvný modul Vykreslit</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plot.cpp" line="28"/>
+        <source>Draw</source>
+        <translation>Vykreslit</translation>
+    </message>
 </context>
 <context>
     <name>plotDialog</name>
     <message>
-        <location filename="../plotequation/plotdialog.cpp" line="6"/>
+        <location filename="../plotequation/plotdialog.cpp" line="15"/>
         <source>Plot equation</source>
-        <translation type="unfinished"></translation>
+        <translation>Vykreslit rovnici</translation>
     </message>
     <message>
-        <location filename="../plotequation/plotdialog.cpp" line="9"/>
+        <location filename="../plotequation/plotdialog.cpp" line="18"/>
         <source>This plugin allows you to plot mathematical equations.
 If you don&apos;t want to use the parametric form, just leave out &quot;Equation2&quot;.
 You can use pi when you need the value of pi (i.e. (3*pi)).
 Use t or x in your equation as a variable/parameter.
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Tento zásuvný modul umožňuje vykreslovat matematické rovnice.
+Pokud nechcete použít parametrický tvar, vynechte pole &quot;Rovnice 2&quot;.
+V případě potřeby lze použít hodnotu pi (například (3*pi)).
+Jako proměnnou (parametr) rovnice použijte t nebo x.
+</translation>
     </message>
     <message>
-        <location filename="../plotequation/plotdialog.cpp" line="13"/>
+        <location filename="../plotequation/plotdialog.cpp" line="22"/>
         <source>Equation 1:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../plotequation/plotdialog.cpp" line="14"/>
-        <source>Equation 2:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../plotequation/plotdialog.cpp" line="17"/>
-        <source>start value:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../plotequation/plotdialog.cpp" line="18"/>
-        <source>end value:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../plotequation/plotdialog.cpp" line="19"/>
-        <source>step size:</source>
-        <translation type="unfinished"></translation>
+        <translation>Rovnice 1:</translation>
     </message>
     <message>
         <location filename="../plotequation/plotdialog.cpp" line="23"/>
+        <source>Equation 2:</source>
+        <translation>Rovnice 2:</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="26"/>
+        <source>start value:</source>
+        <translation>počáteční hodnota:</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="27"/>
+        <source>end value:</source>
+        <translation>koncová hodnota:</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="28"/>
+        <source>step size:</source>
+        <translation>velikost kroku:</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="32"/>
         <source>Draw</source>
+        <translation>Vykreslit</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="33"/>
+        <source>Cancel</source>
+        <translation>Zrušit</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="59"/>
+        <source>Line Segments</source>
+        <comment>Plot Equation to generate RS_Line segments</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../plotequation/plotdialog.cpp" line="24"/>
-        <source>Cancel</source>
-        <translation type="unfinished">Zrušit</translation>
+        <location filename="../plotequation/plotdialog.cpp" line="60"/>
+        <source>Polyline</source>
+        <comment>Plot Equation to generate RS_Polyline</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="61"/>
+        <source>SplinePoints</source>
+        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
