@@ -207,7 +207,7 @@
     </message>
     <message>
         <source>curvature</source>
-        <translation>izliekums</translation>
+        <translation type="obsolete">izliekums</translation>
     </message>
     <message>
         <source>IMAGE</source>
@@ -249,6 +249,10 @@
         <source>UNKNOWN</source>
         <translation>NEZINĀMS</translation>
     </message>
+    <message>
+        <source>SPLINEPOINTS</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LC_SameProp</name>
@@ -272,6 +276,17 @@
         <translation>Parauga spraudnis</translation>
     </message>
 </context>
+<context>
+    <name>PicFile</name>
+    <message>
+        <source>Read PIC file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>import PIC file</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>dibPunto</name>
     <message>
@@ -609,21 +624,72 @@
     </message>
 </context>
 <context>
-    <name>plot</name>
+    <name>picPunto</name>
     <message>
-        <source>Plot plugin</source>
+        <source>File...</source>
+        <translation type="unfinished">Datne...</translation>
+    </message>
+    <message>
+        <source>Scale:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Draw</source>
+        <source>Accept</source>
+        <translation type="unfinished">Pieņemt</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Atcelt</translation>
+    </message>
+    <message>
+        <source>Select file</source>
+        <translation type="unfinished">Izvēlieties datni</translation>
+    </message>
+    <message>
+        <source>Scale Factor is empty or invalid</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>The file %1 not exist</source>
+        <translation type="unfinished">Datne %1 neeksistē</translation>
+    </message>
+    <message>
+        <source>Can&apos;t open the file %1</source>
+        <translation type="unfinished">Nevar atvērt datni %1</translation>
+    </message>
+    <message>
+        <source>%1 objects imported</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>picPunto drawLine: first point is empty %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>picPunto drawLine: next point is empty %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>format error in %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>plot</name>
+    <message>
+        <source>Plot plugin</source>
+        <translation>Grafiku spraudnis</translation>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation>Zīmēt</translation>
+    </message>
 </context>
 <context>
     <name>plotDialog</name>
     <message>
         <source>Plot equation</source>
-        <translation type="unfinished"></translation>
+        <translation>Grafika vienādojums</translation>
     </message>
     <message>
         <source>This plugin allows you to plot mathematical equations.
@@ -655,12 +721,27 @@ Use t or x in your equation as a variable/parameter.
     </message>
     <message>
         <source>Draw</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Zīmēt</translation>
     </message>
     <message>
         <source>Cancel</source>
         <translation type="unfinished">Atcelt</translation>
     </message>
+    <message>
+        <source>Line Segments</source>
+        <comment>Plot Equation to generate RS_Line segments</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Polyline</source>
+        <comment>Plot Equation to generate RS_Polyline</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SplinePoints</source>
+        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>pointBox</name>
