@@ -50,268 +50,273 @@
 <context>
     <name>LC_List</name>
     <message>
-        <location filename="../list/list.cpp" line="24"/>
-        <location filename="../list/list.cpp" line="31"/>
+        <location filename="../list/list.cpp" line="23"/>
+        <location filename="../list/list.cpp" line="30"/>
         <source>List entities</source>
         <translation>Listar entidades</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="47"/>
+        <location filename="../list/list.cpp" line="46"/>
         <source>n</source>
         <translation>n</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="61"/>
+        <location filename="../list/list.cpp" line="60"/>
         <source>Empty Entity</source>
         <translation>Entidade vazia</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="68"/>
+        <location filename="../list/list.cpp" line="67"/>
         <source>X</source>
         <translation>X</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="68"/>
+        <location filename="../list/list.cpp" line="67"/>
         <source>Y</source>
         <translation>Y</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="74"/>
+        <location filename="../list/list.cpp" line="73"/>
         <source>Layer</source>
         <translation>Camada</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="76"/>
+        <location filename="../list/list.cpp" line="75"/>
         <source>Color</source>
         <translation>Cor</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="77"/>
+        <location filename="../list/list.cpp" line="76"/>
         <source>Line type</source>
         <translation>Tipo de linha</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="78"/>
+        <location filename="../list/list.cpp" line="77"/>
         <source>Line thickness</source>
         <translation>Espessura da linha</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="79"/>
+        <location filename="../list/list.cpp" line="78"/>
         <source>ID</source>
         <translation>ID</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="85"/>
+        <location filename="../list/list.cpp" line="84"/>
         <source>POINT</source>
         <translation>POINT</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="86"/>
+        <location filename="../list/list.cpp" line="85"/>
         <location filename="../list/list.cpp" line="195"/>
         <source>in point</source>
         <translation>no ponto</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="91"/>
+        <location filename="../list/list.cpp" line="90"/>
         <source>LINE</source>
         <translation>LINE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="96"/>
+        <location filename="../list/list.cpp" line="95"/>
         <source>from point</source>
         <translation>do ponto</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="99"/>
+        <location filename="../list/list.cpp" line="98"/>
         <source>to point</source>
         <translation>para o ponto</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="104"/>
-        <location filename="../list/list.cpp" line="128"/>
+        <location filename="../list/list.cpp" line="103"/>
+        <location filename="../list/list.cpp" line="127"/>
         <source>length</source>
         <translation>comprimento</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="109"/>
+        <location filename="../list/list.cpp" line="108"/>
         <source>Angle in XY plane</source>
         <translation>Ângulo no plano XY</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="110"/>
+        <location filename="../list/list.cpp" line="109"/>
         <source>Inc.</source>
         <translation>Inc.</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="115"/>
+        <location filename="../list/list.cpp" line="114"/>
         <source>ARC</source>
         <translation>ARC</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="116"/>
-        <location filename="../list/list.cpp" line="132"/>
-        <location filename="../list/list.cpp" line="142"/>
+        <location filename="../list/list.cpp" line="115"/>
+        <location filename="../list/list.cpp" line="131"/>
+        <location filename="../list/list.cpp" line="141"/>
         <source>center point</source>
         <translation>ponto do centro</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="122"/>
-        <location filename="../list/list.cpp" line="136"/>
+        <location filename="../list/list.cpp" line="121"/>
+        <location filename="../list/list.cpp" line="135"/>
+        <location filename="../list/list.cpp" line="199"/>
         <source>radius</source>
         <translation>raio</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="123"/>
+        <location filename="../list/list.cpp" line="122"/>
         <source>initial angle</source>
         <translation>ângulo inicial</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="124"/>
+        <location filename="../list/list.cpp" line="123"/>
         <source>final angle</source>
         <translation>ângulo final</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="131"/>
+        <location filename="../list/list.cpp" line="130"/>
         <source>CIRCLE</source>
         <translation>CIRCLE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="137"/>
+        <location filename="../list/list.cpp" line="136"/>
         <source>circumference</source>
         <translation>circunferência</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="138"/>
+        <location filename="../list/list.cpp" line="137"/>
         <source>area</source>
         <translation>área</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="141"/>
+        <location filename="../list/list.cpp" line="140"/>
         <source>ELLIPSE</source>
         <translation>ELLIPSE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="145"/>
+        <location filename="../list/list.cpp" line="144"/>
         <source>major axis</source>
         <translation>eixo maior</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="163"/>
+        <location filename="../list/list.cpp" line="162"/>
         <source>CONSTRUCTIONLINE</source>
         <translation>CONSTRUCTIONLINE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="166"/>
+        <location filename="../list/list.cpp" line="165"/>
         <source>OVERLAYBOX</source>
         <translation>OVERLAYBOX</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="169"/>
+        <location filename="../list/list.cpp" line="168"/>
         <source>SOLID</source>
         <translation>SOLID</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="173"/>
+        <location filename="../list/list.cpp" line="172"/>
         <source>MTEXT</source>
         <translation>MTEXT</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="176"/>
+        <location filename="../list/list.cpp" line="175"/>
         <source>TEXT</source>
         <translation>TEXT</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="179"/>
+        <location filename="../list/list.cpp" line="178"/>
         <source>INSERT</source>
         <translation>INSERT</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="182"/>
+        <location filename="../list/list.cpp" line="181"/>
         <source>Name</source>
         <translation>Nome</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="183"/>
+        <location filename="../list/list.cpp" line="182"/>
         <source>Insertion point</source>
         <translation>Ponto de inserção</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="188"/>
+        <location filename="../list/list.cpp" line="187"/>
         <source>POLYLINE</source>
         <translation>POLYLINE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="189"/>
+        <location filename="../list/list.cpp" line="188"/>
         <source>Closed</source>
         <translation>Fechado</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="190"/>
+        <location filename="../list/list.cpp" line="189"/>
         <source>No</source>
         <translation>Não</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="190"/>
+        <location filename="../list/list.cpp" line="189"/>
         <source>Yes</source>
         <translation>Sim</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="191"/>
+        <location filename="../list/list.cpp" line="190"/>
         <source>Vertices</source>
         <translation>Vértices</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="199"/>
         <source>curvature</source>
-        <translation>curvatura</translation>
+        <translation type="obsolete">curvatura</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="203"/>
+        <location filename="../list/list.cpp" line="204"/>
         <source>IMAGE</source>
         <translation>IMAGE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="206"/>
+        <location filename="../list/list.cpp" line="207"/>
         <source>SPLINE</source>
         <translation>SPLINE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="209"/>
+        <location filename="../list/list.cpp" line="210"/>
+        <source>SPLINEPOINTS</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../list/list.cpp" line="213"/>
         <source>HATCH</source>
         <translation>HATCH</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="212"/>
+        <location filename="../list/list.cpp" line="216"/>
         <source>DIMLEADER</source>
         <translation>DIMLEADER</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="215"/>
+        <location filename="../list/list.cpp" line="219"/>
         <source>DIMALIGNED</source>
         <translation>DIMALIGNED</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="218"/>
+        <location filename="../list/list.cpp" line="222"/>
         <source>DIMLINEAR</source>
         <translation>DIMLINEAR</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="221"/>
+        <location filename="../list/list.cpp" line="225"/>
         <source>DIMRADIAL</source>
         <translation>DIMRADIAL</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="224"/>
+        <location filename="../list/list.cpp" line="228"/>
         <source>DIMDIAMETRIC</source>
         <translation>DIMDIAMETRIC</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="227"/>
+        <location filename="../list/list.cpp" line="231"/>
         <source>DIMANGULAR</source>
         <translation>DIMANGULAR</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="230"/>
+        <location filename="../list/list.cpp" line="234"/>
         <source>UNKNOWN</source>
         <translation>UNKNOWN</translation>
     </message>
@@ -344,6 +349,19 @@
         <translation>Plugin de exemplo</translation>
     </message>
 </context>
+<context>
+    <name>PicFile</name>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="38"/>
+        <source>Read PIC file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="44"/>
+        <source>import PIC file</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>dibPunto</name>
     <message>
@@ -698,7 +716,7 @@
 <context>
     <name>lc_Listdlg</name>
     <message>
-        <location filename="../list/list.cpp" line="240"/>
+        <location filename="../list/list.cpp" line="251"/>
         <source>List entities</source>
         <translation>Listar entidades</translation>
     </message>
@@ -767,69 +785,151 @@
     </message>
 </context>
 <context>
-    <name>plot</name>
+    <name>picPunto</name>
     <message>
-        <location filename="../plotequation/plot.cpp" line="20"/>
-        <location filename="../plotequation/plot.cpp" line="27"/>
-        <source>Plot plugin</source>
+        <location filename="../picfile/picfile.cpp" line="67"/>
+        <source>File...</source>
+        <translation type="unfinished">Arquivo...</translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="77"/>
+        <source>Scale:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../plotequation/plot.cpp" line="27"/>
-        <source>Draw</source>
+        <location filename="../picfile/picfile.cpp" line="81"/>
+        <source>Accept</source>
+        <translation type="unfinished">Aceitar</translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="85"/>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancelar</translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="113"/>
+        <source>Select file</source>
+        <translation type="unfinished">Selecionar arquivo</translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="121"/>
+        <source>Scale Factor is empty or invalid</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="134"/>
+        <source>The file %1 not exist</source>
+        <translation type="unfinished">O arquivo %1 não existe</translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="139"/>
+        <source>Can&apos;t open the file %1</source>
+        <translation type="unfinished">Não foi possível abrir o arquivo %1</translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="146"/>
+        <source>%1 objects imported</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="168"/>
+        <source>picPunto drawLine: first point is empty %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="181"/>
+        <source>picPunto drawLine: next point is empty %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../picfile/picfile.cpp" line="260"/>
+        <location filename="../picfile/picfile.cpp" line="269"/>
+        <source>format error in %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>plot</name>
+    <message>
+        <location filename="../plotequation/plot.cpp" line="21"/>
+        <location filename="../plotequation/plot.cpp" line="28"/>
+        <source>Plot plugin</source>
+        <translation>Plugin gráfico</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plot.cpp" line="28"/>
+        <source>Draw</source>
+        <translation>desenho</translation>
+    </message>
 </context>
 <context>
     <name>plotDialog</name>
     <message>
-        <location filename="../plotequation/plotdialog.cpp" line="6"/>
+        <location filename="../plotequation/plotdialog.cpp" line="15"/>
         <source>Plot equation</source>
-        <translation type="unfinished"></translation>
+        <translation>Equação gráfica</translation>
     </message>
     <message>
-        <location filename="../plotequation/plotdialog.cpp" line="9"/>
+        <location filename="../plotequation/plotdialog.cpp" line="18"/>
         <source>This plugin allows you to plot mathematical equations.
 If you don&apos;t want to use the parametric form, just leave out &quot;Equation2&quot;.
 You can use pi when you need the value of pi (i.e. (3*pi)).
 Use t or x in your equation as a variable/parameter.
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Este plugin permite plotar equações matemáticas.Se não desejar usar o modo paramétrico, apenas não use &quot;Equação2&quot;.Você pode usar pi quando precisar do valor de pi (i.e.(3*pi)).Use t ou x na sua equação como uma variável/parâmetro.</translation>
     </message>
     <message>
-        <location filename="../plotequation/plotdialog.cpp" line="13"/>
+        <location filename="../plotequation/plotdialog.cpp" line="22"/>
         <source>Equation 1:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../plotequation/plotdialog.cpp" line="14"/>
-        <source>Equation 2:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../plotequation/plotdialog.cpp" line="17"/>
-        <source>start value:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../plotequation/plotdialog.cpp" line="18"/>
-        <source>end value:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../plotequation/plotdialog.cpp" line="19"/>
-        <source>step size:</source>
-        <translation type="unfinished"></translation>
+        <translation>Equação 1:</translation>
     </message>
     <message>
         <location filename="../plotequation/plotdialog.cpp" line="23"/>
+        <source>Equation 2:</source>
+        <translation>Equação 2:</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="26"/>
+        <source>start value:</source>
+        <translation>valor inicial:</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="27"/>
+        <source>end value:</source>
+        <translation>valor final:</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="28"/>
+        <source>step size:</source>
+        <translation>medida:</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="32"/>
         <source>Draw</source>
+        <translation>Desenhar</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="33"/>
+        <source>Cancel</source>
+        <translation>Cancelar</translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="59"/>
+        <source>Line Segments</source>
+        <comment>Plot Equation to generate RS_Line segments</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../plotequation/plotdialog.cpp" line="24"/>
-        <source>Cancel</source>
-        <translation type="unfinished">Cancelar</translation>
+        <location filename="../plotequation/plotdialog.cpp" line="60"/>
+        <source>Polyline</source>
+        <comment>Plot Equation to generate RS_Polyline</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../plotequation/plotdialog.cpp" line="61"/>
+        <source>SplinePoints</source>
+        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
